@@ -12,28 +12,22 @@ import ApexCharts from 'apexcharts'
 window.moment = moment
 window.ApexCharts = ApexCharts
 
-import 'jquery-ui-bundle'
+import 'jquery-ui'
 import './scripts/vendors/jquery/jquery.resizableColumns.js';
 import './scripts/vendors/jquery/jquery-print.min.js';
 
 import * as store from 'store-js';
 window.store = store;
 
+import Sortable from './scripts/vendors/sortablejs/sortable.core.esm.js';
+window.Sortable = Sortable
+
 /* See https://datatables.net/forums/discussion/comment/103356 */
 import dt from 'datatables.net-dt'
 import 'datatables.net-buttons-dt'
 import 'datatables.net-responsive-dt'
 window.dt = dt
 
-/*
-NOTE: It seemes that bs5 datatable components are not correctly working on MacOS
-
-import 'datatables.net'
-import 'datatables.net-buttons-bs'
-import 'datatables.net-responsive-bs'
-import 'datatables.net-bs'
-*/
-
 import 'peity'
 import * as L from 'leaflet'
 import 'leaflet.markercluster'
