@@ -2,11 +2,13 @@ import interfaceTopTables from "./interface_top_tables.js";
 import hostTopTables from "./host_top_tables.js";
 import snmpInterfaceTopTables from "./snmp_interface_top_tables.js";
 import flowDeviceTopTables from "./flow_device_top_tables.js";
+import proxySnmp from "../proxies/snmp.js";
 
 const ui_types = {
 	hide: "hide",
 	select: "select",
 	input: "input",
+	input: "input_confirm",
 };
 
 const sources_url_el_to_source = {
@@ -36,6 +38,14 @@ const sources_url_el_to_source = {
 			value,
 		};
 	},
+	blacklist: (b) => {
+		let label = `${b.column_name}`;
+		let value = label;
+		return {
+			label,
+			value,
+		};
+	},
 	device: (device) => {
 		let label = `${device.name}`;
 		let value = `${device.ip}`;
@@ -45,21 +55,19 @@ const sources_url_el_to_source = {
 		};
 	},
 	if_index: (index) => {
-		console.log(index.device.ip);
 		return '';
-	/*	let label = `${index.name}`;
-		let value = `${index.ip}`;
-		return {
+		/*	let label = `${index.name}`;
+			let value = `${index.ip}`;
+			return {
 			label,
 			value,
-		};*/
+			};*/
 	}
 };
 
 const sources_types_tables = {
 	interface: interfaceTopTables,
 	host: hostTopTables,
-	snmp_interface: snmpInterfaceTopTables,
 	snmp_device: snmpInterfaceTopTables,
 	flow_device: flowDeviceTopTables,
 	flow_interface: flowDeviceTopTables,
@@ -71,10 +79,12 @@ const sources_types = [
 		regex_page_url: "lua\/if_stats", // regex to match url page
 		label: i18n("page_stats.source_def.interface"),
 		query: "iface",
+		f_map_ts_options: null, // convert rest result
 		source_def_array: [{
 			main_source_def: true,
 			label: i18n("page_stats.source_def.interface"),
 			regex_type: null,
+			refresh_on_sources_change: false, // if true sources list are realoaded every time some selected sources changed 
 			sources_url: "lua/rest/v2/get/ntopng/interfaces.lua", // url to get sources list
 			sources_function: null, // custom function that return sources_list, overwrite sources_url
 			value: "ifid", // used in tsQuery parameter, to get init and set value in url
@@ -86,6 +96,33 @@ const sources_types = [
 			ui_type: ui_types.select,
 		}],
 	},
+	{
+		id: "blacklist", //unique id
+		regex_page_url: "lua\/admin\/blacklists", // regex to match url page
+		label: i18n("page_stats.source_def.blacklist"),
+		query: "blacklist",
+		f_map_ts_options: (ts_options, ts_group) => {
+			if (ts_options.series == null) {
+				return ts_options;
+			}
+			ts_options.series.forEach((s) => {
+				if (ts_group.metric.query != null) {
+					s.name = ts_group.metric.label;
+				} else {
+					s.name = s.name.replaceAll("_", " ");
+					s.type = undefined;
+				}
+			});
+			return ts_options;
+		},
+		// display_full_name: true,
+		source_def_array: [{
+			label: i18n("page_stats.source_def.interface"),
+			sources_function: () => { return [{ label: "System", value: -1 }] },
+			value: "ifid",
+			ui_type: ui_types.hide,
+		},]
+	},
 	{
 		id: "vulnerability_scan", //unique id
 		regex_page_url: "lua\/vulnerability_scan", // regex to match url page
@@ -97,7 +134,7 @@ const sources_types = [
 			value: "ifid",
 			ui_type: ui_types.hide,
 		}]
-		
+
 	},
 	{
 		id: "host",
@@ -157,7 +194,7 @@ const sources_types = [
 	},
 	{
 		id: "as",
-		regex_page_url: "lua\/as_details",
+		regex_page_url: "lua\/as_stats",
 		label: i18n("page_stats.source_def.as"),
 		query: "asn",
 		source_def_array: [{
@@ -326,6 +363,9 @@ const sources_types = [
 		regex_page_url: "lua\/pro\/enterprise\/snmp_interface_details",
 		label: i18n("page_stats.source_def.snmp_interface"),
 		query: "snmp_interface",
+		f_map_ts_options: (ts_options, ts_group) => {
+			return ts_options;
+		},
 		source_def_array: [{
 			label: i18n("page_stats.source_def.interface"),
 			sources_function: () => { return [{ label: "", value: -1 }] },
@@ -337,15 +377,22 @@ const sources_types = [
 			sources_url: "lua/pro/rest/v2/get/snmp/device/list.lua", // url to get sources list
 			value: "device",
 			value_url: "host",
-			ui_type: ui_types.input,
+			// refresh_i18n: 'modal_timeseries.snmp_confirm_device',
+			// ui_type: ui_types.input_confirm,
+			ui_type: ui_types.select,
 		}, {
 			main_source_def: true,
 			label: i18n("page_stats.source_def.snmp_interface"),
-//			sources_url: "lua/pro/rest/v2/get/snmp/device/interfaces.lua",
 			regex_type: "text",
+			refresh_on_sources_change: true,
+			sources_function: async (selected_source_value_array) => {
+				const device_host = selected_source_value_array[1];
+				let snmp_interfaces = await proxySnmp.available_interfaces(device_host);
+				return snmp_interfaces.map((iface) => { return { label: iface.name, value: iface.id }; });
+			},
 			value: "if_index",
 			value_url: "snmp_port_idx",
-			ui_type: ui_types.input,
+			ui_type: ui_types.select,
 		}],
 	},
 	{
@@ -370,9 +417,52 @@ const sources_types = [
 			ui_type: ui_types.input,
 		}],
 	},
+	{
+		id: "snmp_qos",
+		id_group: "snmp",
+		regex_page_url: "lua\/pro\/enterprise\/snmp_device_details",
+		label: i18n("page_stats.source_def.snmp_interface"),
+		query: "snmp_interface",
+		f_map_ts_options: (ts_options, ts_group) => {
+			return ts_options;
+		},
+		source_def_array: [{
+			label: i18n("page_stats.source_def.interface"),
+			sources_function: () => { return [{ label: "", value: -1 }] },
+			value: "ifid",
+			ui_type: ui_types.hide,
+		}, {
+			label: i18n("page_stats.source_def.device"),
+			regex_type: "ip",
+			sources_url: "lua/pro/rest/v2/get/snmp/device/list.lua", // url to get sources list
+			value: "device",
+			value_url: "host",
+			ui_type: ui_types.select,
+		}, {
+			main_source_def: true,
+			label: i18n("page_stats.source_def.snmp_interface"),
+			regex_type: "text",
+			refresh_on_sources_change: true,
+			sources_function: async (selected_source_value_array) => {
+				const device_host = selected_source_value_array[1];
+				let snmp_interfaces = await proxySnmp.available_interfaces(device_host);
+				return snmp_interfaces.map((iface) => { return { label: iface.name, value: iface.id }; });
+			},
+			value: "if_index",
+			value_url: "snmp_port_idx",
+			ui_type: ui_types.select,
+		}, {
+			label: i18n("snmp.qos"),
+			regex_type: "text",
+			sources_url: "", 
+			value: "qos_class_id",
+			value_url: "qos_class_id",
+			ui_type: ui_types.hide,
+		}],
+	},
 	{
 		id: "flow_device",
-		regex_page_url: "lua\/pro\/enterprise\/flowdevices_stats",
+		regex_page_url: "lua\/pro\/enterprise\/exporters",
 		label: i18n("page_stats.source_def.flow_device"),
 		query: "flowdev",
 		source_def_array: [{
@@ -415,50 +505,6 @@ const sources_types = [
 			ui_type: ui_types.input,
 		}],
 	},
-	{
-		id: "sflow_device",
-		regex_page_url: "lua\/pro\/enterprise\/sflowdevices_stats",
-		label: i18n("page_stats.source_def.sflow_device"),
-		query: "sflowdev",
-		source_def_array: [{
-			label: i18n("page_stats.source_def.interface"),
-			sources_url: "lua/rest/v2/get/ntopng/interfaces.lua",
-			value: "ifid",
-			ui_type: ui_types.select,
-		}, {
-			main_source_def: true,
-			label: i18n("page_stats.source_def.device"),
-			regex_type: "ip",
-			value: "device",
-			value_url: "ip",
-			ui_type: ui_types.input,
-		}],
-	},
-	{
-		id: "sflow_interface",
-		regex_page_url: "lua\/pro\/enterprise\/sflowdevice_interface_details",
-		label: i18n("page_stats.source_def.sflow_interface"),
-		query: "sflowdev_port",
-		source_def_array: [{
-			label: i18n("page_stats.source_def.interface"),
-			sources_url: "lua/rest/v2/get/ntopng/interfaces.lua",
-			value: "ifid",
-			ui_type: ui_types.select,
-		}, {
-			label: i18n("page_stats.source_def.device"),
-			regex_type: "ip",
-			value: "device",
-			value_url: "ip",
-			ui_type: ui_types.input,
-		}, {
-			main_source_def: true,
-			label: i18n("page_stats.source_def.port"),
-			regex_type: "port",
-			value: "port",
-			value_url: "snmp_port_idx",
-			ui_type: ui_types.input,
-		}],
-	},
 	{
 		id: "observation_point",
 		regex_page_url: "lua\/pro\/enterprise\/observation_points",
