@@ -169,21 +169,7 @@ export const ntopng_utility = function() {
         return await ntopng_utility.http_request(url, rest_params);    
     },
 	from_utc_to_server_date_format: function(utc_ms, format) {
-	    if (format == null) { format = "DD/MMM/YYYY HH:mm"; }
-
-            /* This looks like an hack, please avoid it as creates issues
-	    let status = ntopng_status_manager.get_status();
-	    let epoch_begin = status.epoch_begin;
-	    let epoch_end = status.epoch_end;
-	    if (epoch_begin != null && epoch_end != null && format != null) {
-		let begin = Number.parseInt(epoch_begin);
-		let end = Number.parseInt(epoch_end);
-		if (end - begin <= 11000) {
-		    format = "DD/MMM/YYYY HH:mm:ss";
-		}
-	    }
-	    */
-
+	    if (format == null) { format = "DD/MMM/YYYY HH:mm:ss"; }
 	    let m = moment.tz(utc_ms, ntop_zoneinfo);
 	    let tz_server = m.format(format);
 	    return tz_server;
@@ -222,7 +208,7 @@ export const ntopng_utility = function() {
 	    if (params.csrf == null) {
 		throw `NULL csrf in ${url} POST request.`;
 	    }
-	    return this.http_request(url, { method: 'post', headers, body: JSON.stringify(params) });
+	    return this.http_request(url, { method: 'post', headers, body: JSON.stringify(params) }, throw_exception, not_unwrap);
 	},
 	http_request: async function(url, options, throw_exception, not_unwrap) {
 	    try {
@@ -239,13 +225,13 @@ export const ntopng_utility = function() {
 		    };
 		}
 		let res = await fetch(url, options);
-		if (res.ok == false) {
+		if (res.ok === false) {
 		    console.error(`http_request ${url}\n ok == false`);
 		    console.error(res);
 		    return null;
 		}
 		let json_res = await res.json();
-		if (not_unwrap == true) { return json_res; }
+		if (not_unwrap === true) { return json_res; }
 		return json_res.rsp;
 	    } catch (err) {
 		console.error(err);
