@@ -20,6 +20,7 @@ import { default as PageHostTLS } from "./page-host-tls.vue";
 import { default as PageHostSSH } from "./page-host-ssh.vue";
 import { default as PageHomeMap } from "./page-home-map.vue";
 import { default as PageSankey } from "./page-sankey.vue";
+//import { default as PageSankeyTest } from "./sankey-test.vue";
 import { default as PageHostDetailsApplications } from "./page-host-details-applications.vue";
 import { default as PageHostDetailsTraffic } from "./page-host-details-traffic.vue";
 import { default as PageHostDetailsPackets } from "./page-host-details-packets.vue";
@@ -41,10 +42,34 @@ import { default as PageHostsPortsAnalysis } from "./page-hosts-ports-analysis.v
 import { default as NedgeRepeatersConfig } from "./page-nedge-repeaters-config.vue";
 import { default as PageInactiveHosts } from "./page-inactive-hosts.vue";
 import { default as PageInactiveHostDetails } from "./page-inactive-host-details.vue";
-import { default as PageFlowDeviceDetails } from "./page-flowdevice-config.vue";
-import { default as PageHostsToScan } from "./page-hosts-to-scan.vue";
+import { default as PageExportersConfig } from "./page-flowdevice-config.vue";
+import { default as PageFlowDeviceInterfaceDetails } from "./page-flowdevice-interface-config.vue";
+import { default as PageVulnerabilityScan } from "./page-vulnerability-scan.vue";
 import { default as PageHostVsResult } from "./page-host-vs-result.vue";
 import { default as PageOpenPorts } from "./page-open-ports.vue";
+import { default as PageVulnerabilityScanReport } from "./page-vulnerability-scan-report.vue"
+import { default as PageSNMPUsage } from "./page-snmp-usage.vue"
+import { default as PageHostsList } from "./page-hosts-list.vue"
+import { default as PageFlowsList } from "./page-flows-list.vue"
+import { default as PageSNMPInterfaces } from "./page-snmp-interfaces.vue"
+import { default as PageSNMPTopology } from "./page-snmp-topology.vue"
+import { default as PageSNMPTopologyMap } from "./page-snmp-topology-map.vue"
+import { default as PageSNMPSimilarity } from "./page-snmp-similarity.vue"
+import { default as PageSNMPDevices } from "./page-snmp-devices.vue"
+import { default as PageBlacklists } from "./page-blacklists.vue"
+import { default as PageHistoricalFlow } from "./page-historical-flow-details.vue"
+import { default as PageSNMPQoS } from "./page-snmp-qos.vue"
+import { default as PageGeoMap } from "./hosts-geomap.vue"
+import { default as PageCountryStats } from "./page-country-stats.vue"
+import { default as PageAsStats } from "./page-as-stats.vue"
+import { default as PageProbes } from "./page-probes.vue"
+import { default as PageExporters } from "./page-exporters.vue"
+import { default as PageExportersDetails } from "./page-exporters-details.vue"
+
+/* Config pages */
+import { default as PageSNMPConfig } from "./page-snmp-config.vue"
+import { default as PageHostConfig } from "./page-host-config.vue"
+
 // components
 import { default as AlertInfo } from "./alert-info.vue";
 import { default as Chart } from "./chart.vue";
@@ -87,6 +112,11 @@ import { default as ModalSnapshot } from "./modal-snapshot.vue";
 import { default as ModalAddHostRules } from "./modal-add-host-rules.vue";
 import { default as ModalAddApplication } from "./modal-add-application.vue";
 import { default as ModalDeleteApplication } from "./modal-delete-application.vue";
+import { default as ModalEditReport } from "./modal-edit-vs-report.vue";
+import { default as ModalAddSNMPDevice } from "./modal-add-snmp-device.vue";
+import { default as ModalDeleteSNMPDevice } from "./modal-delete-snmp-device.vue";
+import { default as ModalImportSNMPDevices } from "./modal-import-snmp-devices.vue";
+import { default as ModalEditBlacklist } from "./modal-edit-blacklist.vue";
 
 let ntopVue = {
     // pages
@@ -112,10 +142,25 @@ let ntopVue = {
     PageHostsPortsAnalysis: PageHostsPortsAnalysis,
     PageInactiveHosts: PageInactiveHosts,
     PageInactiveHostDetails: PageInactiveHostDetails,
-    PageHostsToScan: PageHostsToScan,
+    PageVulnerabilityScan: PageVulnerabilityScan,
     PageHostVsResult: PageHostVsResult,
     PageOpenPorts: PageOpenPorts,
+    PageVulnerabilityScanReport: PageVulnerabilityScanReport,
+    PageFlowsList: PageFlowsList,
+    PageAsStats: PageAsStats,
+    PageProbes: PageProbes,
+    PageExportersDetails: PageExportersDetails,
     
+    /* SNMP */
+    PageSNMPDevices: PageSNMPDevices,
+    PageSNMPQoS: PageSNMPQoS,
+    PageSNMPConfig: PageSNMPConfig,
+    PageSNMPUsage: PageSNMPUsage,
+    PageSNMPInterfaces: PageSNMPInterfaces,
+    PageSNMPTopology: PageSNMPTopology,
+    PageSNMPTopologyMap: PageSNMPTopologyMap,
+    PageSNMPSimilarity: PageSNMPSimilarity,
+
     PageEditApplications: PageEditApplications,
 
     PageVLANPortsFlowSankey: PageVLANPortsSankey,
@@ -125,20 +170,26 @@ let ntopVue = {
     NedgeRulesConfig: NedgeRulesConfig,
     NedgeRepeatersConfig: NedgeRepeatersConfig,
 
-
+    PageBlacklists: PageBlacklists,
+    //PageChatbot: PageChatbot,
     // Host details pages
     PageHostDetailsApplications: PageHostDetailsApplications,
     PageHostDetailsTraffic: PageHostDetailsTraffic,
     PageHostDetailsPackets: PageHostDetailsPackets,
     PageHostDetailsFlowSankey: PageHostDetailsFlowSankey,
     PageHostDetailsPorts: PageHostDetailsPorts,
-
+    PageHostsList: PageHostsList,
+    PageGeoMap: PageGeoMap,
+    PageHostConfig: PageHostConfig,
+    PageCountryStats: PageCountryStats,
+    PageExporters: PageExporters,
     PageAggregatedLiveFlows: PageAggregatedLiveFlows,
-
     PageNetworkDiscovery: PageNetworkDiscovery,
-
-    PageFlowDeviceDetails: PageFlowDeviceDetails,
-
+    PageExportersConfig: PageExportersConfig,
+    PageFlowDeviceInterfaceDetails: PageFlowDeviceInterfaceDetails,
+    PageHistoricalFlow: PageHistoricalFlow,
+    //PageSankeyTest: PageSankeyTest,
+    
     // components
     AlertInfo: AlertInfo,
     Chart: Chart,
@@ -181,6 +232,11 @@ let ntopVue = {
     ModalAddHostRules: ModalAddHostRules,
     ModalAddApplication: ModalAddApplication,
     ModalDeleteApplication: ModalDeleteApplication,
+    ModalEditReport: ModalEditReport,
+    ModalAddSNMPDevice: ModalAddSNMPDevice,
+    ModalDeleteSNMPDevice: ModalDeleteSNMPDevice,
+    ModalImportSNMPDevices: ModalImportSNMPDevices,
+    ModalEditBlacklist: ModalEditBlacklist,
 
     Vue: Vue,
 };
