@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,8 +28,11 @@ class Alert {
   time_t last_update;
   AlertType alert_id;
   u_int8_t score;
+  u_int16_t port;
   std::string subtype;
   std::string json;
+  std::string ip;
+  std::string name;
 };
 
 #endif
