@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,15 +32,11 @@
  *
  */
 
-#define ALERT_COUNTER_WINDOW_SECS 3
-
 class AlertCounter {
  private:
   time_t time_last_hit;
-  u_int16_t trailing_window[ALERT_COUNTER_WINDOW_SECS];
-  u_int16_t trailing_window_min;
-  u_int16_t trailing_window_max_since_hits_reset;
-  u_int8_t trailing_index;
+  u_int16_t current_hits;
+  u_int16_t max_hits_since_reset;
   bool hits_reset_req;
 
   void reset_window(time_t when = 0);
@@ -52,4 +48,9 @@ class AlertCounter {
   void reset_hits();
 };
 
+typedef struct {
+  AlertCounter *attacker_counter, *victim_counter;
+} AttackVictimCounter;
+
+
 #endif /* _ALERT_COUNTER_H_ */
