@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@ class AlertStore {
   AlertStore() { ; };
   virtual ~AlertStore() { ; };
 
-  virtual bool query(lua_State *vm, const char *query) { return false; };
+  virtual bool query(lua_State *vm, const char *query, bool limit_rows) { return false; };
 };
 
 #endif /* _ALERT_STORE_H_ */
