@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,4 +44,8 @@ class Fingerprint {
   void lua(const char *key, lua_State *vm);
 };
 
+typedef struct {
+  Fingerprint ja4, hassh;
+} HostFingerprints;
+
 #endif /* _FINGERPRINT_H_ */
