@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,14 +37,19 @@ class FlowCheck;
 
 class Flow : public GenericHashEntry {
  private:
+  int32_t iface_index; /* Interface index on which this flow has been first observed */
   Host *cli_host, *srv_host;
   IpAddress *cli_ip_addr, *srv_ip_addr;
+  /* IPv4 only, so a int32 bit is only needed */
+  u_int32_t src_ip_addr_pre_nat, dst_ip_addr_pre_nat,
+            src_ip_addr_post_nat, dst_ip_addr_post_nat;
   ICMPinfo *icmp_info;
-  u_int32_t privateFlowId /* Used to store specific flow info such as DNS
-                             TransactionId */
-      ;
+  ndpi_confidence_t ndpi_confidence;
+  u_int32_t privateFlowId; /* Used to store specific flow info such as DNS TransactionId or SIP CallId */
   u_int8_t cli2srv_tos, srv2cli_tos; /* RFC 2474, 3168 */
   u_int16_t cli_port, srv_port;
+  u_int16_t src_port_pre_nat, dst_port_pre_nat,
+            src_port_post_nat, dst_port_post_nat;
   u_int16_t vlanId;
   u_int32_t vrfId;
   u_int32_t srcAS, dstAS, prevAdjacentAS, nextAdjacentAS;
@@ -61,15 +66,17 @@ class Flow : public GenericHashEntry {
      predominant of a flow, which is written into `predominant_alert`.
   */
   Bitmap128 alerts_map;
+  std::map<FlowAlertTypeEnum, u_int16_t /* score */> alert_score;
   FlowAlertType predominant_alert;   /* This is the predominant alert */
-  u_int16_t predominant_alert_score; /* The score associated to the predominant
-                                        alert */
+  u_int16_t predominant_alert_score; /* The score associated to the predominant alert */
+  FlowSource flow_source;
+  
   struct {
     u_int8_t is_cli_attacker : 1, is_cli_victim : 1, is_srv_attacker : 1,
         is_srv_victim : 1, auto_acknowledge : 1;
   } predominant_alert_info;
 
-  char *json_protocol_info, *riskInfo;
+  char *json_protocol_info, *riskInfo, *end_reason;
 
   /* Calculate the entropy on the first MAX_ENTROPY_BYTES bytes */
   struct {
@@ -86,6 +93,7 @@ class Flow : public GenericHashEntry {
       has_malicious_srv_signature : 1, src2dst_tcp_zero_window : 1,
       dst2src_tcp_zero_window : 1, non_zero_payload_observed : 1,
       is_periodic_flow : 1;
+  u_int8_t iface_flow_accounted:1, _notused:7;
 
   ndpi_multimedia_flow_type rtp_stream_type;
 #ifdef ALERTED_FLOWS_DEBUG
@@ -106,6 +114,7 @@ class Flow : public GenericHashEntry {
 #endif
   char *ndpiAddressFamilyProtocol;
   ndpi_protocol ndpiDetectedProtocol;
+  char *ndpiFlowRiskName;
   custom_app_t custom_app;
 
   struct {
@@ -116,7 +125,7 @@ class Flow : public GenericHashEntry {
   json_object *json_info;
   ndpi_serializer *tlv_info;
   ndpi_confidence_t confidence;
-  char *host_server_name, *bt_hash;
+  char *host_server_name, *bt_hash, *stun_mapped_address;
   IEC104Stats *iec104;
 #ifdef NTOPNG_PRO
   ModbusStats *modbus;
@@ -132,8 +141,7 @@ class Flow : public GenericHashEntry {
     char *source;
     json_object *json;
   } external_alert;
-  bool
-      trigger_immediate_periodic_update; /* needed to process external alerts */
+  bool trigger_immediate_periodic_update; /* needed to process external alerts */
   time_t next_call_periodic_update; /* The time at which the periodic lua script
                                        on this flow shall be called */
 
@@ -170,6 +178,14 @@ class Flow : public GenericHashEntry {
       char *name;
     } netbios;
 
+    struct {
+      char *name;
+    } dhcp;
+
+    struct {
+      char *call_id;
+    } sip;
+
     struct {
       char *client_signature, *server_signature;
       struct {
@@ -186,12 +202,8 @@ class Flow : public GenericHashEntry {
       char *client_requested_server_name, *server_names;
       /* Certificate dissection */
       struct {
-        /* https://engineering.salesforce.com/tls-fingerprinting-with-ja3-and-ja3s-247362855967
-         */
-        char *client_hash, *server_hash;
-        u_int16_t server_cipher;
-        ndpi_cipher_weakness server_unsafe_cipher;
-      } ja3;
+        char *client_hash;
+      } ja4;
     } tls;
 
     struct {
@@ -208,6 +220,11 @@ class Flow : public GenericHashEntry {
     struct {
       char * currency;
     } mining;
+
+    struct {
+      char * mail_from;
+      char * rcpt_to;
+    } smtp;
     
   } protos;
 
@@ -265,20 +282,21 @@ class Flow : public GenericHashEntry {
   } flowShaperIds;
 #endif
   struct timeval last_update_time;
-
+  
   float top_bytes_thpt, top_goodput_bytes_thpt, top_pkts_thpt;
-  float bytes_thpt_cli2srv, goodput_bytes_thpt_cli2srv;
-  float bytes_thpt_srv2cli, goodput_bytes_thpt_srv2cli;
-  float pkts_thpt_cli2srv, pkts_thpt_srv2cli;
+  float bytes_thpt, goodput_bytes_thpt;
+  float pkts_thpt;
   ValueTrend bytes_thpt_trend, goodput_bytes_thpt_trend, pkts_thpt_trend;
-
+  
+  MinorConnectionStates current_c_state; 
+  u_int counter = 0;
   /*
-     IMPORTANT NOTE
-
-     if you add a new 'directional' field such as cliX and serverX
-     you need to handle it in the Flow::swap() method
+    IMPORTANT NOTE
+    
+    if you add a new 'directional' field such as cliX and serverX
+    you need to handle it in the Flow::swap() method
   */
-
+  
   void deferredInitialization();
   char *intoaV4(unsigned int addr, char *buf, u_short bufLen);
   void allocDPIMemory();
@@ -303,8 +321,7 @@ class Flow : public GenericHashEntry {
     Check (and possibly enqueues) the flow for dump
    */
   void dumpCheck(time_t t, bool last_dump_before_free);
-  void updateCliJA3();
-  void updateSrvJA3();
+  void updateCliJA4();
   void updateHASSH(bool as_client);
   void processExtraDissectedInformation();
   void processDetectedProtocol(
@@ -312,7 +329,7 @@ class Flow : public GenericHashEntry {
   void processDetectedProtocolData(); /* nDPI detected protocol data (e.g.,
                                          ndpiFlow->host_server_name) */
   void setExtraDissectionCompleted();
-  void setProtocolDetectionCompleted(u_int8_t *payload, u_int16_t payload_len);
+  void setProtocolDetectionCompleted(u_int8_t *payload, u_int16_t payload_len, time_t when_seen);
   void updateProtocol(ndpi_protocol proto_id);
   const char *cipher_weakness2str(ndpi_cipher_weakness w) const;
   bool get_partial_traffic_stats(PartializableFlowTrafficStats **dst,
@@ -341,13 +358,14 @@ class Flow : public GenericHashEntry {
   /* Decreases scores on both client and server hosts when the flow is being
    * destructed */
   void decAllFlowScores();
-  void updateServerPortsStats(Host *server_host, ndpi_protocol *proto);
+  void updateServerPortsStats(Host *server_host, ndpi_protocol *proto, time_t when_seen);
   void updateClientContactedPorts(Host *client, ndpi_protocol *proto);
   void updateTCPHostServices(Host *cli_h, Host *srv_h);
   void updateUDPHostServices();
-
+  
  public:
-  Flow(NetworkInterface *_iface, u_int16_t _u_int16_t,
+  Flow(NetworkInterface *_iface, int32_t iface_idx,
+       u_int16_t _vlanId,
        u_int16_t _observation_point_id, u_int32_t _private_flow_id,
        u_int8_t _protocol, Mac *_cli_mac, IpAddress *_cli_ip,
        u_int16_t _cli_port, Mac *_srv_mac, IpAddress *_srv_ip,
@@ -421,7 +439,7 @@ class Flow : public GenericHashEntry {
   void setProtocolJSONInfo();
   void getProtocolJSONInfo(ndpi_serializer *serializer);
 
-  inline char *getJa3CliHash() { return (protos.tls.ja3.client_hash); }
+  inline char *getJa4CliHash() { return (protos.tls.ja4.client_hash); }
 
   bool isBlacklistedFlow() const;
   bool isBlacklistedClient() const;
@@ -432,40 +450,37 @@ class Flow : public GenericHashEntry {
   bool isTiny() const;
   inline bool isProto(u_int16_t p) const {
     return (((ndpiDetectedProtocol.master_protocol == p) ||
-             (ndpiDetectedProtocol.app_protocol == p))
-                ? true
-                : false);
+             (ndpiDetectedProtocol.app_protocol == p)) ? true : false);
   }
   bool isTLS() const;
   inline bool isEncryptedProto() const {
     return (ndpi_is_encrypted_proto(iface->get_ndpi_struct(),
                                     ndpiDetectedProtocol));
   }
-  inline bool isSSH() const { return (isProto(NDPI_PROTOCOL_SSH)); }
-  inline bool isMining() const { return (isProto(NDPI_PROTOCOL_MINING));}
-  inline bool isDNS() const { return (isProto(NDPI_PROTOCOL_DNS)); }
+  inline bool isSSH() const     { return (isProto(NDPI_PROTOCOL_SSH)); }
+  inline bool isMining() const  { return (isProto(NDPI_PROTOCOL_MINING));}
+  inline bool isDNS() const     { return (isProto(NDPI_PROTOCOL_DNS)); }
+  inline bool isSTUN() const    { return (isProto(NDPI_PROTOCOL_STUN)); }
   inline bool isZoomRTP() const {
     return (isProto(NDPI_PROTOCOL_ZOOM) && (isProto(NDPI_PROTOCOL_RTP) || isProto(NDPI_PROTOCOL_SRTP)) );
   }
   inline bool isIEC60870() const { return (isProto(NDPI_PROTOCOL_IEC60870)); }
   inline bool isModbus()   const { return (isProto(NDPI_PROTOCOL_MODBUS));   }
-  inline bool isMDNS() const { return (isProto(NDPI_PROTOCOL_MDNS)); }
-  inline bool isSSDP() const { return (isProto(NDPI_PROTOCOL_SSDP)); }
-  inline bool isNetBIOS() const { return (isProto(NDPI_PROTOCOL_NETBIOS)); }
-  inline bool isDHCP() const { return (isProto(NDPI_PROTOCOL_DHCP)); }
-  inline bool isNTP() const { return (isProto(NDPI_PROTOCOL_NTP)); }
-  inline bool isSMTP() const {
-    return (isProto(NDPI_PROTOCOL_MAIL_SMTP) ||
-            isProto(NDPI_PROTOCOL_MAIL_SMTPS));
-  }
-  inline bool isHTTP() const { return (isProto(NDPI_PROTOCOL_HTTP)); }
-  inline bool isHTTP_PROXY() const { return (isProto(NDPI_PROTOCOL_HTTP_PROXY)); }
+  inline bool isMDNS() const     { return (isProto(NDPI_PROTOCOL_MDNS));     }
+  inline bool isSSDP() const     { return (isProto(NDPI_PROTOCOL_SSDP));     }
+  inline bool isNetBIOS() const  { return (isProto(NDPI_PROTOCOL_NETBIOS));  }
+  inline bool isSIP() const      { return (isProto(NDPI_PROTOCOL_SIP));      }
+  inline bool isDHCP() const     { return (isProto(NDPI_PROTOCOL_DHCP));     }
+  inline bool isNTP() const      { return (isProto(NDPI_PROTOCOL_NTP));      }
+  inline bool isSMTPorSMTPS() const { return (isSMTP() || isSMTPS());        }
+  inline bool isSMTP() const        { return (isProto(NDPI_PROTOCOL_MAIL_SMTP));  }
+  inline bool isSMTPS() const       { return (isProto(NDPI_PROTOCOL_MAIL_SMTPS)); }
+  inline bool isHTTP() const        { return (isProto(NDPI_PROTOCOL_HTTP));       }
+  inline bool isHTTP_PROXY() const  { return (isProto(NDPI_PROTOCOL_HTTP_PROXY)); }
   inline bool isICMP() const {
     return (isProto(NDPI_PROTOCOL_IP_ICMP) || isProto(NDPI_PROTOCOL_IP_ICMPV6));
   }
-  inline bool isBittorrent() const {
-    return (isProto(NDPI_PROTOCOL_BITTORRENT));
-  }
+  inline bool isBittorrent() const { return (isProto(NDPI_PROTOCOL_BITTORRENT)); }
 
 #if defined(NTOPNG_PRO)
   inline bool isLateralMovement() const { return (lateral_movement); }
@@ -477,42 +492,33 @@ class Flow : public GenericHashEntry {
 #endif
 
   inline bool isCliDeviceAllowedProtocol() const {
-    return !cli_host ||
-           cli_host->getDeviceAllowedProtocolStatus(
-               get_detected_protocol(), true) == device_proto_allowed;
+    return !cli_host
+      || cli_host->getDeviceAllowedProtocolStatus(get_detected_protocol(), true) == device_proto_allowed;
   }
   inline bool isSrvDeviceAllowedProtocol() const {
     return !srv_host ||
-           get_bytes_srv2cli() ==
-               0 /* Server must respond to be considered NOT allowed */
-           || srv_host->getDeviceAllowedProtocolStatus(
-                  get_detected_protocol(), false) == device_proto_allowed;
+           get_bytes_srv2cli() == 0 /* Server must respond to be considered NOT allowed */
+           || srv_host->getDeviceAllowedProtocolStatus(get_detected_protocol(), false) == device_proto_allowed;
   }
   inline bool isDeviceAllowedProtocol() const {
     return isCliDeviceAllowedProtocol() && isSrvDeviceAllowedProtocol();
   }
   inline u_int16_t getCliDeviceDisallowedProtocol() const {
-    DeviceProtoStatus cli_ps =
-        cli_host->getDeviceAllowedProtocolStatus(get_detected_protocol(), true);
-    return (cli_ps == device_proto_forbidden_app)
-               ? ndpiDetectedProtocol.app_protocol
+    DeviceProtoStatus cli_ps = cli_host->getDeviceAllowedProtocolStatus(get_detected_protocol(), true);
+    
+    return (cli_ps == device_proto_forbidden_app) ? ndpiDetectedProtocol.app_protocol
                : ndpiDetectedProtocol.master_protocol;
   }
   inline u_int16_t getSrvDeviceDisallowedProtocol() const {
-    DeviceProtoStatus srv_ps = srv_host->getDeviceAllowedProtocolStatus(
-        get_detected_protocol(), false);
-    return (srv_ps == device_proto_forbidden_app)
-               ? ndpiDetectedProtocol.app_protocol
+    DeviceProtoStatus srv_ps = srv_host->getDeviceAllowedProtocolStatus(get_detected_protocol(), false);
+    
+    return (srv_ps == device_proto_forbidden_app) ? ndpiDetectedProtocol.app_protocol
                : ndpiDetectedProtocol.master_protocol;
   }
   inline bool isMaskedFlow() const {
-    return (Utils::maskHost(get_cli_ip_addr()->isLocalHost()) ||
-            Utils::maskHost(get_srv_ip_addr()->isLocalHost()));
+    return (Utils::maskHost(get_cli_ip_addr()->isLocalHost())
+            || Utils::maskHost(get_srv_ip_addr()->isLocalHost()));
   };
-  inline const char *getServerCipherClass() const {
-    return (isTLS() ? cipher_weakness2str(protos.tls.ja3.server_unsafe_cipher)
-                    : NULL);
-  }
   char *serialize(bool use_labels = false);
   /* Prepares an alert JSON and puts int in the resulting `serializer`. */
   void alert2JSON(FlowAlert *alert, ndpi_serializer *serializer);
@@ -534,15 +540,10 @@ class Flow : public GenericHashEntry {
     return (ndpi_get_lower_proto(ndpiDetectedProtocol));
   }
 
-  inline void updateJA3C(char *j) {
-    if (j && (j[0] != '\0') && (protos.tls.ja3.client_hash == NULL))
-      protos.tls.ja3.client_hash = strdup(j);
-    updateCliJA3();
-  }
-  inline void updateJA3S(char *j) {
-    if (j && (j[0] != '\0') && (protos.tls.ja3.server_hash == NULL))
-      protos.tls.ja3.server_hash = strdup(j);
-    updateSrvJA3();
+  inline void updateJA4C(char *j) {
+    if (j && (j[0] != '\0') && (protos.tls.ja4.client_hash == NULL))
+      protos.tls.ja4.client_hash = strdup(j);
+    updateCliJA4();
   }
 
   inline u_int8_t getTcpFlags() const {
@@ -568,7 +569,7 @@ class Flow : public GenericHashEntry {
   static double toMs(const struct timeval *t);
   void timeval_diff(struct timeval *begin, const struct timeval *end,
                     struct timeval *result, u_short divide_by_two);
-  char *getFlowInfo(char *buf, u_int buf_len, bool isLuaRequest);
+  std::string getFlowInfo(bool isLuaRequest);
   inline char *getFlowServerInfo() {
     return (isTLS() && protos.tls.client_requested_server_name)
                ? protos.tls.client_requested_server_name
@@ -612,10 +613,12 @@ class Flow : public GenericHashEntry {
   void processDNSPacket(const u_char *ip_packet, u_int16_t ip_len,
                         u_int64_t packet_time);
   void processIEC60870Packet(bool tx_direction, const u_char *payload,
-                             u_int16_t payload_len, struct timeval *packet_time);
+                             u_int16_t payload_len,
+			     const struct pcap_pkthdr *h);
 #ifdef NTOPNG_PRO
   void processModbusPacket(bool is_query, const u_char *payload,
-			   u_int16_t payload_len, struct timeval *packet_time);
+			   u_int16_t payload_len,
+			   const struct pcap_pkthdr *h);
 #endif
   void endProtocolDissection();
   inline void setCustomApp(custom_app_t ca) {
@@ -634,56 +637,76 @@ class Flow : public GenericHashEntry {
                     u_int out_bytes, u_int out_goodput_bytes,
                     u_int in_fragments, u_int out_fragments, time_t first_seen,
                     time_t last_seen);
+
+  void addPrePostNATIPv4(u_int32_t _src_ip_addr_pre_nat, 
+                          u_int32_t _dst_ip_addr_pre_nat,
+                          u_int32_t _src_ip_addr_post_nat, 
+                          u_int32_t _dst_ip_addr_post_nat);
+
+  void addPrePostNATPort(u_int32_t _src_port_pre_nat, 
+                          u_int32_t _dst_port_pre_nat,
+                          u_int32_t _src_port_post_nat, 
+                          u_int32_t _dst_port_post_nat);
   void check_swap();
 
   inline bool isThreeWayHandshakeOK() const { return (twh_ok ? true : false); };
   inline bool isDetectionCompleted() const {
     return (detection_completed ? true : false);
   };
+  
   inline bool isOneWay() const {
-    return (get_packets() &&
-            (!get_packets_cli2srv() || !get_packets_srv2cli()));
+    return (get_packets() && (!get_packets_cli2srv() || !get_packets_srv2cli()));
   };
+  
   inline bool isBidirectional() const {
     return (get_packets_cli2srv() && get_packets_srv2cli());
   };
+  
   inline bool isRemoteToRemote() const {
     return (cli_host && srv_host && !cli_host->isLocalHost() &&
             !srv_host->isLocalHost());
   };
+  
   inline bool isLocalToRemote() const {
-    return get_cli_ip_addr()->isLocalHost() &&
-           !get_srv_ip_addr()->isLocalHost();
+    return get_cli_ip_addr()->isLocalHost() && !get_srv_ip_addr()->isLocalHost();
   };
+  
   inline bool isRemoteToLocal() const {
-    return !get_cli_ip_addr()->isLocalHost() &&
-           get_srv_ip_addr()->isLocalHost();
+    return !get_cli_ip_addr()->isLocalHost() && get_srv_ip_addr()->isLocalHost();
   };
+  
   inline bool isLocalToLocal() const {
     return get_cli_ip_addr()->isLocalHost() && get_srv_ip_addr()->isLocalHost();
   };
+  
   inline bool isUnicast() const {
     return (cli_ip_addr && srv_ip_addr &&
             !cli_ip_addr->isBroadMulticastAddress() &&
             !srv_ip_addr->isBroadMulticastAddress());
   };
+  
   inline u_int32_t get_cli_ipv4() const {
     return (cli_host->get_ip()->get_ipv4());
   };
+  
   inline u_int32_t get_srv_ipv4() const {
     return (srv_host->get_ip()->get_ipv4());
   };
+  
   inline ndpi_protocol get_detected_protocol() const {
     return (isDetectionCompleted() ? ndpiDetectedProtocol
                                    : ndpiUnknownProtocol);
   };
+  
   inline struct ndpi_flow_struct *get_ndpi_flow() const { return (ndpiFlow); };
   inline const struct ndpi_in6_addr *get_cli_ipv6() const {
     return (cli_host->get_ip()->get_ipv6());
   };
+
   inline const struct ndpi_in6_addr *get_srv_ipv6() const {
     return (srv_host->get_ip()->get_ipv6());
   };
+
   inline u_int16_t get_cli_port() const { return (ntohs(cli_port)); };
   inline u_int16_t get_srv_port() const { return (ntohs(srv_port)); };
   inline u_int16_t get_vlan_id() const { return (vlanId); };
@@ -745,15 +768,9 @@ class Flow : public GenericHashEntry {
   bool get_partial_traffic_stats_view(PartializableFlowTrafficStats *delta,
                                       bool *first_partial);
   bool update_partial_traffic_stats_db_dump();
-  inline float get_pkts_thpt() const {
-    return (pkts_thpt_cli2srv + pkts_thpt_srv2cli);
-  };
-  inline float get_bytes_thpt() const {
-    return (bytes_thpt_cli2srv + bytes_thpt_srv2cli);
-  };
-  inline float get_goodput_bytes_thpt() const {
-    return (goodput_bytes_thpt_cli2srv + goodput_bytes_thpt_srv2cli);
-  };
+  inline float get_pkts_thpt() const { return (pkts_thpt);   };
+  inline float get_bytes_thpt() const { return (bytes_thpt); };
+inline float get_goodput_bytes_thpt() const { return (goodput_bytes_thpt); };
   inline float get_goodput_ratio() const {
     return ((float)(100 * get_goodput_bytes()) / ((float)get_bytes() + 1));
   };
@@ -763,9 +780,6 @@ class Flow : public GenericHashEntry {
   inline time_t get_partial_last_seen() const {
     return (last_db_dump.last_seen);
   };
-  inline u_int32_t get_duration() const {
-    return ((u_int32_t)(get_last_seen() - get_first_seen()));
-  };
   inline char *get_protocol_name() const {
     return (Utils::l4proto2name(protocol));
   };
@@ -799,8 +813,7 @@ class Flow : public GenericHashEntry {
                                : NDPI_PROTOCOL_UNKNOWN));
   };
   inline const char *get_protocol_breed_name() const {
-    return (ndpi_get_proto_breed_name(iface->get_ndpi_struct(),
-                                      get_protocol_breed()));
+    return (ndpi_get_proto_breed_name(get_protocol_breed()));
   };
   inline ndpi_protocol_category_t get_protocol_category() const {
     return (ndpi_get_proto_category(
@@ -873,7 +886,7 @@ class Flow : public GenericHashEntry {
   u_int32_t get_hash_entry_id() const;
 
   static char *printTCPflags(u_int8_t flags, char *const buf, u_int buf_len);
-  char *print(char *buf, u_int buf_len) const;
+  char *print(char *buf, u_int buf_len, bool full_report = true) const;
 
   u_int32_t key();
   static u_int32_t key(Host *cli, u_int16_t cli_port, Host *srv,
@@ -885,6 +898,7 @@ class Flow : public GenericHashEntry {
   void lua_duration_info(lua_State *vm);
   void lua_snmp_info(lua_State *vm);
   void lua_device_protocol_allowed_info(lua_State *vm);
+  void lua_get_flow_connection_state(lua_State *vm);
   void lua_get_tcp_stats(lua_State *vm) const;
 
   void lua_get_unicast_info(lua_State *vm) const;
@@ -899,6 +913,7 @@ class Flow : public GenericHashEntry {
   void lua_get_ip(lua_State *vm, bool client) const;
   void lua_get_mac(lua_State *vm, bool client) const;
   void lua_get_info(lua_State *vm, bool client) const;
+  void lua_get_sip_info(lua_State *vm) const;
   void lua_get_tls_info(lua_State *vm) const;
   void lua_get_ssh_info(lua_State *vm) const;
   void lua_get_http_info(lua_State *vm) const;
@@ -916,6 +931,7 @@ class Flow : public GenericHashEntry {
   void getTLSInfo(ndpi_serializer *serializer) const;
   void getMDNSInfo(ndpi_serializer *serializer) const;
   void getNetBiosInfo(ndpi_serializer *serializer) const;
+  void getSIPInfo(ndpi_serializer *serializer) const;
   void getSSHInfo(ndpi_serializer *serializer) const;
 
   bool equal(const Mac *src_mac, const Mac *dst_mac, const IpAddress *_cli_ip,
@@ -928,6 +944,9 @@ class Flow : public GenericHashEntry {
   bool match(AddressTree *ptree);
   bool matchFlowIP(IpAddress *ip, u_int16_t vlan_id);
   bool matchFlowVLAN(u_int16_t vlan_id);
+  bool matchFlowDeviceIP(u_int32_t flow_device_ip);
+  bool matchInIfIdx(u_int32_t in_if_idx);
+  bool matchOutIfIdx(u_int32_t out_if_idx);
   void dissectHTTP(bool src2dst_direction, char *payload,
                    u_int16_t payload_len);
   void dissectDNS(bool src2dst_direction, char *payload, u_int16_t payload_len);
@@ -938,6 +957,8 @@ class Flow : public GenericHashEntry {
   void dissectNetBIOS(u_int8_t *payload, u_int16_t payload_len);
   void dissectBittorrent(char *payload, u_int16_t payload_len);
   void fillZMQFlowCategory(ndpi_protocol *res);
+  void setDHCPHostName(const char* name);
+  void setSIPCallId(const char* name);
   inline void setICMP(bool src2dst_direction, u_int8_t icmp_type,
                       u_int8_t icmp_code, u_int8_t *icmpdata) {
     if (isICMP()) {
@@ -1114,6 +1135,9 @@ class Flow : public GenericHashEntry {
     return (!isTCPClosed() &&
             ((src2dst_tcp_flags & TH_RST) || (dst2src_tcp_flags & TH_RST)));
   };
+  inline bool isOnlyTCPReset() const {
+    return ((src2dst_tcp_flags & TH_RST) || (dst2src_tcp_flags & TH_RST));
+  }
   inline bool isTCPRefused() const {
     return (!isThreeWayHandshakeOK() && (dst2src_tcp_flags & TH_RST) == TH_RST);
   };
@@ -1295,6 +1319,14 @@ class Flow : public GenericHashEntry {
   u_char *getCommunityId(u_char *community_id, u_int community_id_len);
   void setJSONRiskInfo(char *r);
   char *getJSONRiskInfo();
+  void setEndReason(char *r);
+  char *getEndReason();
+  void setSMTPMailFrom(char *r);
+  char *getSMTPMailFrom();
+  void setSMTPRcptTo(char *r);
+  char *getSMTPRcptTo();
+  void setFlowRiskName(char *r);
+  char *getFlowRiskName();
   void getJSONRiskInfo(ndpi_serializer *serializer);
 
   inline FlowTrafficStats *getTrafficStats() { return (&stats); };
@@ -1317,19 +1349,24 @@ class Flow : public GenericHashEntry {
 
   inline ndpi_confidence_t getConfidence() { return (confidence); }
   inline void setConfidence(ndpi_confidence_t rc) { confidence = rc; }
+  inline void setNdpiConfidence(ndpi_confidence_t rc) { ndpi_confidence = rc; }
 
   inline u_int8_t getCliLocation() {
-    if (cli_host && cli_host->isMulticastHost())
+    if ((cli_host && cli_host->isMulticastHost()) ||
+        (cli_ip_addr && cli_ip_addr->isMulticastAddress()))
       return 2;  // Multicast host
-    else if (cli_host && cli_host->isLocalHost())
+    else if ((cli_host && cli_host->isLocalHost()) ||
+            (cli_ip_addr && cli_ip_addr->isLocalHost()))
       return 1;  // Local host
     else
       return 0;  // Remote host
   }
   inline u_int8_t getSrvLocation() {
-    if (srv_host && srv_host->isMulticastHost())
+    if ((srv_host && srv_host->isMulticastHost()) ||
+        (srv_ip_addr && srv_ip_addr->isMulticastAddress()))
       return 2;  // Multicast host
-    else if (srv_host && srv_host->isLocalHost())
+    else if ((srv_host && srv_host->isLocalHost()) ||
+            (srv_ip_addr && srv_ip_addr->isLocalHost()))
       return 1;  // Local host
     else
       return 0;  // Remote host
@@ -1354,6 +1391,26 @@ class Flow : public GenericHashEntry {
   void swap();
   bool isDPIDetectedFlow();
   void updateHostBlacklists();
+  int32_t getInterfaceIndex()      { return(iface_index); };
+  inline void setFlowSource(FlowSource n) { flow_source = n;     }
+  inline FlowSource getFlowSource()       { return(flow_source); }
+  inline MinorConnectionStates setCurrentConnectionState(u_int8_t new_state) { current_c_state = static_cast<MinorConnectionStates>(new_state); return(current_c_state);  };
+  inline MinorConnectionStates getCurrentConnectionState() { return(current_c_state); };
+  bool checkS1ConnState();
+  bool isTCPFlagSet(u_int8_t flags, int flag_to_check);
+  MinorConnectionStates calculateConnectionState(bool is_cumulative);
+  MajorConnectionStates getMajorConnState();
+  inline u_int32_t getPreNATSrcIp() { return ntohl(src_ip_addr_pre_nat); };
+  inline u_int32_t getPreNATDstIp() { return ntohl(dst_ip_addr_pre_nat); };
+  inline u_int32_t getPostNATSrcIp() { return ntohl(src_ip_addr_post_nat); };
+  inline u_int32_t getPostNATDstIp() { return ntohl(dst_ip_addr_post_nat); };
+  inline u_int16_t getPreNATSrcPort() { return ntohs(src_port_pre_nat); };
+  inline u_int16_t getPreNATDstPort() { return ntohs(dst_port_pre_nat); };
+  inline u_int16_t getPostNATSrcPort() { return ntohs(src_port_post_nat); };
+  inline u_int16_t getPostNATDstPort() { return ntohs(dst_port_post_nat); };
+  inline bool isFlowAccounted()        { return iface_flow_accounted; };
+  inline void setFlowAccounted()       { iface_flow_accounted = 1;    };
+  void accountFlowTraffic();
 };
 
 #endif /* _FLOW_H_ */
