@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,22 +27,20 @@
 class HostAlert;
 
 class Host : public GenericHashEntry,
-             public HostAlertableEntity,
              public Score,
-             public HostChecksStatus {
+             public HostChecksStatus,
+	     public HostAlertableEntity /* Eventually move to LocalHost */ {
  protected:
   IpAddress ip;
   Mac *mac;
   char *asname, *blacklist_name;
 
-  struct {
-    Fingerprint ja3;
-    Fingerprint hassh;
-  } fingerprints;
-
-  u_int16_t host_pool_id, host_services_bitmap;
+  int32_t iface_index; /* Interface index on which this host has been first observed */
+  u_int16_t host_services_bitmap;
   u_int16_t vlan_id;
   u_int16_t observationPointId;
+  u_int16_t host_pool_id;
+  u_int8_t host_pool_id_is_from_mac; /* pool id comes from a MAC match (bool) */
   u_int8_t num_remote_access;
   HostStats *stats, *stats_shadow;
   time_t last_stats_reset;
@@ -72,6 +70,7 @@ class Host : public GenericHashEntry,
     char *http;        /* The HTTP Host: name */
     char *server_name; /* TLS/HTTP or other protocols requesting the host with a
                           specific server name */
+    char *dhcp;  /* name from a DHCP reply */
   } names;
 
   char *ssdpLocation;
@@ -79,21 +78,7 @@ class Host : public GenericHashEntry,
   /* END Host data: */
 
   /* Counters used by host alerts */
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } syn_flood;
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } flow_flood;
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } icmp_flood;
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } dns_flood;
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } snmp_flood;
+  AttackVictimCounter syn_flood, flow_flood, icmp_flood, dns_flood, snmp_flood, rst_scan;
 
   struct {
     u_int32_t syn_sent_last_min, synack_recvd_last_min; /* (attacker) */
@@ -105,13 +90,8 @@ class Host : public GenericHashEntry,
     u_int32_t fin_recvd_last_min, finack_sent_last_min; /* (victim) */
   } fin_scan;
 
-  struct {
-    AlertCounter *attacker_counter, *victim_counter;
-  } rst_scan;
-
-  std::atomic<u_int32_t> num_active_flows_as_client,
-      num_active_flows_as_server; /* Need atomic as inc/dec done on different
-                                     threads */
+  /* Need atomic as inc/dec done on different threads */
+  std::atomic<u_int32_t> num_active_flows_as_client, num_active_flows_as_server;
   u_int32_t asn;
 
   struct {
@@ -153,7 +133,6 @@ class Host : public GenericHashEntry,
   u_int32_t mac_last_seen;
   u_int8_t num_resolve_attempts;
   time_t nextResolveAttempt;
-
   u_int32_t device_ip;
 
 #ifdef NTOPNG_PRO
@@ -176,7 +155,8 @@ class Host : public GenericHashEntry,
   ListeningPorts *listening_ports, *listening_ports_shadow;
 #endif
 
-  void initialize(Mac *_mac, u_int16_t _vlan_id,
+  void initialize(Mac *_mac, int32_t _iface_idx,
+		  u_int16_t _vlan_id,
                   u_int16_t observation_point_id);
   void inlineSetOS(OSType _os);
   bool statsResetRequested();
@@ -201,14 +181,17 @@ class Host : public GenericHashEntry,
   virtual void deferredInitialization();
 
  public:
-  Host(NetworkInterface *_iface, char *ipAddress, u_int16_t _u_int16_t,
+  Host(NetworkInterface *_iface, int32_t _iface_idx,
+       char *ipAddress, u_int16_t _vlan_id,
        u_int16_t observation_point_id);
-  Host(NetworkInterface *_iface, Mac *_mac, u_int16_t _u_int16_t,
+  Host(NetworkInterface *_iface, int32_t _iface_idx,
+       Mac *_mac, u_int16_t _vlan_id,
        u_int16_t observation_point_id, IpAddress *_ip);
 
   virtual ~Host();
 
   virtual bool isLocalHost() const { return (false); };
+  virtual void incResetFlow() const {};
   virtual bool isLocalUnicastHost() const { return (false); };
   virtual bool isSystemHost() const { return (false); };
   inline bool isBroadcastDomainHost() const {
@@ -307,6 +290,7 @@ class Host : public GenericHashEntry,
     return (ip.isBroadcastAddress() || (mac && mac->isBroadcast()));
   }
   bool isMulticastHost() const { return (ip.isMulticastAddress()); }
+  inline bool isUnicastHost() const { return (!isBroadcastHost() && !isMulticastHost()); };
 
   char *printMask(char *str, u_int str_len) {
     return ip.printMask(str, str_len, isLocalHost());
@@ -413,6 +397,7 @@ class Host : public GenericHashEntry,
   char *getMDNSTXTName(char *const buf, ssize_t buf_len);
   char *getMDNSInfo(char *const buf, ssize_t buf_len);
   char *getNetbiosName(char *const buf, ssize_t buf_len);
+  char *getDHCPName(char *const buf, ssize_t buf_len);
   char *getTLSName(char *const buf, ssize_t buf_len);
   char *getHTTPName(char *const buf, ssize_t buf_len);
 #ifdef HAVE_NEDGE
@@ -531,7 +516,7 @@ class Host : public GenericHashEntry,
   void lua_get_num_contacts(lua_State *vm);
   void lua_get_num_http_hosts(lua_State *vm);
   void lua_get_os(lua_State *vm);
-  void lua_get_fingerprints(lua_State *vm);
+  virtual void lua_get_fingerprints(lua_State *vm) { ; }
   void lua_get_geoloc(lua_State *vm);
   void lua_blacklisted_flows(lua_State *vm) const;
   void lua_unidirectional_tcp_udp_flows(lua_State *vm, bool as_subtable) const;
@@ -789,10 +774,11 @@ class Host : public GenericHashEntry,
   void offlineSetMDNSInfo(char *const s);
   void offlineSetMDNSName(const char *n);
   void offlineSetMDNSTXTName(const char *n);
+  void offlineSetDHCPName(const char *n);
   void setServerName(const char *n);
   void setResolvedName(const char *resolved_name);
-  inline Fingerprint *getJA3Fingerprint() { return (&fingerprints.ja3); }
-  inline Fingerprint *getHASSHFingerprint() { return (&fingerprints.hassh); }
+  virtual Fingerprint *getJA4Fingerprint()   { return (NULL); }
+  virtual Fingerprint *getHASSHFingerprint() { return (NULL); }
 
   void setPrefsChanged() { prefs_loaded = 0; }
   virtual void reloadPrefs() {}
@@ -922,7 +908,7 @@ class Host : public GenericHashEntry,
   inline void blacklistHost(char *blacklist_name) { setBlacklistName(blacklist_name); }
   inline char* getBlacklistName()                 { return(blacklist_name);           }
   
-  virtual void setRxOnlyHost(bool set_it) { is_rx_only = set_it; };
+  virtual void toggleRxOnlyHost(bool rx_only);
   inline bool resetHostTopSites() {
     if (stats) {
       stats->resetTopSitesData();
@@ -931,7 +917,7 @@ class Host : public GenericHashEntry,
       return (false);
   }
   inline bool isRxOnlyHost() {
-    return (is_rx_only && (!isBroadcastHost()) && (!isMulticastHost()));
+    return (is_rx_only && isUnicastHost());
   }
   inline void incUnidirectionalIngressTCPUDPFlows() {
     unidirectionalTCPUDPFlows.numIngressFlows++;
@@ -940,7 +926,7 @@ class Host : public GenericHashEntry,
     unidirectionalTCPUDPFlows.numEgressFlows++;
   }
 
-  virtual void setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto) {
+  virtual void setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto, time_t when) {
     ;
   };
   virtual void setContactedPort(bool isTCP, u_int16_t port,
@@ -948,8 +934,7 @@ class Host : public GenericHashEntry,
     ;
   };
   virtual void luaUsedPorts(lua_State *vm) { ; }
-  virtual std::unordered_map<u_int16_t, ndpi_protocol> *getServerPorts(
-      bool isTCP) {
+  virtual std::unordered_map<u_int16_t, ndpi_protocol> *getServerPorts(bool isTCP) {
     return (NULL);
   }
 
@@ -959,9 +944,8 @@ class Host : public GenericHashEntry,
   }
   inline bool isCustomHostScriptAlreadyEvaluated(time_t when) {
     return ((customHostAlert.hostAlreadyEvaluated &&
-             (customHostAlert.skip_until_epoch < when))
-                ? true
-                : false);
+             (customHostAlert.skip_until_epoch <  (u_int32_t)when))
+                ? true : false);
   }
   inline bool isCustomHostScriptFirstRun() {
     return (customHostAlert.checkAlreadyExecutedOnce ? false : true);
@@ -980,19 +964,11 @@ class Host : public GenericHashEntry,
   void setUnidirectionalTCPUDPNoTXEgressFlow(IpAddress *ip, u_int16_t port);
   void setUnidirectionalTCPUDPNoTXIngressFlow(IpAddress *ip, u_int16_t port);
 
-  inline u_int32_t getNumContactedPeersAsClientTCPUDPNoTX() {
-    return (
-        (u_int32_t)ndpi_hll_count(&outgoing_hosts_tcp_udp_port_with_no_tx_hll));
-  };
-  inline u_int32_t getNumContactsFromPeersAsServerTCPUDPNoTX() {
-    return (
-        (u_int32_t)ndpi_hll_count(&incoming_hosts_tcp_udp_port_with_no_tx_hll));
-  };
+  u_int32_t getNumContactedPeersAsClientTCPUDPNoTX();
+  u_int32_t getNumContactsFromPeersAsServerTCPUDPNoTX();
 
   inline u_int16_t getNumContactedTCPUDPServerPortsNoTX() {
-    return (tcp_udp_contacted_ports_no_tx ? (u_int16_t)ndpi_bitmap_cardinality(
-                                                tcp_udp_contacted_ports_no_tx)
-                                          : 0);
+    return (tcp_udp_contacted_ports_no_tx ? (u_int16_t)ndpi_bitmap_cardinality(tcp_udp_contacted_ports_no_tx) : 0);
   }
   inline void setContactedTCPUDPServerPortNoTX(u_int16_t port) {
     if (tcp_udp_contacted_ports_no_tx)
@@ -1000,6 +976,10 @@ class Host : public GenericHashEntry,
   }
 
   void resetHostContacts();
+  inline int32_t getInterfaceIndex()            { return(iface_index); };
+
+  virtual SPSCQueue<std::pair<u_int16_t, u_int16_t>> *getContactedServerPorts() { return (NULL);};
+  virtual char *getSerializationKey(char *buf, uint bufsize) { return (NULL); };
 };
 
 #endif /* _HOST_H_ */
