@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -90,7 +90,8 @@ class HostStats : public GenericTrafficElement {
   };
 
   virtual void computeAnomalyIndex(time_t when){};
-
+  virtual u_int32_t getResetFlow() { return(0); };
+  virtual void incResetFlow() {};
   inline Host *getHost() const { return (host); }
   inline void incNumAlertedFlows(bool as_client) {
     if (as_client)
