@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -60,10 +60,10 @@ class IEC104Stats {
   ~IEC104Stats();
 
   void processPacket(Flow *f, bool tx_direction, const u_char *payload,
-                     u_int16_t payload_len, struct timeval *packet_time);
+                     u_int16_t payload_len, const struct pcap_pkthdr *h);
 
   void lua(lua_State *vm);
-  char *getFlowInfo(char *buf, u_int buf_len);
+  std::string getFlowInfo();
 };
 
 #endif /* _IEC104_STATS_H_ */
