@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,12 +36,14 @@ class InterfaceMemberAlertableEntity : public OtherAlertableEntity {
 
   ~InterfaceMemberAlertableEntity() {
     /* Decrease interface number of engaged alerts on the interface */
-    std::map<std::string, Alert>::const_iterator alert_it;
+    std::map<u_int32_t /* std::string */, Alert>::const_iterator alert_it;
+
     engaged_alerts_lock.wrlock(__FILE__, __LINE__);
+
     for (u_int p = 0; p < MAX_NUM_PERIODIC_SCRIPTS; p++)
-      for (alert_it = engaged_alerts[p].begin();
-           alert_it != engaged_alerts[p].end(); ++alert_it)
+      for (alert_it = engaged_alerts[p].begin(); alert_it != engaged_alerts[p].end(); ++alert_it)
         decNumAlertsEngaged(Utils::mapScoreToSeverity(alert_it->second.score));
+    
     engaged_alerts_lock.unlock(__FILE__, __LINE__);
   };
 };
