@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,8 +49,12 @@ class Mac : public GenericHashEntry {
 #ifdef NTOPNG_PRO
   time_t captive_portal_notified;
 #endif
+
   /* END Mac data: */
 
+#ifdef NTOPNG_PRO
+  void dumpAssetInfo();
+#endif
   void checkDeviceTypeFromManufacturer();
   void readDHCPCache();
   void freeMacData();
@@ -58,7 +62,7 @@ class Mac : public GenericHashEntry {
   bool statsResetRequested();
   void checkStatsReset();
   void dumpToRedis();
-  
+
  public:
   Mac(NetworkInterface *_iface, u_int8_t _mac[6]);
   ~Mac();
@@ -126,6 +130,7 @@ class Mac : public GenericHashEntry {
   }
   inline DeviceType getDeviceType() { return (device_type); }
   char *getDHCPName(char *const buf, ssize_t buf_size);
+  char *getDHCPNameNotLowerCase(char *const buf, ssize_t buf_size);
   void set_hash_entry_state_idle();
   void lua(lua_State *vm, bool show_details, bool asListElement);
   virtual char *get_string_key(char *buf, u_int buf_len) const {
