@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@ class NetworkDiscovery {
   lua_State *mdns_vm;
   Mutex m;
   struct bpf_program fcode;
-  bool has_bpf_filter;
+  bool debug_mode;
 
   u_int32_t wrapsum(u_int32_t sum);
   u_int16_t in_cksum(u_int8_t *buf, u_int16_t buf_len, u_int32_t sum);
