@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -152,31 +152,19 @@ protected:
     Flow JSON contain additional fields not placed inside database columns.
   */
   bool flows_dump_json;
-  /*
-    Flag to indicate whether JSON labels should be used for flow fields inside
-    the dumped flow JSON. If this flag is false, flow fields are keyed with
-    nProbe integer flow keys.
-  */
-  bool flows_dump_json_use_labels;
-
-  /* Queue containing the ip@vlan strings of the hosts to restore. */
-  StringFifoQueue *hosts_to_restore;
 
   /* External alerts contain alertable entities other than
    * host/interface/network which are dynamically allocated when an alert for
    * them occurs. A lock is necessary to guard the insert/delete operations from
    * lookup operations requested from the GUI and to ensure that a delete
    * operation does generate a use-after-free. */
-  std::map<std::pair<AlertEntity, std::string>,
-           InterfaceMemberAlertableEntity *>
-  external_alerts;
+  std::map<std::pair<AlertEntity, std::string>, InterfaceMemberAlertableEntity *> external_alerts;
   Mutex external_alerts_lock;
 
   RoundTripStats *download_stats, *upload_stats;
 
   bool is_view; /* Whether this is a view interface */
-  ViewInterface
-  *viewed_by; /* Whether this interface is 'viewed' by a ViewInterface */
+  ViewInterface *viewed_by; /* Whether this interface is 'viewed' by a ViewInterface */
   u_int8_t viewed_interface_id; /* When this is a 'viewed' interface, this id
                                    represents a unique interface identifier
                                    inside the view */
@@ -204,8 +192,8 @@ protected:
   /* Live Capture */
   Mutex active_captures_lock;
   u_int8_t num_live_captures;
-  struct ntopngLuaContext *live_captures[MAX_NUM_PCAP_CAPTURES];
-  static bool matchLiveCapture(struct ntopngLuaContext *const luactx,
+  NtopngLuaContext *live_captures[MAX_NUM_PCAP_CAPTURES];
+  static bool matchLiveCapture(NtopngLuaContext *const luactx,
                                const struct pcap_pkthdr *const h,
                                const u_char *const packet, Flow *const f);
   void deliverLiveCapture(const struct pcap_pkthdr *const h,
@@ -227,12 +215,10 @@ protected:
   NetworkInterface *dynamic_interface_master; /* Main interface */
 
   bool is_traffic_mirrored, is_loopback;
-  bool discard_probing_traffic;
   bool flows_only_interface; /* Only allocates flows for the interface (e.g., no
                                 hosts, ases, etc) */
   bool is_smart_recording_enabled;
   char *smart_recording_instance_name;
-  ProtoStats discardedProbingStats;
 #ifdef NTOPNG_PRO
   L7Policer *policer;
 
@@ -263,21 +249,23 @@ protected:
   bool pollLoopCreated, flowDumpLoopCreated, flowAlertsDequeueLoopCreated,
     hostAlertsDequeueLoopCreated;
   bool has_too_many_hosts, has_too_many_flows, mtuWarningShown;
-  bool flow_dump_disabled;
-  u_int32_t ifSpeed, numL2Devices, totalNumHosts,
-    numTotalRxOnlyHosts /* subset of numTotalRxOnlyHosts that have received
+  bool flow_dump_disabled_by_user, flow_dump_disabled_by_backend;
+  u_int32_t ifSpeed, scalingFactor;
+  u_int32_t numL2Devices;
+  std::atomic<u_int64_t> totalNumHosts;
+  std::atomic<u_int64_t> numTotalRxOnlyHosts; /* subset of numTotalRxOnlyHosts that have received
 			   but never sent any traffic */
-    ,
-    numLocalHosts,
-    numLocalRxOnlyHosts /* subset of numLocalHosts that have received but
+  std::atomic<u_int64_t> numLocalHosts;
+  std::atomic<u_int64_t> numLocalRxOnlyHosts; /* subset of numLocalHosts that have received but
 			   never sent any traffic */
-    ,
-    scalingFactor;
   /* Those will hold counters at checkpoints */
   u_int64_t checkpointPktCount, checkpointBytesCount, checkpointPktDropCount,
     checkpointDroppedAlertsCount;
-  u_int64_t checkpointDiscardedProbingPktCount,
-    checkpointDiscardedProbingBytesCount;
+  u_int64_t 
+    checkpointTrafficSent, 
+    checkpointTrafficRcvd,
+    checkpointPacketsSent,
+    checkpointPacketsRcvd;
   u_int16_t ifMTU;
   int cpu_affinity; /**< Index of physical core where the network interface
                        works. */
@@ -295,25 +283,21 @@ protected:
   ThroughputStats bytes_thpt, pkts_thpt;
   struct timeval last_periodic_stats_update;
 
-  MacHash
-  *gw_macs; /**< Hash used to identify traffic direction based on gw MAC. */
+  MacHash *gw_macs; /**< Hash used to identify traffic direction based on gw MAC. */
   bool gw_macs_reload_requested;
 
   /* Mac */
   MacHash *macs_hash; /**< Hash used to store MAC information. */
 
   /* Autonomous Systems */
-  AutonomousSystemHash
-  *ases_hash; /**< Hash used to store Autonomous Systems information. */
+  AutonomousSystemHash *ases_hash; /**< Hash used to store Autonomous Systems information. */
 
   /* Observation Point */
   u_int16_t last_obs_point_id;
-  ObservationPointHash
-  *obs_hash; /**< Hash used to store Observation Point information. */
+  ObservationPointHash *obs_hash; /**< Hash used to store Observation Point information. */
 
   /* Operating Systems */
-  OperatingSystemHash
-  *oses_hash; /**< Hash used to store Operating Systems information. */
+  OperatingSystemHash *oses_hash; /**< Hash used to store Operating Systems information. */
 
   /* Countries */
   CountriesHash *countries_hash;
@@ -335,7 +319,7 @@ protected:
     last_pkt_rcvd_remote, /* Meaningful only for ZMQ interfaces */
     next_idle_flow_purge, next_idle_host_purge, next_idle_other_purge;
   bool running, shutting_down, is_idle;
-  NetworkStats **networkStats;
+  NetworkStats **networkStats; /* One stats entry per network defined (-m) */
   InterfaceStatsHash *interfaceStats;
   dhcp_range *dhcp_ranges, *dhcp_ranges_shadow;
 
@@ -345,7 +329,7 @@ protected:
   void deleteDataStructures();
 
   NetworkInterface *getDynInterface(u_int64_t criteria, bool parser_interface);
-  Flow *getFlow(Mac *srcMac, Mac *dstMac, u_int16_t vlan_id,
+  Flow* getFlow(int32_t if_index, Mac *srcMac, Mac *dstMac, u_int16_t vlan_id,
                 u_int16_t observation_domain_id, u_int32_t private_flow_id,
                 u_int32_t deviceIP, u_int32_t inIndex, u_int32_t outIndex,
                 const ICMPinfo *const icmp_info, IpAddress *src_ip,
@@ -416,9 +400,7 @@ protected:
 #ifdef NTOPNG_PRO
   void checkDHCPStorm(time_t when, u_int32_t num_pkts);
 #endif
-  void vlan_ports_lua_response(lua_State *vm, 
-      HostsPorts *count);
-  void sort_ports(lua_State *vm,
+  void lua_push_ports(lua_State *vm,
 		  HostsPorts *count,
 		  u_int16_t protocol);
   void sort_hosts_details(lua_State *vm,
@@ -490,6 +472,7 @@ public:
   inline AddressTree *getInterfaceNetworks() { return (&interface_networks); };
   virtual void startPacketPolling();
   virtual void startFlowDumping();
+  virtual bool isLoading() { return false; };
   virtual void shutdown();
   virtual void cleanup();
   virtual char *getEndpoint(u_int8_t id) { return NULL; };
@@ -557,8 +540,7 @@ public:
     return (ndpi_get_category_id(get_ndpi_struct(), cat));
   };
   inline char *get_ndpi_proto_breed_name(u_int id) {
-    return (ndpi_get_proto_breed_name(
-				      get_ndpi_struct(), ndpi_get_proto_breed(get_ndpi_struct(), id)));
+    return (ndpi_get_proto_breed_name(ndpi_get_proto_breed(get_ndpi_struct(), id)));
   };
   inline char *get_ndpi_full_proto_name(ndpi_protocol protocol, char *buf,
                                         u_int buf_len) const {
@@ -620,8 +602,10 @@ public:
   virtual u_int64_t getCheckPointDroppedAlerts();
   virtual u_int64_t getCheckPointNumBytes();
   virtual u_int32_t getCheckPointNumPacketDrops();
-  virtual u_int64_t getCheckPointNumDiscardedProbingPackets() const;
-  virtual u_int64_t getCheckPointNumDiscardedProbingBytes() const;
+  virtual u_int64_t getCheckPointNumTrafficSent() const;
+  virtual u_int64_t getCheckPointNumTrafficRcvd() const;
+  virtual u_int64_t getCheckPointNumPacketsSent() const;
+  virtual u_int64_t getCheckPointNumPacketsRcvd() const;
   inline void incFlagStats(u_int8_t flags, bool cumulative_flags) {
     pktStats.incFlagStats(flags, cumulative_flags);
   };
@@ -633,13 +617,10 @@ public:
     /* NOTE: nEdge does the incs in NetfilterInterface::incStatsConntrack, keep
      * it in sync! */
 #ifndef HAVE_NEDGE
-    incEthStats(ingressPacket, eth_proto, num_pkts, pkt_len,
-                getPacketOverhead());
-    ndpiStats->incStats(when, ndpi_proto, 0, 0, num_pkts, pkt_len);
-    // Note: here we are not currently interested in packet direction, so we
-    // tell it is receive
-    ndpiStats->incCategoryStats(when, ndpi_category, 0 /* see above comment */,
-                                pkt_len);
+    incEthStats(ingressPacket, eth_proto, num_pkts, pkt_len, getPacketOverhead());
+
+    // incnDPIStats(when, ndpi_proto, ndpi_category, pkt_len, num_pkts);
+    
     pktStats.incStats(1, pkt_len);
     l4Stats.incStats(when, l4proto, ingressPacket ? num_pkts : 0,
                      ingressPacket ? pkt_len : 0, !ingressPacket ? num_pkts : 0,
@@ -664,6 +645,7 @@ public:
                             bool localreceiver) {
     localStats.incStats(num_pkts, pkt_len, localsender, localreceiver);
   };
+  
   inline void incnDPIFlows(u_int16_t l7_protocol) {
     ndpiStats->incFlowsStats(l7_protocol);
   }
@@ -677,12 +659,11 @@ public:
   virtual void sumStats(TcpFlowStats *_tcpFlowStats, EthStats *_ethStats,
                         LocalTrafficStats *_localStats, nDPIStats *_ndpiStats,
                         PacketStats *_pktStats, TcpPacketStats *_tcpPacketStats,
-                        ProtoStats *_discardedProbingStats,
                         DSCPStats *_dscpStats, SyslogStats *_syslogStats,
                         RoundTripStats *_downloadStats,
                         RoundTripStats *_uploadStats) const;
   inline DB *getDB() const { return db; };
-  inline EthStats *getStats() { return (&ethStats); };
+  inline EthStats* getStats() { return (&ethStats); };
   inline int get_datalink() { return (pcap_datalink_type); };
   inline void set_datalink(int l) { pcap_datalink_type = l; };
   bool isStartingUp() const;
@@ -695,7 +676,6 @@ public:
     return show_dynamic_interface_traffic;
   };
   inline bool pushHostFilters() const { return push_host_filters; };
-  inline bool discardProbingTraffic() const { return discard_probing_traffic; };
   inline bool flowsOnlyInterface() const { return flows_only_interface; };
   void updateTrafficMirrored();
   void updateSmartRecording();
@@ -703,13 +683,11 @@ public:
   void updatePushFiltersSettings();
   void updateFlowDumpDisabled();
   void updateLbdIdentifier();
-  void updateDiscardProbingTraffic();
   void updateFlowsOnlyInterface();
-  bool restoreHost(char *host_ip, u_int16_t vlan_id);
-  void checkHostsToRestore();
   u_int printAvailableInterfaces(bool printHelp, int idx, char *ifname,
                                  u_int ifname_len);
-  void findFlowHosts(u_int16_t vlan_id, u_int16_t observation_domain_id,
+  void findFlowHosts(int32_t _iface_idx, u_int16_t vlan_id,
+		     u_int16_t observation_domain_id,
                      u_int32_t private_flow_id, Mac *src_mac,
                      IpAddress *_src_ip, Host **src, Mac *dst_mac,
                      IpAddress *_dst_ip, Host **dst);
@@ -726,12 +704,13 @@ public:
   bool findHostsByMac(lua_State *vm, u_int8_t *mac);
   Host *findHostByMac(u_int8_t *mac);
 
-  bool dissectPacket(
-		     u_int32_t bridge_iface_idx, bool ingressPacket,
+  bool dissectPacket(int32_t iface_index, u_int32_t bridge_iface_idx,
+		     int datalink_type, bool ingressPacket,
 		     u_int8_t *sender_mac, /* Non NULL only for NFQUEUE interfaces */
 		     const struct pcap_pkthdr *h, const u_char *packet,
 		     u_int16_t *ndpiProtocol, Host **srcHost, Host **dstHost, Flow **flow);
-  bool processPacket(u_int32_t bridge_iface_idx, bool ingressPacket,
+  bool processPacket(int32_t if_index, u_int32_t bridge_iface_idx,
+		     int datalink_type, bool *ingressPacket /* in/out */,
                      const struct bpf_timeval *when, const u_int64_t time,
                      struct ndpi_ethhdr *eth, u_int16_t vlan_id,
                      struct ndpi_iphdr *iph, struct ndpi_ipv6hdr *ip6,
@@ -751,7 +730,8 @@ public:
   struct timeval periodicUpdateInitTime() const;
   virtual u_int32_t getFlowMaxIdle();
 
-  virtual void lua(lua_State *vm);
+  virtual void lua(lua_State *vm, bool fullStats);
+  virtual void probeLuaStats(lua_State *vm) { };
   void luaScore(lua_State *vm);
   void luaAlertedFlows(lua_State *vm);
   void luaAnomalies(lua_State *vm);
@@ -797,7 +777,7 @@ public:
 			 bool blacklisted_hosts, u_int8_t ipver_filter, int proto_filter,
 			 TrafficType traffic_type_filter, u_int32_t device_ip, bool tsLua,
 			 bool anomalousOnly, bool dhcpOnly, const AddressTree *const cidr_filter,
-			 char *sortColumn, u_int32_t maxHits, u_int32_t toSkip, bool a2zSortOrder);
+			 char *sortColumn, u_int32_t maxHits, u_int32_t toSkip, bool a2zSortOrder, bool useArrayFormat);
   int getActiveASList(lua_State *vm, const Paginator *p, bool diff = false);
   int getActiveObsPointsList(lua_State *vm, const Paginator *p);
   int getActiveOSList(lua_State *vm, const Paginator *p);
@@ -848,8 +828,6 @@ public:
   virtual u_int32_t getNumDroppedPackets() { return 0; };
   virtual u_int getNumPacketDrops();
   virtual u_int64_t getNumNewFlows();
-  virtual u_int64_t getNumDiscardedProbingPackets() const;
-  virtual u_int64_t getNumDiscardedProbingBytes() const;
   virtual u_int getNumFlows();
   inline u_int getNumL2Devices() { return (numL2Devices); };
   inline u_int getNumHosts() { return (totalNumHosts); };
@@ -872,16 +850,8 @@ public:
   inline u_int64_t getNumDroppedAlertsSinceReset() {
     return getNumDroppedAlerts() - getCheckPointDroppedAlerts();
   }
-  inline u_int64_t getNumDiscProbingPktsSinceReset() const {
-    return getNumDiscardedProbingPackets() -
-      getCheckPointNumDiscardedProbingPackets();
-  };
-  inline u_int64_t getNumDiscProbingBytesSinceReset() const {
-    return getNumDiscardedProbingBytes() -
-      getCheckPointNumDiscardedProbingBytes();
-  }
 
-  virtual void runHousekeepingTasks();
+  void runPeriodicHousekeepingTasks();
   void runShutdownTasks();
   VLAN *getVLAN(u_int16_t u_int16_t, bool create_if_not_present,
                 bool is_inline_call);
@@ -914,7 +884,7 @@ public:
   inline void setIdleState(bool new_state) { is_idle = new_state; };
   inline StatsManager *getStatsManager() { return statsManager; };
   AlertsQueue *getAlertsQueue() const;
-  bool alert_store_query(lua_State *vm, const char *sql);
+  bool alert_store_query(lua_State *vm, const char *sql, bool limit_rows);
 
   void listHTTPHosts(lua_State *vm, char *key);
 #ifdef NTOPNG_PRO
@@ -930,8 +900,8 @@ public:
     if (host_pools) host_pools->reloadPools();
   }
 
-  bool registerLiveCapture(struct ntopngLuaContext *const luactx, int *id);
-  bool deregisterLiveCapture(struct ntopngLuaContext *const luactx);
+  bool registerLiveCapture(NtopngLuaContext *const luactx, int *id);
+  bool deregisterLiveCapture(NtopngLuaContext *const luactx);
   void dumpLiveCaptures(lua_State *vm);
   bool stopLiveCapture(int capture_id);
 #ifdef NTOPNG_PRO
@@ -945,8 +915,8 @@ public:
     if (host_pools) host_pools->luaStats(vm);
   };
   void refreshHostPools();
-  inline u_int16_t getHostPool(Host *h) {
-    if (h && host_pools) return host_pools->getPool(h);
+  inline u_int16_t getHostPool(Host *h, bool *mac_match) {
+    if (h && host_pools) return host_pools->getPool(h, mac_match);
     return NO_HOST_POOL_ID;
   };
   inline u_int16_t getHostPool(Mac *m) {
@@ -990,7 +960,7 @@ public:
                      struct mg_connection *conn);
 
   NetworkStats *getNetworkStats(u_int16_t networkId) const;
-  void allocateStructures();
+  void allocateStructures(bool disable_dump = false);
   void getsDPIStats(lua_State *vm);
   inline bool isDbCreated() { return (db ? db->isDbCreated() : true); };
 #ifdef NTOPNG_PRO
@@ -1024,17 +994,29 @@ public:
   void updateBehaviorStats(const struct timeval *tv);
 
   virtual void getFlowDevices(lua_State *vm);
-  virtual void getFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP) {
-    if (flow_interfaces_stats)
-      flow_interfaces_stats->luaDeviceInfo(vm, deviceIP, this);
-    else
+  virtual void getFlowDeviceInfo(lua_State *vm, u_int32_t deviceID, bool showAllStats = true) {
+    if (flow_interfaces_stats) {
       lua_newtable(vm);
+      flow_interfaces_stats->luaDeviceInfo(vm, deviceID, this, showAllStats);
+      lua_pushinteger(vm, get_id());
+      lua_insert(vm, -2);
+      lua_settable(vm, -3);
+    }
+  };  
+  virtual void getFlowDeviceInfoByIP(lua_State *vm, u_int32_t deviceIP, bool showAllStats = true) {
+    if (flow_interfaces_stats) {
+      lua_newtable(vm);
+      flow_interfaces_stats->luaDeviceInfoByIP(vm, deviceIP, this, showAllStats);
+      lua_pushinteger(vm, get_id());
+      lua_insert(vm, -2);
+      lua_settable(vm, -3);
+    }
   };
 #endif
-  virtual void getSFlowDevices(lua_State *vm);
-  virtual void getSFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP) {
+  virtual void getSFlowDevices(lua_State *vm, bool add_table);
+  virtual void getSFlowDeviceInfo(lua_State *vm, u_int32_t deviceID) {
     if (interfaceStats)
-      interfaceStats->luaDeviceInfo(vm, deviceIP);
+      interfaceStats->luaDeviceInfo(vm, deviceID);
     else
       lua_newtable(vm);
   };
@@ -1151,6 +1133,7 @@ public:
     return (memcmp(a, ifMac, sizeof(ifMac)) == 0);
   }
 
+  virtual bool read_from_stdin() const { return (false); };
   virtual bool read_from_pcap_dump() const { return (false); };
   virtual bool read_from_pcap_dump_done() const { return (false); };
   virtual void set_read_from_pcap_dump_done() { ; };
@@ -1168,7 +1151,8 @@ public:
   inline bool hasConfiguredDhcpRanges() {
     return (dhcp_ranges && !dhcp_ranges->last_ip.isEmpty());
   };
-  inline bool isFlowDumpDisabled() { return (flow_dump_disabled); }
+  inline bool isFlowDumpDisabled() { return (flow_dump_disabled_by_user || 
+    flow_dump_disabled_by_backend); }
   bool isInDhcpRange(IpAddress *ip);
   void getPodsStats(lua_State *vm);
   void getContainersStats(lua_State *vm, const char *pod_filter);
@@ -1278,24 +1262,20 @@ public:
     return (ndpi_get_proto_category(get_ndpi_struct(), proto));
   };
   ndpi_protocol_category_t get_ndpi_proto_category(u_int16_t protoid);
-  void setnDPIProtocolCategory(u_int16_t protoId,
+  void setnDPIProtocolCategory(struct ndpi_detection_module_struct *ndpi_str,
+			       u_int16_t protoId,
                                ndpi_protocol_category_t protoCategory);
-  bool nDPILoadIPCategory(char *what, ndpi_protocol_category_t id,
-                          char *list_name);
-  bool nDPILoadHostnameCategory(char *what, ndpi_protocol_category_t id,
-                                char *list_name);
+  bool nDPILoadIPCategory(char *what, u_int16_t id, char *list_name);
+  bool nDPILoadHostnameCategory(char *what, u_int16_t id, char *list_name);
   int nDPILoadMaliciousJA3Signatures(const char *file_path);
-
+  int setDomainMask(const char *domain, u_int64_t domain_mask);
+  int addTrustedIssuerDN(const char *dn);
   inline void setLastInterfacenDPIReload(time_t now) { last_ndpi_reload = now; }
   inline bool needsnDPICleanup() { return (ndpi_cleanup_needed); }
   inline void setnDPICleanupNeeded(bool needed) {
     ndpi_cleanup_needed = needed;
   }
   u_int16_t getnDPIProtoByName(const char *name);
-  inline void decNumSentRcvdHosts(bool isLocal) {
-    if (isLocal) numLocalRxOnlyHosts--;
-    numTotalRxOnlyHosts--;
-  }
   inline u_int32_t getNewFlowSerial() { return (flow_serial++); }
   bool resetHostTopSites(AddressTree *allowed_hosts, char *host_ip,
                          u_int16_t vlan_id, u_int16_t observationPointId);
@@ -1330,7 +1310,6 @@ public:
   };
   void luaUsedPorts(lua_State *vm) { usedPorts.lua(vm, this); };
 
-  void getVLANHostsPorts(lua_State *vm);
   void getHostsPorts(lua_State *vm);
   void getHostsByPort(lua_State *vm);
   void getHostsByService(lua_State *vm);
@@ -1348,6 +1327,9 @@ public:
   static bool compute_client_server_srv_port_flow_stats(GenericHashEntry *node,
           void *user_data,
           bool *matched);
+  static bool compute_client_server_srv_port_app_proto_flow_stats(GenericHashEntry *node,
+          void *user_data,
+          bool *matched);
   static bool get_host_ports(GenericHashEntry *node,
 				 void *user_data,
 				 bool *matched);
@@ -1357,9 +1339,6 @@ public:
   static bool get_hosts_by_service(GenericHashEntry *node,
 				   void *user_data,
 				   bool *matched);
-  static bool get_vlan_host_ports(GenericHashEntry *node,
-				   void *user_data,
-				   bool *matched);
 
 #ifdef NTOPNG_PRO
   static bool compute_client_server_flow_stats(GenericHashEntry *node,
@@ -1371,6 +1350,10 @@ public:
                                       bool *matched);
 #endif
   void getActiveMacs(lua_State *vm);
+
+  void incnDPIStats(time_t when, u_int16_t ndpi_proto,
+		    ndpi_protocol_category_t ndpi_category,
+		    u_int32_t bytes_len, u_int32_t num_pkts);
 };
 
 #endif /* _NETWORK_INTERFACE_H_ */
