@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -41,10 +41,6 @@ class Ntop {
 #ifndef WIN32
   int startupLockFile;
 #endif
-  pthread_t purgeLoop;    /* Loop which iterates on active interfaces to delete
-                             idle hash table entries */
-  bool purgeLoop_started; /* Flag that indicates whether the purgeLoop has been
-                             started */
   bool flowChecksReloadInProgress, hostChecksReloadInProgress;
   bool hostPoolsReloadInProgress;
   bool interfacesShuttedDown;
@@ -63,12 +59,13 @@ class Ntop {
   NetworkInterface *old_iface_to_purge;
   u_int8_t num_defined_interfaces; /**< Number of defined interfaces. */
   u_int8_t num_dump_interfaces;
+  std::atomic<u_int16_t> num_active_lua_vms;
   HTTPserver *httpd;    /**< Pointer of httpd server. */
   NtopGlobals *globals; /**< Pointer of Ntop globals info and variables. */
   u_int num_cpus;       /**< Number of physical CPU cores. */
   Redis *redis;         /**< Pointer to the Redis server. */
   Mutex m, users_m, speedtest_m, pools_lock;
-  std::map<std::string, bool> cachedCustomLists; /* Cache of lists filenames */
+  std::map<std::string, u_int8_t> cachedCustomLists; /* Cache of lists filenames */
   u_int32_t current_time; /* Upated by current_time */
 #ifndef HAVE_NEDGE
   ElasticSearch *elastic_search; /**< Pointer of Elastic Search. */
@@ -111,14 +108,20 @@ class Ntop {
 #endif
   FifoSerializerQueue *internal_alerts_queue;
   Recipients recipients; /* Handle notification recipients */
+  std::atomic<u_int32_t> num_flow_exporters;
+  std::atomic<u_int32_t> num_flow_interfaces;
 #ifdef NTOPNG_PRO
   AssetManagement am;
 #ifdef HAVE_KAFKA
   KafkaClient kafkaClient;
 #endif
+  MessageBroker *message_broker;
 #endif
 #ifdef HAVE_NEDGE
-  std::vector<MulticastForwarder*> multicastForwarders;
+  std::vector<PacketForwarder*> multicastForwarders;
+#endif
+#ifdef HAVE_SNMP_TRAP
+  SNMPTrap *trap_collector;
 #endif
 
   /* Local network address list */
@@ -150,10 +153,6 @@ class Ntop {
   std::map<std::string /* ifname */, Ping *> ping;
 #endif
 
-#ifdef __linux__
-  int inotify_fd;
-#endif
-
   /* For local network */
   inline int16_t localNetworkLookup(int family, void *addr,
                                     u_int8_t *network_mask_bits = NULL);
@@ -166,18 +165,23 @@ class Ntop {
 
   bool getUserPasswordHashLocal(const char *user, char *password_hash,
                                 u_int password_hash_len) const;
-  bool checkUserPasswordLocal(const char *user, const char *password,
-                              char *group) const;
+  bool checkLocalAuth(const char *user, const char *password, char *group) const;
+  bool checkHTTPAuth(const char *user, const char *password, char *group) const;
+  bool checkLDAPAuth(const char *user, const char *password, char *group) const;
+  bool checkRadiusAuth(const char *user, const char *password, char *group) const;
   bool checkUserPassword(const char *user, const char *password, char *group,
                          bool *localuser) const;
-  bool startPurgeLoop();
 
   void checkReloadFlowChecks();
   void checkReloadHostChecks();
   void checkReloadAlertExclusions();
   void checkReloadHostPools();
   void setZoneInfo();
-  char *getPersistentCustomListName(char *name);
+  char* getPersistentCustomListName(char *name, u_int8_t *list_id /* out */);
+#ifdef NTOPNG_PRO
+  void connectMessageBroker();
+  void reloadMessageBroker();
+#endif
 
  public:
   /**
@@ -370,7 +374,7 @@ class Ntop {
    *
    * @param i Network interface.
    */
-  void initInterface(NetworkInterface *i);
+  void initInterface(NetworkInterface *i, bool disable_dump = false);
 
   /**
    * @brief Get the number of defined network interfaces.
@@ -543,6 +547,7 @@ class Ntop {
   void shutdownInterfaces();
   void shutdownAll();
   void runHousekeepingTasks();
+  void runPeriodicHousekeepingTasks();
   void runShutdownTasks();
   void checkShutdownWhenDone();
   bool isLocalInterfaceAddress(int family, void *addr) {
@@ -571,7 +576,13 @@ class Ntop {
   inline int getUdpSock() { return (udp_socket); }
 #ifdef NTOPNG_PRO
   inline AlertExclusions *getAlertExclusions() { return alert_exclusions; }
+  u_int32_t getMaxNumFlowExporters();
+  u_int32_t getMaxNumFlowExportersInterfaces();
 #endif
+  u_int32_t getNumFlowExporters()              { return num_flow_exporters;  }
+  u_int32_t getNumFlowExportersInterfaces()    { return num_flow_interfaces; }
+  bool incNumFlowExporters();
+  bool incNumFlowExportersInterfaces();
 
   inline u_int getNumCPUs() { return (num_cpus); }
   inline void setNumCPUs(u_int num) { num_cpus = num; }
@@ -620,8 +631,7 @@ class Ntop {
   }
   void lua_alert_queues_stats(lua_State *vm);
   bool recipients_are_empty();
-  bool recipients_enqueue(AlertFifoItem *notification,
-                          AlertEntity alert_entity);
+  bool recipients_enqueue(AlertFifoItem *notification);
   AlertLevel get_default_recipient_minimum_severity();
   bool recipient_enqueue(u_int16_t recipient_id,
                          const AlertFifoItem *const notification);
@@ -633,15 +643,16 @@ class Ntop {
                           Bitmap128 enabled_categories,
                           Bitmap128 enabled_host_pools,
                           Bitmap128 enabled_entities,
-                          Bitmap128 enabled_flow_checks,
-                          Bitmap128 enabled_host_checks,
+                          Bitmap128 enabled_flow_alert_types,
+                          Bitmap128 enabled_host_alert_types,
+                          Bitmap128 enabled_other_alert_types,
+                          bool match_alert_id,
                           bool skip_alerts);
 
   void sendNetworkInterfacesTermination();
   inline time_t getLastStatsReset() { return (last_stats_reset); }
   void resetStats();
 
-  bool isMaliciousJA3Hash(std::string md5_hash);
   struct ndpi_detection_module_struct *initnDPIStruct();
 
   void checkReloadHostsBroadcastDomain();
@@ -672,17 +683,14 @@ class Ntop {
                                 bool *is_admin) {
     return radiusAcc->authenticate(username, password, has_unprivileged_capabilities, is_admin);
   };
-  inline bool radiusAccountingStart(const char *username,
-                                    const char *session_id) {
-    return radiusAcc->startSession(username, session_id);
+  inline bool radiusAccountingStart(RadiusTraffic *info) {
+    return radiusAcc->startSession(info);
   };
-  inline bool radiusAccountingUpdate(const char *username,
-                                     const char *session_id, RadiusTraffic *info) {
-    return radiusAcc->updateSession(username, session_id, info);
+  inline bool radiusAccountingUpdate(RadiusTraffic *info) {
+    return radiusAcc->updateSession(info);
   };
-  inline bool radiusAccountingStop(const char *username, const char *session_id,
-                                   RadiusTraffic *info) {
-    return radiusAcc->stopSession(username, session_id, info);
+  inline bool radiusAccountingStop(RadiusTraffic *info) {
+    return radiusAcc->stopSession(info);
   };
 #endif
 
@@ -694,7 +702,6 @@ class Ntop {
     char val[64];
     return getUserPasswordHashLocal(user, val, sizeof(val));
   }
-  void purgeLoopBody();
 
   /* Local network address list methods */
   inline u_int16_t getNumLocalNetworks() {
@@ -767,6 +774,7 @@ class Ntop {
   bool nDPILoadHostnameCategory(char *what, ndpi_protocol_category_t id,
                                 char *list_name);
   int nDPILoadMaliciousJA3Signatures(const char *file_path);
+  int nDPISetDomainMask(const char *domain, u_int64_t domain_mask);
   void setLastInterfacenDPIReload(time_t now);
   bool needsnDPICleanup();
   void setnDPICleanupNeeded(bool needed);
@@ -778,7 +786,9 @@ class Ntop {
 
   void luaClickHouseStats(lua_State *vm) const;
   void speedtest(lua_State *vm);
-
+#if defined(NTOPNG_PRO)
+  MessageBroker* getMessageBroker() { return(message_broker); };
+#endif
 #if defined(NTOPNG_PRO) && defined(HAVE_CLICKHOUSE) && defined(HAVE_MYSQL)
   inline u_int importClickHouseDumps(bool silence_warnings) {
     return (clickhouseImport ? clickhouseImport->importDumps(silence_warnings)
@@ -795,7 +805,9 @@ class Ntop {
 #endif
   inline Mutex *get_pools_lock()      { return (&pools_lock); };
   inline u_int32_t get_current_time() { return(current_time); };
-  bool createPcapInterface(const char *path, int *iface_id);
+
+  bool createRuntimeInterface(char *name, char *source, int *iface_id);
+
   void incBlacklisHits(std::string listname);
 #if defined(NTOPNG_PRO) && defined(HAVE_KAFKA)
   inline bool sendKafkaMessage(char *kafka_broker_info, char *msg,
@@ -807,6 +819,16 @@ class Ntop {
   inline BlacklistStats* getBlacklistStats() { return(&blStats); }
   inline void resetBlacklistStats()          { blStats.reset();  }
   inline JobQueue* getJobsQueue()            { return(&jobsQueue); }
+  inline PeriodicActivities* getPeriodicActivities() { return(pa); }
+
+  void incNumLuaVMs()                   { num_active_lua_vms++;       }
+  void decNumLuaVMs()                   { num_active_lua_vms--;       } 
+  inline u_int16_t getNumActiveLuaVMs() { return(num_active_lua_vms); }
+  const char* getPersistentCustomListNameById(u_int8_t list_id);
+#ifdef HAVE_SNMP_TRAP
+  void initSNMPTrapCollector();
+  void toggleSNMPTrapCollector(bool enable);
+#endif
 };
 
 extern Ntop *ntop;
