@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,6 +46,7 @@ class Paginator {
   u_int32_t asn_filter;
   u_int32_t deviceIP;
   u_int32_t inIndex, outIndex;
+  int32_t iface_index_filter;
   u_int16_t pool_filter, alert_type_filter;
   AlertLevelGroup alert_type_severity_filter;
   u_int8_t *mac_filter, icmp_type, icmp_code, dscp_filter;
@@ -142,8 +143,9 @@ class Paginator {
 
   inline bool l7protoFilter(int *f_master_proto, int *f_app_proto) const {
     if ((l7proto_filter_master_proto >= 0) || (l7proto_filter_app_proto >= 0)) {
-      *f_master_proto = l7proto_filter_master_proto,
-      *f_app_proto = l7proto_filter_app_proto;
+      /* In this way, only if the filter is selected, the filter is applied */
+      *f_master_proto = (l7proto_filter_master_proto >= 0) ? l7proto_filter_master_proto : NDPI_PROTOCOL_UNKNOWN;
+      *f_app_proto = (l7proto_filter_app_proto >= 0) ? l7proto_filter_app_proto : NDPI_PROTOCOL_UNKNOWN;
       return true;
     }
 
@@ -158,6 +160,14 @@ class Paginator {
     return false;
   }
 
+  inline bool ifaceIndexFilter(int *f) const {
+    if (iface_index_filter >= 0) {
+      (*f) = iface_index_filter;
+      return true;
+    }
+    return false;
+  }
+
   inline bool trafficProfileFilter(char **f) const {
     if (traffic_profile_filter) {
       (*f) = traffic_profile_filter;
