@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,8 +34,10 @@ class ParsedFlowCore {
   u_int8_t version; /* 0 so far */
   u_int8_t l4_proto;
   u_int32_t source_id;
-  u_int32_t device_ip;
-  struct ndpi_in6_addr device_ipv6;
+  u_int32_t exporter_device_ip;
+  u_int32_t nprobe_ip;
+  u_int32_t unique_source_id;
+  struct ndpi_in6_addr exporter_device_ipv6;
   u_int16_t src_port, dst_port;
   u_int32_t inIndex, outIndex;
   ndpi_proto l7_proto;
@@ -59,8 +61,6 @@ class ParsedFlowCore {
   ParsedFlowCore(const ParsedFlowCore &pfc);
   virtual ~ParsedFlowCore();
   void swap();
-
-  void print();
 };
 
 #endif /* _PARSED_FLOW_CORE_H_ */
