@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,13 +26,19 @@
 
 class PcapInterface : public NetworkInterface {
  private:
-  pcap_t *pcap_handle;
+  u_int8_t num_ifaces;
+  char* pcap_ifaces[MAX_NUM_PCAP_INTERFACES]; /* Used when interfaces such as eth0,eth1 */
+  pcap_t* pcap_handle[MAX_NUM_PCAP_INTERFACES];
+  unsigned int ifname_indexes[MAX_NUM_PCAP_INTERFACES];
+  int iface_datalink[MAX_NUM_PCAP_INTERFACES];
   char *pcap_path;
   bool read_pkts_from_pcap_dump, read_pkts_from_pcap_dump_done,
-      emulate_traffic_directions, read_from_stdin_pipe, delete_pcap_when_done;
+    emulate_traffic_directions, read_from_stdin_pipe,
+    delete_pcap_when_done;
   ProtoStats prev_stats_in, prev_stats_out;
   FILE *pcap_list;
-
+  struct timeval startTS, firstPktTS;
+  
   pcap_stat last_pcap_stat;
   u_int32_t getNumDroppedPackets();
   void cleanupPcapDumpDir();
@@ -63,24 +69,29 @@ class PcapInterface : public NetworkInterface {
                 ? CONST_INTERFACE_TYPE_PCAP_DUMP
                 : CONST_INTERFACE_TYPE_PCAP);
   };
-  inline pcap_t *get_pcap_handle() { return (pcap_handle); };
+  inline pcap_t *get_pcap_handle(u_int8_t id) { return ((id < num_ifaces) ? pcap_handle[id] : NULL); };
   inline virtual bool areTrafficDirectionsSupported() {
     return (emulate_traffic_directions);
   };
-  inline void set_pcap_handle(pcap_t *p) { pcap_handle = p; };
+  inline void set_pcap_handle(pcap_t *p, u_int8_t id) { if(id < num_ifaces) pcap_handle[id] = p; };
   inline FILE *get_pcap_list() { return (pcap_list); };
   void startPacketPolling();
   bool set_packet_filter(char *filter);
+  bool read_from_stdin() const { return (read_from_stdin_pipe); };
   bool read_from_pcap_dump() const { return (read_pkts_from_pcap_dump); };
   bool read_from_pcap_dump_done() const {
     return (read_pkts_from_pcap_dump_done);
   };
   void set_read_from_pcap_dump_done() { read_pkts_from_pcap_dump_done = true; };
-  inline void sendTermination() {
-    if (pcap_handle) pcap_breakloop(pcap_handle);
-  };
+  void sendTermination();
   bool reproducePcapOriginalSpeed() const;
   virtual void updateDirectionStats();
+  inline u_int8_t get_num_ifaces() { return(num_ifaces); }
+  bool processNextPacket(pcap_t *pd, int32_t if_index, int datalink_type);
+  bool reopen(u_int8_t iface_id);  
+  unsigned int get_ifindex(int i) { return(ifname_indexes[i]); }
+  int get_ifdatalink(int i)       { return(iface_datalink[i]); }
+  char* getPcapIfaceName(int i)   { return(pcap_ifaces[i]);    }
 };
 
 #endif /* _PCAP_INTERFACE_H_ */
