@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@ class Prefs {
   char **deferred_interfaces_to_register, *cli;
   char *http_binding_address1, *http_binding_address2;
   char *https_binding_address1, *https_binding_address2;
-  bool enable_client_x509_auth, reproduce_at_original_speed;
+  bool enable_client_x509_auth, reproduce_at_original_speed, disable_purge;
   char* zmq_publish_events_url, *http_log_path;
   const char *clickhouse_client, *clickhouse_cluster_name;
   Ntop* ntop;
@@ -59,13 +59,17 @@ class Prefs {
     enable_asn_behaviour_analysis, enable_network_behaviour_analysis,
     enable_iface_l7_behaviour_analysis, emit_flow_alerts, emit_host_alerts,
     dump_flows_on_clickhouse, use_mac_in_flow_key, do_reforge_timestamps,
-    add_vlan_tags_to_cloud_exporters, collect_blacklist_stats;
+    add_vlan_tags_to_cloud_exporters, collect_blacklist_stats,
+    fail_on_invalid_license, limited_resources_mode, fingerprint_stats,
+    tls_quic_hostnaming;
   u_int32_t behaviour_analysis_learning_period;
   u_int32_t iec60870_learning_period, modbus_learning_period,
     devices_learning_period;
+  u_int32_t host_port_learning_period;
 #ifdef NTOPNG_PRO
   ndpi_bitmap* modbus_allowed_function_codes;
   u_int modbus_too_many_exceptions;
+  bool netbox_enabled, asset_inventory_enabled, snmp_trap_enabled;
 #endif
   ServiceAcceptance behaviour_analysis_learning_status_during_learning,
       behaviour_analysis_learning_status_post_learning;
@@ -88,7 +92,7 @@ class Prefs {
       enable_intranet_traffic_rrd_creation;
   bool enable_tiny_flows_export;
   bool enable_captive_portal, enable_informative_captive_portal,
-      mac_based_captive_portal;
+      mac_based_captive_portal, enable_external_auth_captive_portal;
   bool override_dst_with_post_nat_dst, override_src_with_post_nat_src;
   bool routing_mode_enabled, global_dns_forging_enabled;
   bool device_protocol_policies_enabled, enable_vlan_trunk_bridge;
@@ -116,16 +120,13 @@ class Prefs {
   u_int http_port, https_port;
   u_int8_t num_interfaces;
   u_int16_t auto_assigned_pool_id;
-  u_int8_t vs_max_num_scans; 
+  u_int8_t vs_max_num_scans;
+  bool vs_slow_scan; 
   bool dump_flows_on_es, dump_flows_on_mysql, dump_flows_on_syslog,
       dump_json_flows_on_disk, dump_ext_json;
 #ifdef NTOPNG_PRO
   bool dump_flows_direct;
   u_int32_t max_aggregated_flows_upperbound, max_aggregated_flows_traffic_upperbound;
-  bool is_geo_map_score_enabled, is_geo_map_asname_enabled,
-      is_geo_map_alerted_flows_enabled, is_geo_map_blacklisted_flows_enabled,
-      is_geo_map_host_name_enabled, is_geo_map_rxtx_data_enabled,
-      is_geo_map_num_flows_enabled;
 #endif
   bool enable_runtime_flows_dump; /**< runtime preference to enable/disable
                                      flows dump from the UI */
@@ -168,11 +169,16 @@ class Prefs {
   bool json_labels_string_format;
   char *es_type, *es_index, *es_url, *es_user, *es_pwd, *es_host;
   char *mysql_host, *mysql_dbname, *mysql_user, *mysql_pw;
+#if defined(HAVE_CLICKHOUSE) && defined(NTOPNG_PRO) && defined(HAVE_MYSQL)
+  char *ch_user; /* In case of ch cloud, 2 users are needed, 
+                    one for mysql and one for ch */
+  bool ntopng_assets_inventory_enabled;
+#endif
 #if !defined(WIN32) && !defined(__APPLE__)
   int flows_syslog_facility;
 #endif
-  int mysql_port;
-  int clickhouse_tcp_port;
+  int mysql_port, clickhouse_tcp_port;
+  bool mysql_port_secure, clickhouse_tcp_port_secure;
   char *ls_host, *ls_port, *ls_proto;
   bool has_cmdl_trace_lvl; /**< Indicate whether a verbose level
                               has been provided on the command line.*/
@@ -188,10 +194,14 @@ class Prefs {
   char* test_runtime_script_path;
   char* test_post_script_path;
 
+  char* message_broker_url;
+  char* message_broker;
 #ifdef NTOPNG_PRO
   bool print_maintenance, print_license;
 #endif
   bool print_version, print_version_json;
+  bool snmp_polling;
+  bool active_monitoring;
 
   InterfacesSet lan_interfaces, wan_interfaces;
 
@@ -222,7 +232,8 @@ class Prefs {
   bool is_enterprise_m_edition();
   bool is_enterprise_l_edition();
   bool is_enterprise_xl_edition();
-  bool is_cloud_edition();
+
+  bool is_edr_mode() { return false; /* TODO (used to be private Cloud mode) */ };
 
   bool is_nedge_pro_edition();
   bool is_nedge_enterprise_edition();
@@ -326,7 +337,6 @@ class Prefs {
   inline bool is_flows_dump_enabled() {
     return (do_dump_flows() && is_runtime_flows_dump_enabled());
   };
-
   int32_t getDefaultPrefsValue(const char* pref_key, int32_t default_value);
   void getDefaultStringPrefsValue(const char* pref_key, char** buffer,
                                   const char* default_value);
@@ -353,6 +363,12 @@ class Prefs {
   inline const char* get_test_post_script_path() {
     return (test_post_script_path);
   };
+  inline const char* get_message_broker_url() {
+    return(message_broker_url);
+  };
+  inline const char* get_message_broker() {
+    return(message_broker);
+  };
   inline char* get_export_endpoint() { return (export_endpoint); };
   inline char* get_export_zmq_encryption_key() {
     return (export_zmq_encryption_key);
@@ -371,6 +387,9 @@ class Prefs {
   inline bool do_simulate_vlans() { return (simulate_vlans); };
   inline bool do_simulate_macs() { return (simulate_macs); };
   inline bool do_insecure_tls() { return (insecure_tls); };
+  inline bool do_snmp_polling() { return (snmp_polling); };
+  inline bool do_active_monitoring(){ return (active_monitoring); };
+  inline bool do_tls_quic_hostnaming() { return (tls_quic_hostnaming); };
   inline char* get_cpu_affinity() { return (cpu_affinity); };
   inline char* get_other_cpu_affinity() { return (other_cpu_affinity); };
 #ifdef __linux__
@@ -465,9 +484,15 @@ class Prefs {
   inline char* get_mysql_host() { return (mysql_host); };
   inline int get_mysql_port() { return (mysql_port); };
   inline int get_clickhouse_tcp_port() { return (clickhouse_tcp_port); };
+  inline bool is_mysql_port_secure() { return (mysql_port_secure); };
+  inline bool is_clickhouse_tcp_port_secure() { return (clickhouse_tcp_port_secure); };
   inline char* get_mysql_dbname() { return (mysql_dbname); };
   inline char* get_mysql_tablename() { return ((char*)"flows"); };
   inline char* get_mysql_user() { return (mysql_user); };
+#if defined(HAVE_CLICKHOUSE) && defined(NTOPNG_PRO) && defined(HAVE_MYSQL)
+  /* If this is not NULL, it means that the user is using CH Cloud */
+  inline char* get_ch_user() { return (ch_user); };
+#endif
   inline char* get_mysql_pw() { return (mysql_pw); };
 #if !defined(WIN32) && !defined(__APPLE__)
   inline int get_flows_syslog_facility() { return (flows_syslog_facility); };
@@ -571,16 +596,18 @@ class Prefs {
     return (enable_captive_portal && !enable_vlan_trunk_bridge);
   }
 
+  inline bool enableActivitiesDebug() const {
+    return (enable_activities_debug);
+  }
+
+#ifdef HAVE_NEDGE
   bool isInformativeCaptivePortalEnabled() const;
+  bool isExternalAuthCaptivePortalEnabled() const;
+  const char* getCaptivePortalUrl();
 
   inline bool isMacBasedCaptivePortal() const {
     return (mac_based_captive_portal);
   }
-  inline bool enableActivitiesDebug() const {
-    return (enable_activities_debug);
-  }
-#ifdef HAVE_NEDGE
-  const char* getCaptivePortalUrl();
 #endif
   const TsDriver getTimeseriesDriver() const { return (timeseries_driver); }
 
@@ -628,6 +655,7 @@ class Prefs {
   inline bool purgeHostsFlowsOnPcapFiles() {
     return (pcap_file_purge_hosts_flows);
   };
+  inline bool disablePurge() { return (disable_purge);  };
   inline void enableBehaviourAnalysis() { enable_behaviour_analysis = true; };
   inline bool isBehavourAnalysisEnabled() {
     return (enable_behaviour_analysis);
@@ -660,11 +688,15 @@ class Prefs {
   inline u_int32_t getIEC60870LearingPeriod() { return (iec60870_learning_period); };
   inline u_int32_t getModbusLearingPeriod()   { return (modbus_learning_period); };
 #ifdef NTOPNG_PRO
+  inline bool isNetBoxEnabled() { return netbox_enabled; };
+  inline bool isAssetInventoryEnabled() { return asset_inventory_enabled; };
+  inline bool isSNMPTrapEnabled() { return snmp_trap_enabled; };
   inline ndpi_bitmap* getModbusAllowedFunctionCodes() { return (modbus_allowed_function_codes);  };
   inline void         setModbusTooManyExceptionsThreshold(u_int v) { modbus_too_many_exceptions = v;     }
   inline u_int        getModbusTooManyExceptionsThreshold()        { return(modbus_too_many_exceptions); }
 #endif
   inline u_int32_t devicesLearingPeriod() { return (devices_learning_period); };
+  inline u_int32_t hostPortLearningPeriod() { return (host_port_learning_period); };
   inline bool are_alerts_disabled() { return (disable_alerts); };
   inline bool dontEmitFlowAlerts() {
     return (disable_alerts || !emit_flow_alerts);
@@ -692,10 +724,13 @@ class Prefs {
   char* getKafkaOptions() { return (kafka_options); }
 #endif
   inline bool useMacAddressInFlowKey()     { return (use_mac_in_flow_key);  }
+  inline bool enableFingerprintStats()     { return (fingerprint_stats);    }
   inline bool doReforgeTimestamps()        { return(do_reforge_timestamps); }
   inline void enableVLANCloudToExporters() { add_vlan_tags_to_cloud_exporters = true;  }
   inline bool addVLANCloudToExporters()    { return(add_vlan_tags_to_cloud_exporters); }
   inline bool collectBlackListStats()      { return(collect_blacklist_stats);          }
+  inline bool limitResourcesUsage()        { return(limited_resources_mode);           }
+  inline bool failOnInvalidLicense()       { return(fail_on_invalid_license);          }
 };
 
 #endif /* _PREFS_H_ */
