@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2014-23 - ntop.org
+ * (C) 2014-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@ class RecipientQueue {
  private:
   u_int16_t recipient_id;
   bool skip_alerts;
+  bool match_alert_id;
 
   AlertFifoQueue *queue;
 
@@ -56,11 +57,16 @@ class RecipientQueue {
   /* MUST be large enough to contain MAX_NUM_HOST_POOLS */
   Bitmap128 enabled_host_pools;
 
-  Bitmap128 enabled_flow_checks; /* MUST be large enough to contain
+  Bitmap128 enabled_flow_alert_types; /* MUST be large enough to contain
                                  FlowAlertTypeEnum */
 
-  Bitmap128 enabled_host_checks; /* MUST be large enough to contain
-                                 HostCheckID */
+  Bitmap128 enabled_host_alert_types; /* MUST be large enough to contain
+                                 HostAlertID */
+
+  Bitmap128 enabled_other_alert_types; /* MUST be large enough to contain
+                                 Other alert IDs defined in other_alert_keys.lua */
+
+  bool doDebug(const AlertFifoItem* const notification);
 
  public:
   RecipientQueue(u_int16_t recipient_id);
@@ -80,8 +86,7 @@ class RecipientQueue {
    *
    * @return True if the enqueue succeeded, false otherwise
    */
-  bool enqueue(const AlertFifoItem* const notification,
-               AlertEntity alert_entity);
+  bool enqueue(const AlertFifoItem* const notification);
 
   /**
    * @brief Sets the minimum severity for notifications to use this recipient
@@ -127,28 +132,38 @@ class RecipientQueue {
   };
 
   /**
-   * @brief Sets enabled flow checks to use this recipient
-   * @param enabled_flow_checks
+   * @brief Sets enabled flow alert types to use this recipient
+   * @param enabled_flow_alert_types
    *
    * @return
    */
-  inline void setEnabledFlowChecks(Bitmap128 _enabled_flow_checks) {
-    enabled_flow_checks = _enabled_flow_checks;
+  inline void setEnabledFlowAlertTypes(Bitmap128 _enabled_flow_alert_types) {
+    enabled_flow_alert_types = _enabled_flow_alert_types;
   };
 
   /**
-   * @brief Sets enabled host checks to use this recipient
-   * @param enabled_host_checks
+   * @brief Sets enabled host alert types to use this recipient
+   * @param enabled_host_alert_types
    *
    * @return
    */
-  inline void setEnabledHostChecks(Bitmap128 _enabled_host_checks) {
-    enabled_host_checks = _enabled_host_checks;
+  inline void setEnabledHostAlertTypes(Bitmap128 _enabled_host_alert_types) {
+    enabled_host_alert_types = _enabled_host_alert_types;
   };
 
   /**
-   * @brief Sets enabled host checks to use this recipient
-   * @param enabled_host_checks
+   * @brief Sets enabled other alert types to use this recipient
+   * @param enabled_other_alert_types
+   *
+   * @return
+   */
+  inline void setEnabledOtherAlertTypes(Bitmap128 _enabled_other_alert_types) {
+    enabled_other_alert_types = _enabled_other_alert_types;
+  };
+
+  /**
+   * @brief Sets alerts to be ignored
+   * @param skip_alerts
    *
    * @return
    */
@@ -156,6 +171,16 @@ class RecipientQueue {
     skip_alerts = _skip_alerts;
   };
 
+  /**
+   * @brief Toggle match on alert_id only (ignore severity, category, etc)
+   * @param match_alert_id
+   *
+   * @return
+   */
+  inline void toggleAlertIDMatch(bool _match_alert_id) {
+    match_alert_id = _match_alert_id;
+  };
+
   /**
    * @brief Returns queue status (drops and uses)
    * @param vm A Lua VM instance
