@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2014-23 - ntop.org
+ * (C) 2014-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -59,13 +59,10 @@ class Recipients {
   /**
    * @brief Enqueues a notification to all available recipients
    * @param notification The notification to be enqueued
-   * @param alert_entity Indicates to enqueue the alert only to recipients
-   * responsible for `alert_entity` alerts
    *
    * @return True if the enqueue succeeded, false otherwise
    */
-  bool enqueue(const AlertFifoItem* const notification,
-               AlertEntity alert_entity);
+  bool enqueue(const AlertFifoItem* const notification);
 
   /**
    * @brief Registers a recipient identified with `recipient_id` so its
@@ -85,8 +82,10 @@ class Recipients {
                           Bitmap128 enabled_categories,
                           Bitmap128 enabled_host_pools,
                           Bitmap128 enabled_entities,
-                          Bitmap128 enabled_flow_checks,
-                          Bitmap128 enabled_host_checks,
+                          Bitmap128 enabled_flow_alert_types,
+                          Bitmap128 enabled_host_alert_types,
+                          Bitmap128 enabled_other_alert_types,
+                          bool match_alert_id,
                           bool skip_alerts);
 
   /**
