@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,11 +26,6 @@
 
 #define SNMP_MAX_NUM_OIDS 10
 
-#ifdef HAVE_LIBSNMP
-#include <net-snmp/net-snmp-config.h>
-#include <net-snmp/net-snmp-includes.h>
-#endif
-
 /* ******************************* */
 
 typedef enum {
@@ -40,17 +35,6 @@ typedef enum {
   snmp_set_pdu,
 } snmp_pdu_primitive;
 
-#ifdef HAVE_LIBSNMP
-class SNMPSession {
- public:
-  struct snmp_session session;
-  void *session_ptr;
-
-  SNMPSession();
-  ~SNMPSession();
-};
-#endif
-
 class SNMP {
  private:
   u_int snmp_version;
@@ -63,7 +47,8 @@ class SNMP {
   int udp_sock;
   u_int32_t request_id;
 #endif
-
+  u_int8_t getbulk_max_num_repetitions;
+  
   void send_snmp_request(char *agent_host, u_int version, char *community,
                          char *level, char *username, char *auth_protocol,
                          char *auth_passphrase, char *privacy_protocol,
@@ -82,7 +67,7 @@ class SNMP {
  public:
   SNMP();
   ~SNMP();
-
+  
 #ifdef HAVE_LIBSNMP
   void handle_async_response(struct snmp_pdu *pdu, const char *agent_ip);
   void send_snmp_set_request(char *agent_host, char *community,
@@ -99,11 +84,15 @@ class SNMP {
                            char value_types[SNMP_MAX_NUM_OIDS],
                            char *values[SNMP_MAX_NUM_OIDS], bool _batch_mode);
 #endif
+
   void send_snmpv1v2c_request(char *agent_host, char *community,
                               snmp_pdu_primitive pduType, u_int version,
                               char *oid[SNMP_MAX_NUM_OIDS], bool _batch_mode);
   void snmp_fetch_responses(lua_State *vm, u_int timeout);
 
+  void     set_snmpbulk_max_repetitions(u_int8_t n) { getbulk_max_num_repetitions = n;     };
+  u_int8_t get_snmpbulk_max_repetitions()           { return(getbulk_max_num_repetitions); };
+  
   int get(lua_State *vm, bool skip_first_param);
   int getnext(lua_State *vm, bool skip_first_param);
   int getnextbulk(lua_State *vm, bool skip_first_param);
