@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@ class SQLiteAlertStore : virtual public AlertStore, public SQLiteStoreManager {
   SQLiteAlertStore(int interface_id, const char *db_filename);
   ~SQLiteAlertStore();
 
-  bool query(lua_State *vm, const char *query);
+  bool query(lua_State *vm, const char *query, bool limit_rows);
 };
 
 #endif /* _SQLITE_ALERT_STORE_H_ */
