@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ class SyslogCollectorInterface : public SyslogParserInterface {
   void startPacketPolling();
   void shutdown();
   bool set_packet_filter(char *filter);
-  virtual void lua(lua_State *vm);
+  virtual void lua(lua_State *vm, bool fullStats);
 };
 
 #endif /* HAVE_NEDGE */
