@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,16 +26,20 @@
 
 class UsedPorts {
  private:
+  Host* h;
   /* Used for both TCP and UDP */
-  std::unordered_map<u_int16_t, ndpi_protocol> udp_server_ports,
-      tcp_server_ports;
-  std::unordered_map<u_int16_t, ndpi_protocol> udp_client_contacted_ports,
-      tcp_client_contacted_ports;
+  std::unordered_map<u_int16_t /* port */, ndpi_protocol> udp_server_ports, tcp_server_ports;
+  std::unordered_map<u_int16_t /* port */, ndpi_protocol> udp_client_contacted_ports, tcp_client_contacted_ports;
 
+  ServerPortsBitmap *bitmap_server_ports;
+  
   void setLuaArray(lua_State *vm, NetworkInterface *iface, bool isTCP,
                    std::unordered_map<u_int16_t, ndpi_protocol> *ports);
-
+  char* getRedisKey(char *redis_key, size_t key_len);
+  void restore();
+  
  public:
+  UsedPorts(Host* h);
   UsedPorts();
   ~UsedPorts();
 
@@ -47,7 +51,7 @@ class UsedPorts {
   inline std::unordered_map<u_int16_t, ndpi_protocol> getTCPServerPorts() { return(tcp_server_ports); };
 
 
-  void setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto);
+  bool setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto);
   void setContactedPort(bool isTCP, u_int16_t port, ndpi_protocol *proto);
   void setLuaArrayUDPServerPorts(lua_State *vm, NetworkInterface *iface) {setLuaArray(vm, iface, false, &udp_server_ports);};
   void setLuaArrayTCPServerPorts(lua_State *vm, NetworkInterface *iface) {setLuaArray(vm, iface, true, &tcp_server_ports);};
