@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,6 @@ class ViewInterface : public NetworkInterface {
   virtual void sumStats(TcpFlowStats *_tcpFlowStats, EthStats *_ethStats,
                         LocalTrafficStats *_localStats, nDPIStats *_ndpiStats,
                         PacketStats *_pktStats, TcpPacketStats *_tcpPacketStats,
-                        ProtoStats *_discardedProbingStats,
                         DSCPStats *_dscpStats, SyslogStats *_syslogStats,
                         RoundTripStats *_downloadStats,
                         RoundTripStats *_uploadStats) const;
@@ -74,8 +73,6 @@ class ViewInterface : public NetworkInterface {
   virtual u_int64_t getNumDroppedAlerts();
   virtual u_int64_t getNumBytes();
   virtual u_int getNumPacketDrops();
-  virtual u_int64_t getNumDiscardedProbingPackets() const;
-  virtual u_int64_t getNumDiscardedProbingBytes() const;
   virtual u_int64_t getNumNewFlows();
   virtual u_int getNumFlows();
   virtual u_int64_t getNumActiveAlertedFlows() const;
@@ -86,18 +83,22 @@ class ViewInterface : public NetworkInterface {
   virtual u_int64_t getCheckPointDroppedAlerts();
   virtual u_int64_t getCheckPointNumBytes();
   virtual u_int32_t getCheckPointNumPacketDrops();
-  virtual u_int64_t getCheckPointNumDiscardedProbingPackets() const;
-  virtual u_int64_t getCheckPointNumDiscardedProbingBytes() const;
+  virtual u_int64_t getCheckPointNumTrafficSent() const;
+  virtual u_int64_t getCheckPointNumTrafficRcvd() const;
+  virtual u_int64_t getCheckPointNumPacketsSent() const;
+  virtual u_int64_t getCheckPointNumPacketsRcvd() const;
   virtual void checkPointCounters(bool drops_only);
 
   virtual bool hasSeenVLANTaggedPackets() const;
 
 #ifdef NTOPNG_PRO
   virtual void getFlowDevices(lua_State *vm);
-  virtual void getFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP);
+  virtual void getFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP, bool showAllStats);
+  virtual void getFlowDeviceInfoByIP(lua_State *vm, u_int32_t deviceIP, bool showAllStats);
 #endif
-  virtual void getSFlowDevices(lua_State *vm);
+  virtual void getSFlowDevices(lua_State *vm, bool add_table);
   virtual void getSFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP);
+  virtual void lua(lua_State *vm, bool fullStats);
 
   virtual u_int32_t getFlowsHashSize();
   virtual Flow *findFlowByKeyAndHashId(u_int32_t key, u_int hash_id,
