@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -61,7 +61,7 @@ class ZMQCollectorInterface : public ZMQParserInterface {
 
   void startPacketPolling();
   bool set_packet_filter(char *filter);
-  virtual void lua(lua_State *vm);
+  virtual void lua(lua_State *vm, bool fullStats);
   virtual bool areTrafficDirectionsSupported() { return (true); };
 };
 
