@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,10 +42,10 @@ class ZMQParserInterface : public ParserInterface {
   u_int32_t polling_start_time;
   bool once, is_sampled_traffic;
   u_int32_t flow_max_idle, returned_flow_max_idle;
-  u_int64_t zmq_initial_bytes, zmq_initial_pkts,
+  u_int64_t zmq_initial_bytes, zmq_initial_pkts, zmq_initial_drops,
       zmq_remote_initial_exported_flows;
-  std::map<u_int32_t, ZMQ_RemoteStats *> source_id_last_zmq_remote_stats;
-  ZMQ_RemoteStats *zmq_remote_stats, *zmq_remote_stats_shadow;
+  std::map<u_int32_t, nProbeStats *> source_id_last_zmq_remote_stats;
+  nProbeStats *zmq_remote_stats, *zmq_remote_stats_shadow;
   u_int32_t remote_lifetime_timeout, remote_idle_timeout;
   struct timeval last_zmq_remote_stats_update;
   RwLock lock;
@@ -53,6 +53,7 @@ class ZMQParserInterface : public ParserInterface {
   CustomAppMaps *custom_app_maps;
 #endif
 
+  void exporterLuaStats(lua_State *vm, nProbeStats *zrs);
   void loadVLANMappings();
   u_int16_t findVLANMapping(std::string name);
   
@@ -85,8 +86,7 @@ class ZMQParserInterface : public ParserInterface {
  protected:
   struct {
     u_int32_t num_flows,   /* flows processed */
-        num_dropped_flows, /* flows unhandles (received but no room in the flow
-                              hash) */
+        num_dropped_flows, /* flows unhandles (received but no room in the flow hash) */
         num_events, num_counters, num_hello, num_listening_ports, num_templates,
         num_options, num_network_events, num_snmp_interfaces, zmq_msg_rcvd,
         zmq_msg_drops;
@@ -129,7 +129,7 @@ class ZMQParserInterface : public ParserInterface {
                               u_int32_t source_id, u_int32_t msg_id, void *data);
 
   u_int32_t periodicStatsUpdateFrequency() const;
-  virtual void setRemoteStats(ZMQ_RemoteStats *zrs);
+  virtual void setRemoteStats(nProbeStats *zrs);
 #ifdef NTOPNG_PRO
   virtual bool getCustomAppDetails(u_int32_t remapped_app_id,
                                    u_int32_t *const pen,
@@ -139,7 +139,8 @@ class ZMQParserInterface : public ParserInterface {
   u_int32_t getNumDroppedPackets() {
     return zmq_remote_stats ? zmq_remote_stats->sflow_pkt_sample_drops : 0;
   };
-  virtual void lua(lua_State *vm);
+  virtual void lua(lua_State *vm, bool fullStats);
+  virtual void probeLuaStats(lua_State *vm);
   inline u_int32_t getFlowMaxIdle() { return (returned_flow_max_idle); }
 };
 
