@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *  http://www.ntop.org/
  *
@@ -21,6 +21,8 @@
 #ifndef _ZMQ_PUBLISHER_H_
 #define _ZMQ_PUBLISHER_H_
 
+#ifdef HAVE_ZMQ
+
 class ZMQPublisher {
  private:
   void *context; /**< ZMQ context */
@@ -42,4 +44,6 @@ class ZMQPublisher {
   inline bool sendControlMessage(char *msg) { return (sendMessage("message", msg)); }
 };
 
+#endif /* HAVE_ZMQ */
+
 #endif /* _ZMQ_PUBLISHER_H_ */
