@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *  http://www.ntop.org/
  *
@@ -16,6 +16,8 @@
 
 #ifndef HAVE_NEDGE
 
+#ifdef HAVE_ZMQ
+
 class ZMQUtils {
  private:
 
@@ -31,5 +33,6 @@ class ZMQUtils {
 #endif
 };
 
+#endif /* HAVE_ZMQ */
 #endif /* HAVE_NEDGE */
 #endif /* _ZMQ_UTILS_H_ */
