@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@ class BlacklistedFlowAlert : public FlowAlert {
   static FlowAlertType getClassType() {
     return {flow_alert_blacklisted, alert_category_security};
   }
-  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_CRITICAL; };
 
   BlacklistedFlowAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f) {};
   ~BlacklistedFlowAlert(){};
