@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@ class ElephantFlowAlert : public FlowAlert {
   static FlowAlertType getClassType() {
     return {flow_alert_elephant_flow, alert_category_security};
   }
-  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
   ElephantFlowAlert(FlowCheck *c, Flow *f, u_int64_t _l2r_th, u_int64_t _r2l_th)
       : FlowAlert(c, f) {
