@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 #include "flow_alerts/NotPurgedAlert.h"
 #include "flow_alerts/RareDestinationAlert.h"
 #include "flow_alerts/RemoteAccessAlert.h"
-#include "flow_alerts/RemoteToLocalInsecureProtoAlert.h"
+#include "flow_alerts/RemoteToLocalInsecureFlowAlert.h"
 #include "flow_alerts/RemoteToRemoteAlert.h"
 #include "flow_alerts/TCPNoDataExchangedAlert.h"
 #include "flow_alerts/TCPZeroWindowAlert.h"
@@ -83,6 +83,9 @@
 #include "flow_alerts/IECInvalidTransitionAlert.h"
 #include "flow_alerts/IECInvalidCommandTransitionAlert.h"
 #include "flow_alerts/IECUnexpectedTypeIdAlert.h"
+#include "flow_alerts/BlacklistedClientContactAlert.h"
+#include "flow_alerts/BlacklistedServerContactAlert.h"
+#include "flow_alerts/TCPFlowResetAlert.h"
 
 /* Pro Alerts - do NOT use #ifdef as alerts must always be available */
 #include "flow_alerts/FlowRiskTLSUnsafeCiphersAlert.h"
