@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@ class UnexpectedSMTPServer : public UnexpectedServer {
   }
 
  protected:
-  bool isAllowedProto(Flow *f) { return (f->isSMTP()); }
+  bool isAllowedProto(Flow *f) { return (f->isSMTPorSMTPS()); }
 
  public:
   UnexpectedSMTPServer() : UnexpectedServer(){};
