@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -84,6 +84,9 @@
 #include "flow_checks/UnexpectedSMTPServer.h"
 #include "flow_checks/WebMining.h"
 #include "flow_checks/VLANBidirectionalTraffic.h"
+#include "flow_checks/BlacklistedClientContact.h"
+#include "flow_checks/BlacklistedServerContact.h"
+#include "flow_checks/TCPFlowReset.h"
 
 #ifdef NTOPNG_PRO
 #include "flow_checks/DataExfiltration.h"
