@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,9 @@
 class ScanDetectionAlert : public HostAlert {
  private:
   u_int64_t num_incomplete_flows, num_incomplete_flows_threshold;
+  u_int16_t num_server_ports;
+  u_int32_t as_server, as_server_threshold;
+  bool is_rx_only;
 
   ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
 
@@ -38,6 +41,10 @@ class ScanDetectionAlert : public HostAlert {
   ScanDetectionAlert(HostCheck* c, Host* f, risk_percentage cli_pctg,
                      u_int32_t _num_incomplete_flows,
                      u_int32_t _num_incomplete_flows_threshold);
+  ScanDetectionAlert(HostCheck* c, Host* f, risk_percentage cli_pctg, 
+                    u_int16_t num_server_ports,
+                    u_int32_t as_server,
+                    u_int32_t as_server_threshold);
   ~ScanDetectionAlert(){};
 
   HostAlertType getAlertType() const { return getClassType(); }
