@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -149,6 +149,8 @@
 #define NO_NDPI_PROTOCOL ((u_int)-1)
 #define NDPI_MIN_NUM_PACKETS 12
 #define GTP_U_V1_PORT 2152
+#define EOIP_PORT 16667 /* Ethernet over IP */
+#define L2TP_PORT 1701
 #define TZSP_PORT 37008
 #define VXLAN_PORT 4789
 #define CAPWAP_DATA_PORT 5247
@@ -197,6 +199,7 @@
 #define MAX_HASH_ENTRY_IDLE                                               \
   60 /* sec - Generic idle time for hash entries different from hosts and \
         flows (i.e., ASes and Macs) */
+#define MAX_PROBE_IDLE_IDLE 1800 /* 30 min (Used in ZMQParserInterface.cpp) */
 #define MAX_RRD_QUEUE_LEN 200000 /* timeseries in the queue */
 #define MIN_NUM_IDLE_ENTRIES_IF 5000
 #define INTF_RRD_RAW_DAYS 1
@@ -213,7 +216,7 @@
 #define MAX_NUM_QUEUED_ADDRS \
   500 /* Maximum number of queued address for resolution */
 #define MAX_NUM_QUEUED_CONTACTS 25000
-#define NTOP_COPYRIGHT "(C) 1998-23 ntop.org"
+#define NTOP_COPYRIGHT "(C) 1998-24 ntop.org"
 #define DEFAULT_PID_PATH "/var/run/ntopng.pid"
 #define SYSTEM_INTERFACE_NAME "__system__"
 #define SYSTEM_INTERFACE_ID -1
@@ -225,8 +228,11 @@
 #define DHCP_CACHE "ntopng.dhcp.%d.cache.%s"
 #define DHCP_STORM_QUEUE_NAME "ntopng.dhcp.storm.%d"
 #define ASSET_SERVICE_KEY "ntopng.asset.%d.%s" /* ifId.host */
+#define ASSET_LIST_INSERTION_KEY "ntopng.asset.device_queue.%d" /* take in sync with lua code */
+#define ASSET_HASH_CACHE_KEY "ntopng.asset.hash.cache.%d" /* take in sync with lua code */
 #define DHCP_STORM_PPS_THSHOLD 2048
 #define NTOPNG_TRACE "ntopng.trace"
+#define ALERT_TRACE_ERRORS "ntopng.trace_error.alert_queue"
 #define TRACES_PER_LOG_FILE_HIGH_WATERMARK 10000
 #define MAX_NUM_NTOPNG_LOG_FILES 5
 #define MAX_NUM_NTOPNG_TRACES 32
@@ -246,6 +252,7 @@
 #define TRAFFIC_FILTERING_CACHE_DURATION 43200 /* 12 h */
 #define DNS_CACHE_DURATION            3600     /*  1 h */
 #define LOCAL_HOSTS_CACHE_DURATION    3600     /*  1 h */
+#define LOCALHOST_SERVER_PORT_BITMAP "ntopng.cache.localhost_srv_port_bitmap.%d%s" 
 #define HOST_LABEL_NAMES_KEY          "ntopng.cache.host_labels.%s"
 #define IFACE_DHCP_RANGE_KEY          "ntopng.prefs.ifid_%u.dhcp_ranges"
 #define HOST_SERIALIZED_KEY           "ntopng.serialized_hosts.ifid_%u_%s@%d"
@@ -324,6 +331,7 @@
 #define CONST_INTERFACE_TYPE_DUMMY "dummy"
 #define CONST_INTERFACE_TYPE_ZC_FLOW "ZC-flow"
 #define CONST_INTERFACE_TYPE_CUSTOM "custom"
+#define CONST_INTERFACE_TYPE_DB "db"
 #define CONST_INTERFACE_TYPE_UNKNOWN "unknown"
 
 #define CONST_DEMO_MODE_DURATION 600          /* 10 min */
@@ -610,6 +618,7 @@
 #define LINE_PROTOCOL_MAX_LINE 512
 
 #define CONST_DEVICES_LEARNING_TIME 7200 /* 2 hours */
+#define CONST_HOST_PORT_LEARNING_TIME 7200 /* 2 hours */
 #define CONST_IEC104_LEARNING_TIME 21600 /* 6 hours */
 #define CONST_MODBUS_LEARNING_TIME 3600  /* 1 hour */
 #define CONST_INFLUXDB_KEY_EXPORTED_POINTS \
@@ -636,6 +645,10 @@
 #define CONST_DEFAULT_FLOWS_ONLY_INTERFACE false
 #define CONST_ALERT_DISABLED_PREFS \
   NTOPNG_PREFS_PREFIX ".disable_alerts_generation"
+#define CONST_PREFS_ENABLE_SNMP_POLLING \
+  NTOPNG_PREFS_PREFIX ".snmp_polling"
+#define CONST_PREFS_ENABLE_ACTIVE_MONITORING \
+  NTOPNG_PREFS_PREFIX ".active_monitoring"
 #define CONST_PREFS_ENABLE_ACCESS_LOG NTOPNG_PREFS_PREFIX ".enable_access_log"
 #define CONST_PREFS_ENABLE_SQL_LOG NTOPNG_PREFS_PREFIX ".enable_sql_log"
 #define CONST_TOP_TALKERS_ENABLED NTOPNG_PREFS_PREFIX ".host_top_sites_creation"
@@ -656,8 +669,6 @@
   NTOPNG_PREFS_PREFIX ".ifid_%d.is_flow_dump_disabled"
 #define CONST_LBD_SERIALIZATION_PREFS \
   NTOPNG_PREFS_PREFIX ".ifid_%d.serialize_local_broadcast_hosts_as_macs"
-#define CONST_DISCARD_PROBING_TRAFFIC \
-  NTOPNG_PREFS_PREFIX ".ifid_%d.discard_probing_traffic"
 #define CONST_FLOWS_ONLY_INTERFACE \
   NTOPNG_PREFS_PREFIX ".ifid_%d.debug.flows_only_interface"
 #define CONST_NBOX_USER NTOPNG_PREFS_PREFIX ".nbox_user"
@@ -702,6 +713,8 @@
   NTOPNG_PREFS_PREFIX ".enable_informative_captive_portal"
 #define CONST_PREFS_INFORM_URL \
   NTOPNG_PREFS_PREFIX ".informative_captive_portal_url"
+#define CONST_PREFS_EXTERNAL_AUTH \
+  NTOPNG_PREFS_PREFIX ".external_auth_captive_portal"
 #define CONST_PREFS_DEFAULT_L7_POLICY NTOPNG_PREFS_PREFIX ".default_l7_policy"
 #define CONST_PREFS_GLOBAL_DNS_FORGING_ENABLED \
   NTOPNG_PREFS_PREFIX ".global_dns_forging"
@@ -714,6 +727,7 @@
   NTOPNG_PREFS_PREFIX ".is_client_x509_auth_enabled"
 #define CONST_PREFS_EMIT_FLOW_ALERTS NTOPNG_PREFS_PREFIX ".emit_flow_alerts"
 #define CONST_PREFS_EMIT_HOST_ALERTS NTOPNG_PREFS_PREFIX ".emit_host_alerts"
+#define CONST_PREFS_TLS_QUIC_HOSTNAMING NTOPNG_PREFS_PREFIX ".tls_quic_hostnaming"
 
 #define CONST_PREFS_COLLECT_BLACKLISTSTATS NTOPNG_PREFS_PREFIX ".collect_blacklist_stats"
 #define CONST_BLACKLIST_DAILY_STATS        NTOPNG_CACHE_PREFIX ".bl_hosts.%s"
@@ -740,14 +754,47 @@
   NTOPNG_PREFS_PREFIX ".iec60870_learning_period"
 #define CONST_PREFS_MODBUS_ANALYSIS_LEARNING_PERIOD \
   NTOPNG_PREFS_PREFIX ".modbus_learning_period"
+#define CONST_PREFS_HOST_PORT_LEARNING_PERIOD \
+  NTOPNG_PREFS_PREFIX ".host_port_learning_period"
 #define CONST_PREFS_DEVICES_ANALYSIS_LEARNING_PERIOD \
   NTOPNG_PREFS_PREFIX ".devices_learning_period"
 
+
 #define CONST_DEFAULT_BEHAVIOUR_ANALYSIS_LEARNING_PERIOD \
   7200  // 2 hours by default
 
-#define CONST_PREFS_USE_MAC_IN_FLOW_KEY \
+#define CONST_PREFS_NETBOX_ENABLED \
+  NTOPNG_PREFS_PREFIX ".toggle_netbox"
+#define CONST_DEFAULT_NETBOX_ENABLED \
+  0  // disabled by default
+
+#define CONST_PREFS_NTOPNG_ASSETS_INVENTORY_ENABLED \
+  NTOPNG_PREFS_PREFIX ".toggle_ntopng_assets_inventory"
+#define CONST_DEFAULT_NTOPNG_ASSETS_INVENTORY_ENABLED \
+  0  // disabled by default
+  
+#define CONST_PREFS_NETBOX_ENABLED \
+  NTOPNG_PREFS_PREFIX ".toggle_netbox"
+#define CONST_DEFAULT_NETBOX_ENABLED \
+  0  // disabled by default
+  
+#define CONST_PREFS_ASSET_INVENTORY_ENABLED \
+  NTOPNG_PREFS_PREFIX ".toggle_asset_inventory" // same name as lua prefs.lua
+#define CONST_DEFAULT_ASSET_INVENTORY_ENABLED \
+  0  // disabled by default
+
+#define CONST_PREFS_SNMP_TRAP_ENABLED \
+  NTOPNG_PREFS_PREFIX ".toggle_snmp_trap" // same name as lua prefs.lua
+#define CONST_DEFAULT_SNMP_TRAP_ENABLED \
+  0  // disabled by default
+
+#define CONST_PREFS_USE_MAC_IN_FLOW_KEY		\
   NTOPNG_PREFS_PREFIX ".use_mac_in_flow_key"
+#define CONST_PREFS_FINGERPRINT_STATS \
+  NTOPNG_PREFS_PREFIX ".fingerprint_stats"
+
+#define CONST_PREFS_NETWORK_DISCOVERY_DEBUG \
+  NTOPNG_PREFS_PREFIX ".network_discovery_debug"
 
 #define CONST_USER_GROUP_ADMIN "administrator"
 #define CONST_USER_GROUP_UNPRIVILEGED "unprivileged"
@@ -762,30 +809,17 @@
 #define CONST_LOCAL_HOST_IDLE_PREFS NTOPNG_PREFS_PREFIX ".local_host_max_idle"
 
 #define CONST_VS_MAX_NUM_SCANS NTOPNG_PREFS_PREFIX ".host_to_scan_max_num_scans"
+#define CONST_VS_SLOW_SCAN NTOPNG_PREFS_PREFIX ".vs.vs_slow_scan"
 #define CONST_RUNTIME_MAX_UI_STRLEN NTOPNG_PREFS_PREFIX ".max_ui_strlen"
 #define CONST_RUNTIME_PREFS_TS_DRIVER NTOPNG_PREFS_PREFIX ".timeseries_driver"
 #define CONST_RUNTIME_IS_AUTOLOGOUT_ENABLED \
   NTOPNG_PREFS_PREFIX ".is_autologon_enabled"
 #define CONST_RUNTIME_IS_INTERFACE_NAME_ONLY \
   NTOPNG_PREFS_PREFIX ".is_interface_name_only"
-#define CONST_RUNTIME_IS_GEO_MAP_SCORE_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_score_enabled"
 #define CONST_MAX_AGGREGATED_FLOWS_UPPERBOUND \
   NTOPNG_PREFS_PREFIX ".max_aggregated_flows_upperbound"
 #define CONST_MAX_AGGREGATED_FLOWS_TRAFFIC_UPPERBOUND \
   NTOPNG_PREFS_PREFIX ".max_aggregated_flows_traffic_upperbound"
-#define CONST_RUNTIME_IS_GEO_MAP_ASNAME_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_asname_enabled"
-#define CONST_RUNTIME_IS_GEO_MAP_ALERTED_FLOWS_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_alerted_flows_enabled"
-#define CONST_RUNTIME_IS_GEO_MAP_BLACKLISTED_FLOWS_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_blacklisted_flows_enabled"
-#define CONST_RUNTIME_IS_GEO_MAP_HOST_NAME_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_host_name_enabled"
-#define CONST_RUNTIME_IS_GEO_MAP_RXTX_DATA_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_rxtx_data_enabled"
-#define CONST_RUNTIME_IS_GEO_MAP_NUM_FLOWS_ENABLED \
-  NTOPNG_PREFS_PREFIX ".is_geo_map_num_flows_enabled"
 #define CONST_RUNTIME_ACTIVE_LOCAL_HOSTS_CACHE_ENABLED \
   NTOPNG_PREFS_PREFIX ".is_active_local_host_cache_enabled"
 #define CONST_RUNTIME_ACTIVE_LOCAL_HOSTS_CACHE_INTERVAL \
@@ -886,6 +920,7 @@
 #define CONST_LOOPBACK_ADDRESS "127.0.0.1"
 #define CONST_EPP_MAX_CMD_NUM 34
 #define CONST_DEFAULT_MAX_PACKET_SIZE 1522
+#define CONST_MAX_PACKET_SIZE         65535 /* https://wiki.wireshark.org/MTU */
 
 /* ARP matrix generation preferences */
 #define CONST_DEFAULT_ARP_MATRIX_GENERATION \
@@ -1058,6 +1093,25 @@
 #define STORE_MANAGER_MAX_QUERY 2048
 #define STORE_MANAGER_MAX_KEY 20
 #define DEFAULT_GLOBAL_DNS ""
+
+/* MESSAGE BROKER CONSTS */
+
+#define CONST_PREFS_MESSAGE_BROKER_URL \
+  NTOPNG_PREFS_PREFIX ".message_broker_url"
+#define DEFAULT_MESSAGE_BROKER_URL "0.0.0.0:4222"
+
+#define BROKER_RPC_CALL_DEFAULT_TIMEOUT_MS (u_int64_t)10000
+#define BROKER_RPC_CALL_MAX_RSP_LEN (u_int64_t)256
+
+/* IMPORTANT Keep in Sync with brokers_list of prefs.lua */
+#define CONST_NATS_M_BROKER_ID "nats"
+#define CONST_MQTT_M_BROKER_ID "mqtt"
+
+#define CONST_PREFS_MESSAGE_BROKER \
+  NTOPNG_PREFS_PREFIX ".message_broker"
+#define DEFAULT_MESSAGE_BROKER CONST_NATS_M_BROKER_ID
+
+/* ********************* */
 #define DEFAULT_DATE_TYPE "middle_endian"
 #define DEFAULT_SAFE_SEARCH_DNS "208.67.222.123" /* OpenDNS Family Shield */
 
@@ -1180,6 +1234,7 @@
 #define PREF_RADIUS_ADMIN_GROUP NTOPNG_PREFS_PREFIX ".radius.radius_admin_group"
 #define PREF_RADIUS_UNPRIV_CAP_GROUP \
   NTOPNG_PREFS_PREFIX ".radius.radius_unpriv_capabilties_group"
+#define PREF_RADIUS_EXT_AUTHE_LOCAL_AUTHO NTOPNG_PREFS_PREFIX ".radius.external_auth_for_local_users_enabled"
 
 #ifdef HAVE_RADIUS
 #define MAX_RADIUS_LEN 256
@@ -1249,7 +1304,7 @@
 
 #define HTTP_MAX_CONTENT_TYPE_LENGTH 63
 #define HTTP_MAX_HEADER_LINES 20
-#define HTTP_MAX_POST_DATA_LEN (1 << 17) /* 128K */
+#define HTTP_MAX_POST_DATA_LEN (1 << 19) /* 128K */
 #define HTTP_CONTENT_TYPE_HEADER "Content-Type: "
 #define CONST_HELLO_HOST "hello"
 
@@ -1303,10 +1358,13 @@
 #define DROP_HOST_POOL_PRE_JAIL_POOL \
   NTOPNG_PREFS_PREFIX ".jail.pre_jail_pool.%s"
 
-extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
+#ifdef __cplusplus
+class NtopngLuaContext; /* Forward */
+extern NtopngLuaContext* getUserdata(struct lua_State *vm);
 #define getLuaVMContext(a) (a ? getUserdata(a) : NULL)
 #define getLuaVMUserdata(a, b) (a ? getUserdata(a)->b : NULL)
 #define getLuaVMUservalue(a, b) getUserdata(a)->b
+#endif
 
 /*
    We assume that a host with more than CONST_MAX_NUM_HOST_USES
@@ -1318,13 +1376,22 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
 
 /* Keep in sync with nProbe */
 #define MAX_ZMQ_FLOW_BUF 16384
-#define DEFAULT_ZMQ_TCP_KEEPALIVE 1       /* Keepalive ON */
-#define DEFAULT_ZMQ_TCP_KEEPALIVE_IDLE 30 /* Keepalive after 30 seconds */
-#define DEFAULT_ZMQ_TCP_KEEPALIVE_CNT 3   /* Keepalive send 3 probes */
-#define DEFAULT_ZMQ_TCP_KEEPALIVE_INTVL \
-  3 /* Keepalive probes sent every 3 seconds */
+#define DEFAULT_ZMQ_TCP_KEEPALIVE        1 /* Keepalive ON */
+#define DEFAULT_ZMQ_TCP_KEEPALIVE_IDLE  30 /* Keepalive after 30 seconds */
+#define DEFAULT_ZMQ_TCP_KEEPALIVE_CNT    3 /* Keepalive send 3 probes */
+#define DEFAULT_ZMQ_TCP_KEEPALIVE_INTVL  3 /* Keepalive probes sent every 3 seconds */
+
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_M  16
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_L  32
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XL 128
+
+#define MIN_NUM_ASYNC_SNMP_ENGINES         NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_M
+#define MAX_NUM_ASYNC_SNMP_ENGINES         NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XL
+
+#if defined(NTOPNG_PRO) && defined(HAVE_LIBSNMP)
+#define HAVE_SNMP_TRAP
+#endif
 
-#define MAX_NUM_ASYNC_SNMP_ENGINES 64
 #define MIN_NUM_HASH_WALK_ELEMS 512
 
 #define COMPANION_QUEUE_LEN 4096
@@ -1384,6 +1451,8 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
 
 #define UNKNOWN_FLOW_DIRECTION 2
 
+#define UNKNOWN_PKT_IFACE_IDX  -1
+
 /******************************************************************************/
 
 /* ClickHouse */
@@ -1392,8 +1461,9 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
   Also on FreeBSD the tool is installed on /usr/bin and not /usr/local/bin
   when installed as specified on https://clickhouse.com/#quick-start
 */
-#define CLICKHOUSE_CLIENT "/usr/bin/clickhouse-client"
-#define CLICKHOUSE_ALT_CLIENT "/usr/local/bin/clickhouse-client"
+#define CLICKHOUSE_CLIENT "clickhouse-client"
+#define CLICKHOUSE_ALT_CLIENT "clickhouse"
+#define CLICKHOUSE_ALT_CLIENT_CMD "clickhouse client"
 
 #define CLICKHOUSE_DUMP_PERF_MAX_RECORDS 1000
 #define CLICKHOUSE_DUMP_PERF_NUM_LOOPS 500000
@@ -1470,10 +1540,11 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
 #define INTERFACE_PROFILING_SUB_SECTION_EXIT(f, i)
 #endif
 
-#define MAX_NUM_CONCURRENT_JOBS  8
-#define MAX_NUM_QUEUED_JOBS      256
+#define MAX_NUM_CONCURRENT_JOBS    8
+#define MAX_NUM_QUEUED_JOBS        256
+#define CONST_MAX_NUM_QUEUED_PORTS 8
 
-#define SIMULATE_VLANS_MAX_VALUE 0x8 /* 8 in hexadecimal */
+#define SIMULATE_VLANS_MAX_VALUE 0xa /* 10 in hexadecimal */
 
 #define CHECKS_PROFILING
 #if defined(PROFILING) && defined(CHECKS_PROFILING)
@@ -1504,6 +1575,8 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
   "ntopng.checks.iec104_invalid_transition_enabled"
 #define CHECKS_MODBUS_INVALID_TRANSITION \
   "ntopng.checks.modbus_invalid_transition_enabled"
+#define CHECKS_MODBUS_TOO_MANY_EXCEPTIONS \
+  "ntopng.checks.modbus_too_many_exceptions"
 
 #define CUSTOM_FLOW_NDPI_SCRIPT \
   "scripts/callbacks/checks/flows/custom_flow_protocol_detected_script.lua"
@@ -1513,6 +1586,13 @@ extern struct ntopngLuaContext *getUserdata(struct lua_State *vm);
   "scripts/callbacks/checks/flows/custom_flow_end_script.lua"
 
 #define OFFLINE_LOCAL_HOSTS_KEY "ntopng.hosts.offline.ifid_%d"
+#define EXPORTERS_EXCEEDED_LIMITS_KEY "ntopng.limits.exporters"
+
+#define MAX_NUM_PCAP_INTERFACES 8
+
+#define NO_VLAN (u_int16_t)-1
+#define NO_IN_IF_INDEX (u_int32_t)-1
+#define NO_OUT_IF_INDEX (u_int32_t)-1
 /******************************************************************************/
 
 #endif /* _NTOP_DEFINES_H_ */
