@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -123,6 +123,7 @@
 #define BGP_PREV_ADJACENT_ASN 129
 #define EXPORTER_IPV4_ADDRESS 130
 #define EXPORTER_IPV6_ADDRESS 131
+#define FLOW_END_REASON 136
 #define FLOW_ID 148
 #define FLOW_START_SEC 150
 #define FLOW_END_SEC 151
@@ -145,8 +146,8 @@
 #define BIFLOW_DIRECTION 239
 #define POST_NAT_SRC_IPV4_ADDR 225
 #define POST_NAT_DST_IPV4_ADDR 226
-#define POST_NAPT_SRC_TRANSPORT_PORT 227
-#define POST_NAPT_DST_TRANSPORT_PORT 228
+#define POST_NAT_SRC_TRANSPORT_PORT 227
+#define POST_NAT_DST_TRANSPORT_PORT 228
 #define OBSERVATION_POINT_TYPE 277
 #define INITIATOR_PKTS 298
 #define RESPONDER_PKTS 299
@@ -237,8 +238,6 @@
 #define DOWNSTREAM_SESSION_ID NTOP_BASE_ID + 447
 #define TLS_SERVER_NAME NTOP_BASE_ID + 188
 #define BITTORRENT_HASH NTOP_BASE_ID + 189
-#define JA3C_HASH NTOP_BASE_ID + 489
-#define JA3S_HASH NTOP_BASE_ID + 490
 #define TLS_CIPHER NTOP_BASE_ID + 493
 #define SSL_UNSAFE_CIPHER NTOP_BASE_ID + 494
 #define L7_PROTO_RISK NTOP_BASE_ID + 509
@@ -247,6 +246,8 @@
 #define FLOW_VERDICT NTOP_BASE_ID + 522
 #define L7_ERROR_CODE NTOP_BASE_ID + 554
 #define L7_RISK_INFO NTOP_BASE_ID + 555
+#define JA4C_HASH NTOP_BASE_ID + 576
+#define FLOW_SOURCE  NTOP_BASE_ID+579 /* 0 = packets, 1 = collected NetFlow/IPFIX, 2 = collected sFlow/nfLite */
 
 /* eBPF / Process */
 #define SRC_PROC_PID NTOP_BASE_ID + 168
@@ -556,6 +557,10 @@
 #define FLOW_TIME NTOP_BASE_ID + 532
 #define PROFILE NTOP_BASE_ID + 533
 #define STATUS NTOP_BASE_ID + 534
+#define MAJOR_CONNECTION_STATE NTOP_BASE_ID + 535
+#define MINOR_CONNECTION_STATE NTOP_BASE_ID + 536
+#define L7_SERVICE NTOP_BASE_ID+582
+#define UNIQUE_SOURCE_ID NTOP_BASE_ID+589 /* Unique nProbe + exporter flow source identifier */
 
 /* sFlow Counter Fields */
 #define SFLOW_DEVICE_IP 0
