@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -177,6 +177,10 @@ https://translate.google.co.uk/translate?sl=auto&tl=en&u=http%3A%2F%2Fbugsfixed.
 #include <sys/capability.h>
 #include <sys/prctl.h>
 #endif
+
+#if defined(HAVE_NATS)
+#include <nats/nats.h>
+#endif
 };
 
 #include <fstream>
@@ -201,6 +205,7 @@ https://translate.google.co.uk/translate?sl=auto&tl=en&u=http%3A%2F%2Fbugsfixed.
 #include <sstream>
 #include <queue>
 #include <typeinfo>
+#include <thread>
 
 using namespace std;
 
@@ -220,6 +225,7 @@ using namespace std;
 #include "Cardinality.h"
 #include "PeerStats.h"
 #include "IpAddress.h"
+#include "nProbeStats.h"
 #include "Ping.h"
 #include "JobQueue.h"
 #include "ContinuousPingStats.h"
@@ -292,20 +298,24 @@ using namespace std;
 #include "FlowProfiles.h"
 #include "SubInterface.h"
 #include "SubInterfaces.h"
-#endif
+#endif /* HAVE_NEDGE */
 #include "CounterTrend.h"
 #include "LRUMacIP.h"
 #include "FlowInterfacesStats.h"
 #ifdef HAVE_LDAP
 #include "LdapAuthenticator.h"
-#endif
-#endif
+#endif /* HAVE_LDAP */
+#endif /* NTOPNG_PRO */
 #include "HostPoolStats.h"
 #include "HostPools.h"
 #include "Fingerprint.h"
 #include "Prefs.h"
 #include "DnsStats.h"
+#include "SNMPSession.h"
 #include "SNMP.h"
+#ifdef HAVE_SNMP_TRAP
+#include "SNMPTrap.h"
+#endif
 #include "NetworkDiscovery.h"
 #include "ICMPstats.h"
 #include "ICMPinfo.h"
@@ -341,11 +351,13 @@ using namespace std;
 #include <radcli/radcli.h>
 #endif
 
+#include "ServerPortsBitmap.h"
 #include "Condvar.h"
 #include "TimeseriesExporter.h"
 #include "InfluxDBTimeseriesExporter.h"
 #include "L4Stats.h"
 #include "AlertsQueue.h"
+#include "NtopngLuaContext.h"
 #include "LuaEngineFunctions.h"
 #include "LuaEngine.h"
 #include "SPSCQueue.h"
@@ -375,6 +387,7 @@ using namespace std;
 #include "FlowsHostInfo.h"
 #include "AggregatedFlowsStats.h"
 #include "NetworkInterface.h"
+#include "NtopngLuaContext.h"
 #ifndef HAVE_NEDGE
 #include "PcapInterface.h"
 #endif
@@ -404,6 +417,7 @@ using namespace std;
 #include "ClickHouseAlertStore.h"
 #endif
 #ifdef NTOPNG_PRO
+#include "NtopCloud.h"
 #include "NtopPro.h"
 #include "DnsHostMapping.h"
 #include "TrafficShaper.h"
@@ -429,6 +443,9 @@ using namespace std;
 #include "ZCCollectorInterface.h"
 #include "DummyInterface.h"
 #include "ExportInterface.h"
+#if defined(NTOPNG_PRO) && defined(HAVE_CLICKHOUSE)
+#include "ClickHouseInterface.h"
+#endif
 #endif
 
 #if defined(HAVE_KAFKA) && defined(NTOPNG_PRO)
@@ -457,6 +474,8 @@ using namespace std;
 #ifdef NTOPNG_PRO
 #include "AssetManagement.h"
 #include "ModbusStats.h"
+#include "MessageBroker.h"
+#include "NatsBroker.h"
 #endif
 #include "IEC104Stats.h"
 #include "Flow.h"
@@ -469,6 +488,7 @@ using namespace std;
 #include "HostHash.h"
 #include "ThreadedActivityStats.h"
 #include "ThreadedActivity.h"
+#include "QueuedThreadData.h"
 #include "ThreadPool.h"
 #include "PeriodicScript.h"
 #include "PeriodicActivities.h"
@@ -488,8 +508,11 @@ using namespace std;
 #include "HostChecksLoader.h"
 #include "HostChecksExecutor.h"
 #ifdef HAVE_NEDGE
+#include "PacketForwarder.h"
 #include "MulticastForwarder.h"
+#include "BroadcastForwarder.h"
 #endif
+
 #include "Radius.h"
 #include "Ntop.h"
 
@@ -497,4 +520,6 @@ using namespace std;
 #include "ntoppro_defines.h"
 #endif
 
+extern bool trace_new_delete;
+
 #endif /* _NTOP_H_ */
