@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -54,6 +54,13 @@ typedef enum {
   mask_remote_hosts = 2
 } HostMask;
 
+/* Keep it in sync with nProbe */
+typedef enum {
+  packet_to_flow = 0,          /* packet capture or nTap  */
+  collected_netflow_ipfix = 1, /* collected NetFlow/IPFIX */
+  collected_sflow = 2          /* collected sFlow/nfLite  */
+} FlowSource;
+
 /* Struct used to pass parameters when walking hosts and flows periodically to
  * update their stats */
 class AlertCheckLuaEngine;
@@ -120,6 +127,12 @@ typedef enum {
 
 #define MAX_NUM_PERIODIC_SCRIPTS 6
 
+typedef enum {
+  lua_engine_mode_http = 1,
+  lua_engine_mode_callback,
+  lua_engine_mode_cloud
+} LuaEngineMode;
+
 typedef enum {
   trend_unknown = 0,
   trend_up = 1,
@@ -227,6 +240,7 @@ typedef enum {
   alert_entity_test = 10,
   alert_entity_asn = 11,
   alert_entity_l7 = 12,
+  alert_entity_mitre_table_info = 13,
 
   /* Add new entities above ^ and do not exceed alert_entity_other */
   alert_entity_other = 15,
@@ -351,29 +365,13 @@ typedef struct {
   u_int32_t remapped_app_id;
 } custom_app_t;
 
+PACK_ON struct l2tp_header {
+  u_int16_t flags, tunnel_id, session_id;
+} PACK_OFF;
+
 /* IMPORTANT: whenever the Parsed_FlowSerial is changed, nProbe must be updated
  * too */
 
-typedef struct zmq_remote_stats {
-  char remote_ifname[32], remote_ifaddress[64];
-  char remote_probe_address[64], remote_probe_public_address[64];
-  char remote_probe_version[64], remote_probe_os[64];
-  char remote_probe_license[64], remote_probe_edition[64];
-  char remote_probe_maintenance[64];
-  u_int32_t source_id, num_exporters;
-  u_int64_t remote_bytes, remote_pkts, num_flow_exports;
-  u_int32_t remote_ifspeed, remote_time, local_time, avg_bps, avg_pps;
-  u_int32_t remote_lifetime_timeout, remote_idle_timeout,
-      remote_collected_lifetime_timeout;
-  u_int32_t export_queue_full, too_many_flows, elk_flow_drops,
-      sflow_pkt_sample_drops, flow_collection_drops,
-      flow_collection_udp_socket_drops;
-  struct {
-    u_int64_t nf_ipfix_flows;
-    u_int64_t sflow_samples;
-  } flow_collection;
-} ZMQ_RemoteStats;
-
 typedef struct zmq_template {
   u_int32_t pen, field;
   const char *format, *name, *descr;
@@ -432,11 +430,11 @@ typedef enum {
   flow_alert_dns_data_exfiltration = 6,
   flow_alert_dns_invalid_query = 7,
   flow_alert_elephant_flow = 8,
-  flow_alert_notused_1 = 9,
+  flow_alert_blacklisted_client_contact = 9,
   flow_alert_external = 10,
   flow_alert_longlived = 11,
   flow_alert_low_goodput = 12,
-  flow_alert_notused_2 = 13,
+  flow_alert_blacklisted_server_contact = 13,
   flow_alert_internals = 14,
   flow_alert_notused_3 = 15,
   flow_alert_remote_to_remote = 16,
@@ -522,6 +520,9 @@ typedef enum {
   flow_alert_ndpi_fully_encrypted = 96,
   flow_alert_ndpi_tls_alpn_sni_mismatch = 97,
   flow_alert_ndpi_malware_host_contacted = 98,
+  flow_alert_ndpi_binary_data_transfer = 99,
+  flow_alert_tcp_flow_reset = 100,
+  flow_alert_ndpi_probing_attempt = 101,
   
   MAX_DEFINED_FLOW_ALERT_TYPE, /* Leave it as last member */
 
@@ -552,18 +553,18 @@ typedef enum {
   host_alert_syn_scan = 5,
   host_alert_syn_flood = 6,
   host_alert_domain_names_contacts = 7,
-  host_alert_p2p_traffic = 8,
-  host_alert_dns_traffic = 9,
+  host_alert_notused_1 = 8,
+  host_alert_notused_2 = 9,
   host_alert_flows_anomaly = 10,
   host_alert_score_anomaly = 11,
   host_alert_remote_connection = 12,
   host_alert_host_log = 13,
   host_alert_dangerous_host = 14,
-  host_alert_ntp_traffic = 15,
+  host_alert_notused_3 = 15,
   host_alert_countries_contacts = 16,
   host_alert_score_threshold = 17,
   host_alert_icmp_flood = 18,
-  host_alert_pkt_threshold = 19,
+  host_alert_notused_4 = 19,
   host_alert_scan_detected = 20,
   host_alert_fin_scan = 21,
   host_alert_dns_flood = 22,
@@ -572,11 +573,19 @@ typedef enum {
   host_alert_rst_scan = 25,
   host_alert_traffic_volume = 26,
   host_alert_external_script = 27, /* Triggered from Lua (see rest/v2/trigger/host/alert.lua) */
+  host_alert_host_scanner = 28,
+  host_alert_server_ports_contacts = 29,
 
   MAX_DEFINED_HOST_ALERT_TYPE, /* Leave it as last member */
   MAX_HOST_ALERT_TYPE = 32     /* Constrained by HostAlertBitmap */
 } HostAlertTypeEnum;
 
+/* Note: "other" alerts (other than flow, host) are defined in Lua */
+/* keep the below in sync with other_alert_keys.lua */
+#define MAX_OTHER_ALERT_TYPE 127
+#define OTHER_BASE_KEY 4096
+#define MAX_DEFINED_OTHER_ALERT_TYPE (MAX_OTHER_ALERT_TYPE+1)
+
 typedef struct {
   HostAlertTypeEnum id;
   AlertCategory category;
@@ -597,17 +606,13 @@ typedef enum {
   host_check_countries_contacts,
   host_check_dns_server_contacts,
   host_check_score_host,
-  host_check_p2p_traffic,
-  host_check_dns_traffic,
   host_check_flow_anomaly,
   host_check_score_anomaly,
   host_check_remote_connection,
   host_check_dangerous_host,
-  host_check_ntp_traffic,
   host_check_domain_names_contacts,
   host_check_score_threshold,
   host_check_icmp_flood,
-  host_check_pkt_threshold,
   host_check_scan_detection,
   host_check_mac_reassociation,
   host_check_fin_scan,
@@ -618,6 +623,9 @@ typedef enum {
   host_check_traffic_volume, /* Dummy check (see
                                 ntop_interface_update_ip_reassignment) */
   host_check_external_script,
+  host_check_host_scanner,
+  host_check_rx_only_host_scan,
+  host_check_server_ports_contacts,
 
   NUM_DEFINED_HOST_CHECKS, /* Leave it as last member */
 } HostCheckID;
@@ -661,6 +669,7 @@ typedef enum {
   column_vlan,
   column_proto_l4,
   column_ndpi,
+  column_protocol,
   column_duration,
   column_thpt,
   column_bytes,
@@ -883,79 +892,6 @@ typedef struct {
   u_int8_t num_replies_ok, num_replies_error;
 } FlowDNSStats;
 
-/* Forward class declarations for the Lua context */
-class NetworkStats;
-class Host;
-class Flow;
-class ThreadedActivity;
-class ThreadedActivityStats;
-
-struct ntopngLuaContext {
-  char *allowed_ifname, *user, *group, *csrf;
-  char *sqlite_hosts_filter, *sqlite_flows_filter;
-  bool sqlite_filters_loaded;
-  void *zmq_context, *zmq_subscriber;
-  struct mg_connection *conn;
-  AddressTree *allowedNets;
-  NetworkInterface *iface;
-  AddressTree *addr_tree;
-  SNMP *snmpBatch, *snmpAsyncEngine[MAX_NUM_ASYNC_SNMP_ENGINES];
-  Host *host;
-  NetworkStats *network;
-  Flow *flow;
-  bool localuser;
-  u_int16_t observationPointId;
-
-  /* Capabilities bitmap */
-  u_int64_t capabilities;
-
-  /* Packet capture */
-  struct {
-    bool captureInProgress;
-    pthread_t captureThreadLoop;
-    pcap_t *pd;
-    pcap_dumper_t *dumper;
-    u_int32_t end_capture;
-  } pkt_capture;
-
-  /* Live capture written to mongoose socket */
-  struct {
-    u_int32_t capture_until, capture_max_pkts, num_captured_packets;
-    void *matching_host;
-    bool bpfFilterSet;
-    struct bpf_program fcode;
-
-    /* Status */
-    bool pcaphdr_sent;
-    bool stopped;
-
-    /* Partial sends */
-    char send_buffer[1600];
-    u_int data_not_yet_sent_len; /*
-                                    Amount of data that was
-                                    not sent mostly due to
-                                    socket buffering
-                                 */
-  } live_capture;
-
-  /*
-     Indicate the time when the vm will be reloaded.
-     This can be used so that Lua scripts running in an infinite-loop fashion,
-     e.g., notifications.lua, can know when to break so they can be reloaded
-     with new configurations. Useful when user scripts change or when recipient
-     configurations change.
-   */
-  time_t next_reload;
-  /* Periodic scripts (ThreadedActivity.cpp) */
-  time_t deadline;
-  const ThreadedActivity *threaded_activity;
-  ThreadedActivityStats *threaded_activity_stats;
-
-#if defined(NTOPNG_PRO)
-  BinAnalysis *bin;
-#endif
-};
-
 typedef enum {
   lan_interface = 1,
   wan_interface,
@@ -982,7 +918,8 @@ typedef enum {
   interface_type_DIVERT,
   interface_type_DUMMY,
   interface_type_ZC_FLOW,
-  interface_type_SYSLOG
+  interface_type_SYSLOG,
+  interface_type_DB_VIEW
 } InterfaceType;
 
 /* Update Flow::dissectHTTP when extending the type below */
@@ -1209,10 +1146,20 @@ typedef struct {
 } InOutTraffic;
 
 typedef struct {
-  u_int64_t bytes_sent;
-  u_int64_t bytes_rcvd;
-  u_int64_t packets_sent;
-  u_int64_t packets_rcvd;
+  /* All int32 because following the rfc, they use 32 bits */
+  /* See: https://datatracker.ietf.org/doc/html/rfc2866 */
+  char *mac;
+  char *last_ip;
+  char *username;
+  char *session_id;
+  char *nas_port_name;
+  u_int32_t nas_port_id;
+  u_int32_t bytes_sent;
+  u_int32_t bytes_rcvd;
+  u_int32_t packets_sent;
+  u_int32_t packets_rcvd;
+  u_int32_t terminate_cause;
+  u_int32_t time;
 } RadiusTraffic;
 
 typedef enum {
@@ -1223,8 +1170,32 @@ typedef enum {
   client_server_criteria,
   app_client_server_criteria,
   info_criteria,
-  client_server_srv_port
+  client_server_srv_port,
+  client_server_srv_port_app_proto
 } AnalysisCriteria;
 
+typedef enum {
+  MINOR_NO_STATE = 0, /* Initial Flow State (just for constructor) */
+  S0,           /* Only SYN in src2dst_tcp_flags; no flags in dst2src_tcp_flags */
+  S1,           /* ... */
+  SF,
+  REJ,
+  S2,
+  S3,
+  RSTO,
+  RSTR,
+  RSTOS0,
+  RSTRH,
+  SH,
+  SHR,
+  OTH = 13
+} MinorConnectionStates;
 
+typedef enum {
+  MAJOR_NO_STATE = 0, 
+  ATTEMPTED,
+  ESTABLISHED,
+  CLOSED = 3
+} MajorConnectionStates;
+  
 #endif /* _NTOP_TYPEDEFS_H_ */
