@@ -1,6 +1,10 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
+
+local dirs = ntop.getDirs()
+package.path = dirs.installdir .. "/scripts/lua/modules/timeseries/?.lua;" .. package.path
+
 local ts_utils = require "ts_utils_core"
 local schema
 
@@ -28,37 +32,6 @@ schema:addTag("periodic_script")
 schema:addMetric("writes")
 schema:addMetric("drops")
 
--------------------------------------------------------
--- TRAFFIC ELEMENTS CHECKS SCHEMAS
--------------------------------------------------------
-
-schema = ts_utils.newSchema("elem_check:duration", {
-    step = 60,
-    metrics_type = ts_utils.metrics.gauge
-})
-schema:addTag("ifid")
-schema:addTag("check")
-schema:addTag("subdir")
-schema:addMetric("num_ms")
-
-schema = ts_utils.newSchema("elem_check:num_calls", {
-    step = 60,
-    metrics_type = ts_utils.metrics.gauge
-})
-schema:addTag("ifid")
-schema:addTag("check")
-schema:addTag("subdir")
-schema:addMetric("num_calls")
-
-schema = ts_utils.newSchema("elem_check:total_stats", {
-    step = 60,
-    metrics_type = ts_utils.metrics.gauge
-})
-schema:addTag("ifid")
-schema:addTag("subdir")
-schema:addMetric("num_ms")
-schema:addMetric("num_calls")
-
 -------------------------------------------------------
 -- HASH_TABLES SCHEMAS
 -------------------------------------------------------
@@ -748,3 +721,19 @@ schema = ts_utils.newSchema("redis:hits", {
 schema:addTag("ifid")
 schema:addTag("command")
 schema:addMetric("num_calls")
+
+-- ################################################
+
+-- SNMP
+schema = ts_utils.newSchema("snmp_if:traffic_min", {
+    step = 60,
+    rrd_heartbeat = 600,
+    rrd_fname = "bytes_per_minute",
+    is_system_schema = true
+})
+schema:addTag("ifid")
+schema:addTag("device")
+schema:addTag("if_index")
+schema:addMetric("bytes_sent")
+schema:addMetric("bytes_rcvd")
+
