@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,17 +24,20 @@
 /* **************************************** */
 
 AddressResolution::AddressResolution(int _num_resolvers) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   num_resolved_addresses = num_resolved_fails = 0;
   num_resolvers = _num_resolvers;
 
-  if (!(resolveThreadLoop =
-            (pthread_t *)calloc(num_resolvers, sizeof(pthread_t))))
+  if (!(resolveThreadLoop = (pthread_t *)calloc(num_resolvers, sizeof(pthread_t))))
     throw 2;
 }
 
 /* **************************************** */
 
 AddressResolution::~AddressResolution() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if (ntop->getPrefs() && ntop->getPrefs()->is_dns_resolution_enabled()) {
     for (int i = 0; i < num_resolvers; i++) {
       if (resolveThreadLoop[i]) pthread_join(resolveThreadLoop[i], NULL);
@@ -120,10 +123,9 @@ void AddressResolution::resolveHostName(const char *_numeric_ip, char *symbolic,
         inet_pton(AF_INET6, numeric_ip, &in6.sin6_addr);
         len = sizeof(struct sockaddr_in6), sa = (struct sockaddr *)&in6;
       } else {
-        ntop->getTrace()->traceEvent(
-            TRACE_INFO,
-            "Invalid IPv6 address to resolve '%s': already symbolic?",
-            numeric_ip);
+        ntop->getTrace()->traceEvent(TRACE_INFO,
+				     "Invalid IPv6 address to resolve '%s': already symbolic?",
+				     numeric_ip);
         return; /* Invalid format */
       }
     } else {
@@ -147,7 +149,7 @@ void AddressResolution::resolveHostName(const char *_numeric_ip, char *symbolic,
       ntop->getRedis()->setResolvedAddress(numeric_ip, hostname);
       if ((symbolic != NULL) && (symbolic_len > 0))
         snprintf(symbolic, symbolic_len, "%s", hostname);
-      ntop->getTrace()->traceEvent(TRACE_INFO, "Resolved %s to %s", numeric_ip,
+      ntop->getTrace()->traceEvent(TRACE_DEBUG, "Resolved %s to %s", numeric_ip,
                                    hostname);
       m.lock(__FILE__, __LINE__);
       num_resolved_addresses++;
