@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,26 +27,13 @@
 
 AutonomousSystem::AutonomousSystem(NetworkInterface *_iface, IpAddress *ipa)
     : GenericHashEntry(_iface), GenericTrafficElement(), Score(_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   asname = NULL;
   round_trip_time = 0;
   alerted_flows_as_client = alerted_flows_as_server = 0;
 #ifdef NTOPNG_PRO
   nextMinPeriodicUpdate = 0;
-
-#if 0
-  score_behavior = NULL;
-  traffic_tx_behavior = NULL;
-  traffic_rx_behavior = NULL;
-
-  if (ntop->getPrefs()->isASNBehavourAnalysisEnabled()) {
-    score_behavior = new BehaviorAnalysis();
-    traffic_tx_behavior = new BehaviorAnalysis(
-					       0.9 /* Alpha parameter *///, 0.1 /* Beta parameter */,
-					       0.05 /* Significance */, true /* Counter */);
-    traffic_rx_behavior = new BehaviorAnalysis(0.9 /* Alpha parameter */, 0.1 /* Beta parameter */,
-					       0.05 /* Significance */, true /* Counter */);
-  }
-#endif
 					       
 #endif
   ntop->getGeolocation()->getAS(ipa, &asn, &asname);
@@ -64,15 +51,10 @@ void AutonomousSystem::set_hash_entry_state_idle() { ; /* Nothing to do */ }
 /* *************************************** */
 
 AutonomousSystem::~AutonomousSystem() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   if (asname) free(asname);
     /* TODO: decide if it is useful to dump AS stats to redis */
-/*
-#ifdef NTOPNG_PRO
-  if (score_behavior) delete (score_behavior);
-  if (traffic_tx_behavior) delete (traffic_tx_behavior);
-  if (traffic_rx_behavior) delete (traffic_rx_behavior);
-#endif
-*/
+
 #ifdef AS_DEBUG
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "Deleted Autonomous System %u",
                                asn);
@@ -144,15 +126,7 @@ void AutonomousSystem::lua(lua_State *vm, DetailsLevel details_level,
   lua_pushstring(vm, "alerted_flows");
   lua_insert(vm, -2);
   lua_settable(vm, -3);
-/*
-#ifdef NTOPNG_PRO
-  if (traffic_rx_behavior)
-    traffic_rx_behavior->luaBehavior(vm, "traffic_rx_behavior");
-  if (traffic_tx_behavior)
-    traffic_tx_behavior->luaBehavior(vm, "traffic_tx_behavior");
-  if (score_behavior) score_behavior->luaBehavior(vm, "score_behavior");
-#endif
-*/
+
   Score::lua_get_score(vm);
   Score::lua_get_score_breakdown(vm);
 
@@ -181,34 +155,6 @@ void AutonomousSystem::updateStats(const struct timeval *tv) {
 
 #ifdef NTOPNG_PRO
 
-void AutonomousSystem::updateBehaviorStats(const struct timeval *tv) {
-  /* 5 Min Update */
-  if (tv->tv_sec >= nextMinPeriodicUpdate) {
-#if 0
-    char score_buf[256], tx_buf[128], rx_buf[128];
-
-    /* Traffic behavior stats update, currently score, traffic rx and tx */
-    if (score_behavior) {
-      snprintf(score_buf, sizeof(score_buf), "AS %d | score", asn);
-      score_behavior->updateBehavior(iface, getScore(), score_buf,
-                                     (asn ? true : false));
-    }
-
-    if (traffic_tx_behavior) {
-      snprintf(tx_buf, sizeof(tx_buf), "AS %d | traffic tx", asn);
-      traffic_tx_behavior->updateBehavior(iface, getNumBytesSent(), tx_buf,
-                                          (asn ? true : false));
-    }
-
-    if (traffic_rx_behavior) {
-      snprintf(rx_buf, sizeof(rx_buf), "AS %d | traffic rx", asn);
-      traffic_rx_behavior->updateBehavior(iface, getNumBytesRcvd(), rx_buf,
-                                          (asn ? true : false));
-    }
-#endif
-
-    nextMinPeriodicUpdate = tv->tv_sec + ASES_BEHAVIOR_REFRESH;
-  }
-}
+void AutonomousSystem::updateBehaviorStats(const struct timeval *tv) {}
 
 #endif
