@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,8 @@
  * @param num_tot_elems The bitmask size in number of bit.
  */
 Bitmask::Bitmask(u_int32_t num_tot_elems) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   tot_elems = num_tot_elems;
   num_elems = tot_elems / 8;
 
@@ -53,6 +55,7 @@ Bitmask::Bitmask(u_int32_t num_tot_elems) {
  * Destructor.
  */
 Bitmask::~Bitmask() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   if (bits) free(bits);
 }
 
@@ -122,4 +125,4 @@ bool Bitmask::bitmask_isset(u_int32_t n) {
 
 /* ********************************************************** */
 
-void Bitmask::bitmask_clr_all() { memset(bits, 0, num_elems); }
\ No newline at end of file
+void Bitmask::bitmask_clr_all() { memset(bits, 0, num_elems); }
