@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,8 @@ static void *esLoop(void *ptr) {
 /* **************************************** */
 
 ElasticSearch::ElasticSearch(NetworkInterface *_iface) : DB(_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   snprintf(es_version, sizeof(es_version), "%c", '0');
   es_version_inited = false;
   num_queued_elems = 0;
@@ -64,6 +66,7 @@ ElasticSearch::ElasticSearch(NetworkInterface *_iface) : DB(_iface) {
 /* **************************************** */
 
 ElasticSearch::~ElasticSearch() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   shutdown();
   if (es_template_push_url) free(es_template_push_url);
   if (es_version_query_url) free(es_version_query_url);
@@ -140,7 +143,7 @@ bool ElasticSearch::startQueryLoop() {
 /* **************************************** */
 
 void ElasticSearch::indexESdata() {
-  time_t last_dump = time(0);
+  u_int32_t last_dump = (u_int32_t)time(NULL);
   char *postbuf = (char *)malloc(ES_BULK_BUFFER_SIZE);
   char *pending_flow = NULL;
 
@@ -150,10 +153,11 @@ void ElasticSearch::indexESdata() {
   }
 
   while (!ntop->getGlobals()->isShutdown() && isRunning()) {
-    time_t now = time(0);
+    u_int32_t now = (u_int32_t)time(NULL);
 
     if ((num_queued_elems >= ES_MIN_BUFFERED_FLOWS) ||
-        ((num_queued_elems > 0 || pending_flow) && (now >= last_dump + ntop->getPrefs()->get_dump_frequency()))) {
+        ((num_queued_elems > 0 || pending_flow)
+	 && (now >= last_dump + ntop->getPrefs()->get_dump_frequency()))) {
       u_int len, num_flows;
       char index_name[64], header[256];
       struct tm *tm_info;
