@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,19 +24,23 @@
 /* **************************************************** */
 
 FlowAlert::FlowAlert(FlowCheck *c, Flow *f) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   flow = f;
   cli_attacker = srv_attacker = false;
   cli_victim = srv_victim = false;
   if (c) check_name = c->getName();
+  alert_score = SCORE_LEVEL_INFO;
 }
 
 /* **************************************************** */
 
-FlowAlert::~FlowAlert() {}
+FlowAlert::~FlowAlert() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+}
 
 /* ***************************************************** */
 
-ndpi_serializer *FlowAlert::getSerializedAlert() {
+ndpi_serializer* FlowAlert::getSerializedAlert() {
   ndpi_serializer *serializer;
 
   serializer = (ndpi_serializer *)malloc(sizeof(ndpi_serializer));
@@ -57,11 +61,13 @@ ndpi_serializer *FlowAlert::getSerializedAlert() {
 
   /* Add information relative to this check */
   ndpi_serialize_start_of_block(serializer, "alert_generation");
-  ndpi_serialize_string_string(serializer, "script_key",
-                               getCheckName().c_str());
+  ndpi_serialize_string_string(serializer, "script_key", getCheckName().c_str());
   ndpi_serialize_string_string(serializer, "subdir", "flow");
   flow->getJSONRiskInfo(serializer);
   ndpi_serialize_end_of_block(serializer);
+  if (flow->isBlacklistedFlow())
+    ndpi_serialize_string_string(serializer, "blacklist", 
+      flow->get_custom_category_file() ? flow->get_custom_category_file() : "");
 
   flow->getProtocolJSONInfo(serializer);
 
