@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 
 FlowChecksExecutor::FlowChecksExecutor(FlowChecksLoader *fcl,
                                        NetworkInterface *_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   iface = _iface;
   loadFlowChecks(fcl);
 };
@@ -32,6 +33,7 @@ FlowChecksExecutor::FlowChecksExecutor(FlowChecksLoader *fcl,
 /* **************************************************** */
 
 FlowChecksExecutor::~FlowChecksExecutor() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   if (protocol_detected) delete protocol_detected;
   if (periodic_update) delete periodic_update;
   if (flow_end) delete flow_end;
@@ -52,6 +54,7 @@ void FlowChecksExecutor::loadFlowChecks(FlowChecksLoader *fcl) {
 FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
   FlowAlertType predominant_alert = f->getPredominantAlert();
   FlowCheck *predominant_check = NULL;
+  bool new_predominant_alert = false;
   std::list<FlowCheck *> *checks = NULL;
   FlowAlert *alert = NULL;
 #ifdef CHECKS_PROFILING
@@ -59,6 +62,9 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
 #endif
 
   switch (c) {
+    case flow_check_flow_begin:
+      checks = flow_begin;
+      break;
     case flow_check_protocol_detected:
       checks = protocol_detected;
       break;
@@ -68,9 +74,6 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
     case flow_check_flow_end:
       checks = flow_end;
       break;
-    case flow_check_flow_begin:
-      checks = flow_begin;
-      break;
     default:
       return NULL;
   }
@@ -87,6 +90,9 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
     // fc->getName().c_str());
 
     switch (c) {
+      case flow_check_flow_begin:
+        fc->flowBegin(f);
+        break;
       case flow_check_protocol_detected:
         fc->protocolDetected(f);
         break;
@@ -96,9 +102,6 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
       case flow_check_flow_end:
         fc->flowEnd(f);
         break;
-      case flow_check_flow_begin:
-        fc->flowBegin(f);
-        break;
       default:
         break;
     }
@@ -111,6 +114,7 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
 
     /* Check if the check triggered a predominant alert */
     if (f->getPredominantAlert().id != predominant_alert.id) {
+      new_predominant_alert = true;
       predominant_alert = f->getPredominantAlert();
       predominant_check = fc;
     }
@@ -118,9 +122,71 @@ FlowAlert *FlowChecksExecutor::execChecks(Flow *f, FlowChecks c) {
 
   /* Do NOT allocate any alert, there is nothing left to do as flow alerts don't
    * have to be emitted */
-  if (ntop->getPrefs()->dontEmitFlowAlerts()) return (NULL);
+  if (ntop->getPrefs()->dontEmitFlowAlerts())
+    return (NULL);
 
-  if (predominant_check) {
+  if(new_predominant_alert) {
+    Host *cli_u = f->getViewSharedClient(), *srv_u = f->getViewSharedServer();
+#ifdef DEBUG
+    char buf[64];
+#endif
+
+#ifdef DEBUG
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "[%s/%u][%s] ->> %p/%p [%s]",
+				 predominant_check->getName().c_str(), c,
+				 f->getInterface()->get_name(),
+				 cli_u, srv_u, f->print(buf, sizeof(buf)));
+#endif
+
+    if(cli_u && srv_u) {
+      if(cli_u->isFlowAlertDisabled(predominant_alert)
+	 || srv_u->isFlowAlertDisabled(predominant_alert)) {
+#ifdef DEBUG
+	ntop->getTrace()->traceEvent(TRACE_NORMAL, "Skipping alert");
+#endif
+
+	return(NULL);
+      }
+    } else {
+      /* This flow has not yet been walked by ViewInterface::viewed_flows_walker() */
+      const IpAddress *cli_ip = f->get_cli_ip_addr(), *srv_ip = f->get_srv_ip_addr();
+      Host *cli_host, *srv_host;
+      Mac *srcMac = NULL, *dstMac = NULL;
+      ViewInterface *viewedBy = f->getInterface()->viewedBy();
+
+#ifdef DEBUG
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Searching hosts %p", viewedBy);
+#endif
+
+      if(viewedBy) {
+	viewedBy->findFlowHosts(f->getInterfaceIndex(),
+				f->get_vlan_id(), f->get_observation_point_id(),
+				f->getPrivateFlowId(), srcMac,
+				(IpAddress *)cli_ip, &cli_host, dstMac,
+				(IpAddress *)srv_ip, &srv_host);
+
+	if(cli_host && srv_host) {
+#ifdef DEBUG
+	  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Hosts found");
+#endif
+
+	  if(cli_host->isFlowAlertDisabled(predominant_alert)
+	     || srv_host->isFlowAlertDisabled(predominant_alert)) {
+#ifdef DEBUG
+	    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Skipping alert");
+#endif
+	    return(NULL);
+	  }
+	} else {
+#ifdef DEBUG
+	  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Hosts NOT found");
+#endif
+	}
+      }
+    }
+  }
+
+  if (new_predominant_alert) {
     /* Allocate the alert */
     alert = predominant_check->buildAlert(f);
 
