@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@ FlowChecksLoader::FlowChecksLoader() : ChecksLoader() {
     Assuments all risks as unhanlded. Bits corresponding to risks handled by
     checks will be set to zero during checks registration.
    */
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   NDPI_BITMASK_SET_ALL(unhandled_ndpi_risks);
   NDPI_CLR_BIT(unhandled_ndpi_risks, NDPI_NO_RISK);
 }
@@ -36,6 +37,8 @@ FlowChecksLoader::FlowChecksLoader() : ChecksLoader() {
 /* **************************************************** */
 
 FlowChecksLoader::~FlowChecksLoader() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   for (std::map<std::string, FlowCheck *>::const_iterator it = cb_all.begin();
        it != cb_all.end(); ++it)
     delete it->second;
@@ -113,7 +116,7 @@ void FlowChecksLoader::registerChecks() {
   if ((fcb = new NotPurged())) registerCheck(fcb);
   if ((fcb = new RemoteAccess())) registerCheck(fcb);
   if ((fcb = new RareDestination())) registerCheck(fcb);
-  if ((fcb = new RemoteToLocalInsecureProto())) registerCheck(fcb);
+  if ((fcb = new RemoteToLocalInsecureFlow())) registerCheck(fcb);
   if ((fcb = new RemoteToRemote())) registerCheck(fcb);
   if ((fcb = new TCPZeroWindow())) registerCheck(fcb);
   if ((fcb = new TCPNoDataExchanged())) registerCheck(fcb);
@@ -124,6 +127,9 @@ void FlowChecksLoader::registerChecks() {
   if ((fcb = new UnexpectedSMTPServer())) registerCheck(fcb);
   if ((fcb = new WebMining())) registerCheck(fcb);
   if ((fcb = new VLANBidirectionalTraffic())) registerCheck(fcb);
+  if ((fcb = new BlacklistedClientContact())) registerCheck(fcb);
+  if ((fcb = new BlacklistedServerContact())) registerCheck(fcb);
+  if ((fcb = new TCPFlowReset())) registerCheck(fcb);
 
 #ifdef NTOPNG_PRO
   if ((fcb = new DataExfiltration())) registerCheck(fcb);
