@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -247,6 +247,12 @@ static const FlowAlertTypeExtended risk_enum_to_alert_type[NDPI_MAX_RISK] {
 
     /* NDPI_MALWARE_HOST_CONTACTED */
     {{flow_alert_ndpi_malware_host_contacted, alert_category_security}, "ndpi_malware_host_contacted"},
+
+    /* NDPI_BINARY_DATA_TRANSFER */
+    {{flow_alert_ndpi_binary_data_transfer, alert_category_security}, "ndpi_binary_data_transfer"},
+
+    /* NDPI_PROBING_ATTEMPT */
+    {{flow_alert_ndpi_probing_attempt, alert_category_security}, "ndpi_probing_attempt"},
 };
 
 /* **************************************************** */
