@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,11 +23,15 @@
 
 /* *************************************** */
 
-FlowStats::FlowStats() { resetStats(); }
+FlowStats::FlowStats() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  resetStats(); }
 
 /* *************************************** */
 
-FlowStats::~FlowStats() {}
+FlowStats::~FlowStats() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+}
 
 /* *************************************** */
 
@@ -218,9 +222,9 @@ void FlowStats::lua(lua_State *vm) {
 
   lua_newtable(vm);
 
-  std::map<std::string, u_int16_t>::iterator it;
-  for (it = talking_hosts.begin(); it != talking_hosts.end(); it++)
-    lua_push_uint32_table_entry(vm, it->first.c_str(), it->second);
+  std::map<std::string, u_int16_t>::iterator it2;
+  for (it2 = talking_hosts.begin(); it2 != talking_hosts.end(); it2++)
+    lua_push_uint32_table_entry(vm, it2->first.c_str(), it2->second);
 
   lua_pushstring(vm, "talking_with");
   lua_insert(vm, -2);
