@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,8 @@
 
 GenericHash::GenericHash(NetworkInterface *_iface, u_int _num_hashes,
                          u_int _max_hash_size, const char *_name) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   num_hashes = _num_hashes;
   current_size = 0;
   /* Allow the total number of entries (that is, active and those idle but still
@@ -321,6 +323,11 @@ u_int GenericHash::purgeIdle(const struct timeval *tv, bool force_idle,
   size_t idle_entries_shadow_old_size;
   vector<GenericHashEntry *>::const_iterator it;
 
+  if(ntop->getPrefs()->disablePurge()) {
+    /* ntop->getTrace()->traceEvent(TRACE_WARNING, "Purge disabled"); */
+    return(0);
+  }
+  
   if (!idle_entries) {
     idle_entries = idle_entries_shadow;
 
