@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -1076,6 +1076,15 @@ bool HTTPserver::create_api_token(const char *username, char *api_token,
   /* Note: we are not checking the user password as the admin
    * or the same (authenticated) user is generating the session */
   if (ntop->existsUserLocal(username)) {
+
+    /* 
+      Delete the old token before creating the new one.
+      */
+    char old_api_token[NTOP_SESSION_ID_LENGTH];
+    if (ntop->getUserAPIToken(username, old_api_token, sizeof(old_api_token))) {
+      ntop->getRedis()->hashDel(NTOPNG_API_TOKEN_PREFIX, old_api_token);
+    }
+
     /*
       Use the same random generator used for the sessions
      */
@@ -1548,7 +1557,7 @@ static int handle_lua_request(struct mg_connection *conn) {
                                    request_info->uri, path);
 
       try {
-        l = new LuaEngine(NULL);
+        l = new LuaEngine();
       } catch (std::bad_alloc &ba) {
         ntop->getTrace()->traceEvent(TRACE_ERROR,
                                      "[HTTP] Unable to start Lua interpreter.");
@@ -1788,6 +1797,8 @@ HTTPserver::HTTPserver(const char *_docs_dir, const char *_scripts_dir) {
   bool good_ssl_cert = false;
   struct timeval tv;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   memset(ports, 0, sizeof(ports)),
       memset(access_log_path, 0, sizeof(access_log_path));
   use_http = true;
@@ -1809,7 +1820,8 @@ HTTPserver::HTTPserver(const char *_docs_dir, const char *_scripts_dir) {
   addHTTPOption("document_root", _docs_dir);
   addHTTPOption("access_control_list", acl_management);
   /* (char*)"extra_mime_types", (char*)"" */ /* see mongoose.c */
-  addHTTPOption("num_threads", "5");
+
+  addHTTPOption("num_threads", ntop->getPrefs()->limitResourcesUsage() ? "3" : "5");
 
   /* Randomize data */
   gettimeofday(&tv, NULL);
@@ -1951,6 +1963,8 @@ void HTTPserver::startHttpServer() {
 /* ****************************************** */
 
 HTTPserver::~HTTPserver() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if (httpd_v4) mg_stop(httpd_v4);
 #ifdef HAVE_NEDGE
   if (httpd_captive_v4) mg_stop(httpd_captive_v4);
