@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,24 +23,29 @@
 
 /* *************************************** */
 
-Host::Host(NetworkInterface *_iface, char *ipAddress, u_int16_t _u_int16_t,
+Host::Host(NetworkInterface *_iface, int32_t _iface_idx,
+	   char *ipAddress, u_int16_t _vlan_id,
            u_int16_t observation_point_id)
     : GenericHashEntry(_iface),
-      HostAlertableEntity(_iface, alert_entity_host),
       Score(_iface),
-      HostChecksStatus() {
+      HostChecksStatus(),
+      HostAlertableEntity(_iface, alert_entity_host) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   ip.set(ipAddress);
-  initialize(NULL, _u_int16_t, observation_point_id);
+  initialize(NULL, _iface_idx, _vlan_id, observation_point_id);
 }
 
 /* *************************************** */
 
-Host::Host(NetworkInterface *_iface, Mac *_mac, u_int16_t _u_int16_t,
+Host::Host(NetworkInterface *_iface, int32_t _iface_idx,
+	   Mac *_mac, u_int16_t _vlan_id,
            u_int16_t observation_point_id, IpAddress *_ip)
     : GenericHashEntry(_iface),
-      HostAlertableEntity(_iface, alert_entity_host),
       Score(_iface),
-      HostChecksStatus() {
+      HostChecksStatus(),
+      HostAlertableEntity(_iface, alert_entity_host) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   ip.set(_ip);
 
 #ifdef BROADCAST_DEBUG
@@ -51,12 +56,14 @@ Host::Host(NetworkInterface *_iface, Mac *_mac, u_int16_t _u_int16_t,
                                isBroadcastHost() ? 1 : 0);
 #endif
 
-  initialize(_mac, _u_int16_t, observation_point_id);
+  initialize(_mac, _iface_idx, _vlan_id, observation_point_id);
 }
 
 /* *************************************** */
 
 Host::~Host() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if ((getUses() > 0)
       /* View hosts are not in sync with viewed flows so during shutdown it can
          be normal */
@@ -114,11 +121,14 @@ Host::~Host() {
   */
   iface->decPoolNumHosts(get_host_pool(), false /* Host is deleted offline */);
   if (customHostAlert.msg) free(customHostAlert.msg);
-  if (tcp_udp_contacted_ports_no_tx)
-    ndpi_bitmap_free(tcp_udp_contacted_ports_no_tx);
 
-  ndpi_hll_destroy(&outgoing_hosts_tcp_udp_port_with_no_tx_hll);
-  ndpi_hll_destroy(&incoming_hosts_tcp_udp_port_with_no_tx_hll);
+  if(!ntop->getPrefs()->limitResourcesUsage()) {
+    if (tcp_udp_contacted_ports_no_tx)
+      ndpi_bitmap_free(tcp_udp_contacted_ports_no_tx);
+    
+    ndpi_hll_destroy(&outgoing_hosts_tcp_udp_port_with_no_tx_hll);
+    ndpi_hll_destroy(&incoming_hosts_tcp_udp_port_with_no_tx_hll);
+  }
 }
 
 /* *************************************** */
@@ -167,8 +177,7 @@ u_int16_t Host::decScoreValue(u_int16_t score_decr,
 /* *************************************** */
 
 void Host::updateSynAlertsCounter(time_t when, bool syn_sent) {
-  AlertCounter *counter =
-      syn_sent ? syn_flood.attacker_counter : syn_flood.victim_counter;
+  AlertCounter *counter = syn_sent ? syn_flood.attacker_counter : syn_flood.victim_counter;
 
   counter->inc(when, this);
 
@@ -187,8 +196,7 @@ void Host::updateFinAlertsCounter(time_t when, bool fin_sent) {
 /* *************************************** */
 
 void Host::updateRstAlertsCounter(time_t when, bool rst_sent) {
-  AlertCounter *counter =
-      rst_sent ? rst_scan.attacker_counter : rst_scan.victim_counter;
+  AlertCounter *counter = rst_sent ? rst_scan.attacker_counter : rst_scan.victim_counter;
 
   counter->inc(when, this);
 }
@@ -203,8 +211,7 @@ void Host::updateFinAckAlertsCounter(time_t when, bool finack_sent) {
 /* *************************************** */
 
 void Host::updateICMPAlertsCounter(time_t when, bool icmp_sent) {
-  AlertCounter *counter =
-      icmp_sent ? icmp_flood.attacker_counter : icmp_flood.victim_counter;
+  AlertCounter *counter = icmp_sent ? icmp_flood.attacker_counter : icmp_flood.victim_counter;
 
   counter->inc(when, this);
 }
@@ -212,8 +219,7 @@ void Host::updateICMPAlertsCounter(time_t when, bool icmp_sent) {
 /* *************************************** */
 
 void Host::updateDNSAlertsCounter(time_t when, bool dns_sent) {
-  AlertCounter *counter =
-      dns_sent ? dns_flood.attacker_counter : dns_flood.victim_counter;
+  AlertCounter *counter = dns_sent ? dns_flood.attacker_counter : dns_flood.victim_counter;
 
   counter->inc(when, this);
 }
@@ -221,8 +227,7 @@ void Host::updateDNSAlertsCounter(time_t when, bool dns_sent) {
 /* *************************************** */
 
 void Host::updateSNMPAlertsCounter(time_t when, bool snmp_sent) {
-  AlertCounter *counter =
-      snmp_sent ? snmp_flood.attacker_counter : snmp_flood.victim_counter;
+  AlertCounter *counter = snmp_sent ? snmp_flood.attacker_counter : snmp_flood.victim_counter;
 
   counter->inc(when, this);
 }
@@ -257,15 +262,17 @@ void Host::housekeep(time_t t) {
 
 /* *************************************** */
 
-void Host::initialize(Mac *_mac, u_int16_t _vlanId,
+void Host::initialize(Mac *_mac, int32_t _iface_idx,
+		      u_int16_t _vlanId,
                       u_int16_t observation_point_id) {
   if (_vlanId == (u_int16_t)-1) _vlanId = 0;
 
   vlan_id = _vlanId & 0xFFF; /* Cleanup any possible junk */
-
+  iface_index = _iface_idx;
+  host_pool_id_is_from_mac = false; 
   /* stats = NULL; useless initi, it will be instantiated by specialized classes
    */
-  stats_shadow = NULL;
+  stats = stats_shadow = NULL;
 #ifndef HAVE_NEDGE
   listening_ports = listening_ports_shadow = NULL;
 #endif
@@ -279,7 +286,9 @@ void Host::initialize(Mac *_mac, u_int16_t _vlanId,
   active_alerted_flows = 0;
 
   is_dhcp_host = 0, is_crawler_bot_scanner = 0, is_in_broadcast_domain = 0,
-  more_then_one_device = 0, device_ip = 0;
+    more_then_one_device = 0, device_ip = 0;
+
+  is_rx_only = false;
 
   last_stats_reset = ntop->getLastStatsReset(); /* assume fresh stats, may be
                                                    changed by deserialize */
@@ -292,7 +301,7 @@ void Host::initialize(Mac *_mac, u_int16_t _vlanId,
   memset(&num_blacklisted_flows, 0, sizeof(num_blacklisted_flows));
   memset(&customHostAlert, 0, sizeof(customHostAlert));
 
-  setRxOnlyHost(true);
+  toggleRxOnlyHost(true);
 
 #ifdef NTOPNG_PRO
   host_traffic_shapers = NULL;
@@ -326,12 +335,15 @@ void Host::initialize(Mac *_mac, u_int16_t _vlanId,
   fin_scan.fin_recvd_last_min = fin_scan.finack_sent_last_min = 0;
   INTERFACE_PROFILING_SUB_SECTION_EXIT(iface, 17);
 
-  tcp_udp_contacted_ports_no_tx = ndpi_bitmap_alloc();
-  ndpi_hll_init(&outgoing_hosts_tcp_udp_port_with_no_tx_hll,
-                5 /* StdError: 18.4% */);
-  ndpi_hll_init(&incoming_hosts_tcp_udp_port_with_no_tx_hll,
-                5 /* StdError: 18.4% */);
-
+  if(!ntop->getPrefs()->limitResourcesUsage()) {
+    tcp_udp_contacted_ports_no_tx = ndpi_bitmap_alloc();
+    ndpi_hll_init(&outgoing_hosts_tcp_udp_port_with_no_tx_hll,
+		  5 /* StdError: 18.4% */);
+    ndpi_hll_init(&incoming_hosts_tcp_udp_port_with_no_tx_hll,
+		  5 /* StdError: 18.4% */);
+  } else
+    tcp_udp_contacted_ports_no_tx = NULL;
+  
   if (ip.getVersion() /* IP is set */) {
     char country_name[64];
 
@@ -357,7 +369,8 @@ void Host::initialize(Mac *_mac, u_int16_t _vlanId,
                                         true /* Inline call */)) != NULL)
       obs_point->incUses();
   }
-
+    
+  /* Increase the number of active hosts */
   reloadHostBlacklist();
 }
 
@@ -409,10 +422,13 @@ char *Host::get_hostkey(char *buf, u_int buf_len, bool force_vlan) {
 /* *************************************** */
 
 void Host::updateHostPool(bool isInlineCall, bool firstUpdate) {
+  bool mac_match = false;
+
   if (!iface) return;
 
   if (!firstUpdate) iface->decPoolNumHosts(get_host_pool(), isInlineCall);
-  host_pool_id = iface->getHostPool(this);
+  host_pool_id = iface->getHostPool(this, &mac_match);
+  host_pool_id_is_from_mac = mac_match;
   iface->incPoolNumHosts(get_host_pool(), isInlineCall);
 
 #ifdef NTOPNG_PRO
@@ -533,6 +549,9 @@ void Host::lua_get_names(lua_State *const vm, char *const buf,
       cur_mac->getDHCPName(buf, buf_size);
       if (buf[0]) lua_push_str_table_entry(vm, "dhcp", buf);
     }
+
+    getDHCPName(buf, buf_size);
+    if (buf[0]) lua_push_str_table_entry(vm, "dhcp", buf);
   }
 
   lua_pushstring(vm, "names");
@@ -611,7 +630,8 @@ void Host::lua_get_as(lua_State *vm) const {
 /* ***************************************************** */
 
 void Host::lua_get_host_pool(lua_State *vm) const {
-  lua_push_uint64_table_entry(vm, "host_pool_id", get_host_pool());
+  lua_push_uint64_table_entry(vm, "host_pool_id", host_pool_id);
+  lua_push_str_table_entry(vm, "host_pool_match", host_pool_id_is_from_mac ? "mac" : "ip");
 }
 /* ***************************************************** */
 
@@ -646,7 +666,7 @@ void Host::lua_get_min_info(lua_State *vm) {
   lua_push_bool_table_entry(vm, "crawlerBotScannerHost",
                             isCrawlerBotScannerHost());
   lua_push_bool_table_entry(vm, "is_blacklisted", isBlacklisted());
-  lua_push_bool_table_entry(vm, "is_rx_only", is_rx_only);
+  lua_push_bool_table_entry(vm, "is_rx_only", isRxOnlyHost());
   lua_push_bool_table_entry(vm, "is_broadcast", isBroadcastHost());
   lua_push_bool_table_entry(vm, "is_multicast", isMulticastHost());
   lua_push_int32_table_entry(vm, "host_services_bitmap", host_services_bitmap);
@@ -824,13 +844,6 @@ void Host::lua_get_num_http_hosts(lua_State *vm) {
 
 /* ***************************************************** */
 
-void Host::lua_get_fingerprints(lua_State *vm) {
-  fingerprints.ja3.lua("ja3_fingerprint", vm);
-  fingerprints.hassh.lua("hassh_fingerprint", vm);
-}
-
-/* ***************************************************** */
-
 void Host::lua_unidirectional_tcp_udp_flows(lua_State *vm,
                                             bool as_subtable) const {
   lua_newtable(vm);
@@ -898,6 +911,7 @@ void Host::lua(lua_State *vm, AddressTree *ptree, bool host_details,
   lua_push_str_table_entry(vm, "ip",
                            (ipaddr = printMask(ip_buf, sizeof(ip_buf))));
   lua_push_uint32_table_entry(vm, "vlan", get_vlan_id());
+  lua_push_int32_table_entry(vm, "iface_index", iface_index);
   lua_push_uint32_table_entry(vm, "observation_point_id",
                               get_observation_point_id());
   lua_push_bool_table_entry(vm, "serialize_by_mac", serializeByMac());
@@ -925,18 +939,14 @@ void Host::lua(lua_State *vm, AddressTree *ptree, bool host_details,
   lua_get_num_contacts(vm);
   lua_get_num_http_hosts(vm);
 
-  lua_push_float_table_entry(
-      vm, "bytes_ratio", ndpi_data_ratio(getNumBytesSent(), getNumBytesRcvd()));
-  lua_push_float_table_entry(
-      vm, "pkts_ratio", ndpi_data_ratio(getNumPktsSent(), getNumPktsRcvd()));
-
-  lua_push_int32_table_entry(
-      vm, "num_contacted_peers_with_tcp_udp_flows_no_response",
-      getNumContactedPeersAsClientTCPUDPNoTX());
-  lua_push_int32_table_entry(
-      vm, "num_incoming_peers_that_sent_tcp_udp_flows_no_response",
-      getNumContactsFromPeersAsServerTCPUDPNoTX());
+  lua_push_float_table_entry(vm, "bytes_ratio", ndpi_data_ratio(getNumBytesSent(), getNumBytesRcvd()));
+  lua_push_float_table_entry(vm, "pkts_ratio", ndpi_data_ratio(getNumPktsSent(), getNumPktsRcvd()));
 
+  lua_push_int32_table_entry(vm, "num_contacted_peers_with_tcp_udp_flows_no_response",
+			     getNumContactedPeersAsClientTCPUDPNoTX());
+  lua_push_int32_table_entry(vm, "num_incoming_peers_that_sent_tcp_udp_flows_no_response",
+			     getNumContactsFromPeersAsServerTCPUDPNoTX());
+  
   if (device_ip)
     lua_push_str_table_entry(vm, "device_ip",
                              Utils::intoaV4(device_ip, buf, sizeof(buf)));
@@ -944,7 +954,7 @@ void Host::lua(lua_State *vm, AddressTree *ptree, bool host_details,
   if (blacklist_name != NULL)
     lua_push_str_table_entry(vm, "blacklist_name", blacklist_name);
 
-  lua_push_bool_table_entry(vm, "is_rx_only", is_rx_only);
+  lua_push_bool_table_entry(vm, "is_rx_only", isRxOnlyHost());
 
   if (more_then_one_device)
     lua_push_bool_table_entry(vm, "more_then_one_device", more_then_one_device);
@@ -1047,10 +1057,13 @@ char *Host::get_name(char *buf, u_int buf_len,
 
   num_resolve_attempts++;
 
-  getResolvedName(name_buf, sizeof(name_buf));
+  getServerName(name_buf, sizeof(name_buf));
   if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
 
-  getServerName(name_buf, sizeof(name_buf));
+  getDHCPName(name_buf, sizeof(name_buf));
+  if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
+
+  getResolvedName(name_buf, sizeof(name_buf));
   if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
 
   /* Most relevant names goes first */
@@ -1072,8 +1085,10 @@ char *Host::get_name(char *buf, u_int buf_len,
   getMDNSInfo(name_buf, sizeof(name_buf));
   if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
 
-  getTLSName(name_buf, sizeof(name_buf));
-  if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
+  if (ntop->getPrefs()->do_tls_quic_hostnaming()) {
+    getTLSName(name_buf, sizeof(name_buf));
+    if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
+  }
 
   getHTTPName(name_buf, sizeof(name_buf));
   if (name_buf[0] && !Utils::isIPAddress(name_buf)) goto out;
@@ -1208,6 +1223,18 @@ char *Host::getTLSName(char *const buf, ssize_t buf_len) {
 
 /* ***************************************** */
 
+char *Host::getDHCPName(char *const buf, ssize_t buf_len) {
+  if (buf && buf_len) {
+    m.lock(__FILE__, __LINE__);
+    snprintf(buf, buf_len, "%s", names.dhcp ? names.dhcp : "");
+    m.unlock(__FILE__, __LINE__);
+  }
+
+  return ((char*)buf);
+}
+
+/* ***************************************** */
+
 char *Host::getHTTPName(char *const buf, ssize_t buf_len) {
   if (buf && buf_len) {
     m.lock(__FILE__, __LINE__);
@@ -1379,7 +1406,7 @@ void Host::serialize(json_object *my_object, DetailsLevel details_level) {
     json_object_object_add(my_object, "is_blacklisted",
                            json_object_new_boolean(isBlacklisted()));
     json_object_object_add(my_object, "is_rx_only",
-                           json_object_new_boolean(is_rx_only ? true : false));
+                           json_object_new_boolean(isRxOnlyHost()));
     json_object_object_add(my_object, "host_services_bitmap",
                            json_object_new_int(host_services_bitmap));
 
@@ -1391,7 +1418,7 @@ void Host::serialize(json_object *my_object, DetailsLevel details_level) {
 
 /* *************************************** */
 
-char *Host::get_visual_name(char *buf, u_int buf_len) {
+char* Host::get_visual_name(char *buf, u_int buf_len) {
   bool mask_host = Utils::maskHost(isLocalHost());
   char buf2[64];
   char *sym_name;
@@ -1683,6 +1710,18 @@ void Host::offlineSetMDNSName(const char *mdns_n) {
 
 /* *************************************** */
 
+void Host::offlineSetDHCPName(const char *dhcp_n) {
+  if (!isValidHostName(dhcp_n)) return;
+  if (!names.dhcp && dhcp_n &&
+      (names.dhcp = strdup(dhcp_n))) {
+#ifdef NTOPNG_PRO
+    ntop->get_am()->setResolvedName(this, label_dhcp, names.dhcp);
+#endif
+  }
+}
+
+/* *************************************** */
+
 void Host::offlineSetMDNSTXTName(const char *mdns_n_txt) {
   if (!names.mdns_txt && mdns_n_txt &&
       (names.mdns_txt = Utils::toLowerResolvedNames(mdns_n_txt))) {
@@ -1708,11 +1747,20 @@ void Host::offlineSetNetbiosName(const char *netbios_n) {
 /* *************************************** */
 
 void Host::offlineSetTLSName(const char *tls_n) {
-  if (!isValidHostName(tls_n)) return;
-
+  if((!isValidHostName(tls_n)) || isLocalHost()) {
+     /*
+       As in TLS we cannot check if the connection reported
+       some mismatches we do not set TLS names for local hosts
+       that are more subject to naming errors, and that whose
+       name could be set via other protocols
+     */    
+    return;
+  }
+  
   if (!names.tls && tls_n && (names.tls = Utils::toLowerResolvedNames(tls_n))) {
 #ifdef NTOPNG_PRO
-    ntop->get_am()->setResolvedName(this, label_tls, names.tls);
+    if (ntop->getPrefs()->do_tls_quic_hostnaming())
+      ntop->get_am()->setResolvedName(this, label_tls, names.tls);
 #endif
   }
 }
@@ -1990,6 +2038,10 @@ void Host::freeHostNames() {
     free(names.tls);
     names.tls = NULL;
   }
+  if (names.dhcp) {
+    free(names.dhcp);
+    names.dhcp = NULL;
+  }
 }
 
 /* *************************************** */
@@ -2219,9 +2271,9 @@ bool Host::enqueueAlertToRecipients(HostAlert *alert, bool released) {
     notification->alert_category = alert->getAlertType().category;
     notification->alert_id = alert->getAlertType().id;
     notification->host.host_pool = get_host_pool();
+    notification->alert_entity = alert_entity_host;
 
-    rv = ntop->recipients_enqueue(notification,
-                                  alert_entity_host /* Host recipients */);
+    rv = ntop->recipients_enqueue(notification);
 
     if (!rv)
       delete notification;
@@ -2734,8 +2786,9 @@ void Host::triggerCustomHostAlert(u_int8_t score, char *msg) {
 */
 void Host::setUnidirectionalTCPUDPNoTXEgressFlow(IpAddress *ip,
                                                  u_int16_t port) {
-  ndpi_hll_add_number(&outgoing_hosts_tcp_udp_port_with_no_tx_hll,
-                      ip->key() + (port << 8));  // Simple hash
+  if(!ntop->getPrefs()->limitResourcesUsage())
+    ndpi_hll_add_number(&outgoing_hosts_tcp_udp_port_with_no_tx_hll,
+			ip->key() + (port << 8));  // Simple hash
 }
 
 /* *************************************** */
@@ -2747,14 +2800,51 @@ void Host::setUnidirectionalTCPUDPNoTXEgressFlow(IpAddress *ip,
 */
 void Host::setUnidirectionalTCPUDPNoTXIngressFlow(IpAddress *ip,
                                                   u_int16_t port) {
-  ndpi_hll_add_number(&incoming_hosts_tcp_udp_port_with_no_tx_hll,
-                      ip->key() + (port << 8));  // Simple hash
+  if(!ntop->getPrefs()->limitResourcesUsage())
+    ndpi_hll_add_number(&incoming_hosts_tcp_udp_port_with_no_tx_hll,
+			ip->key() + (port << 8));  // Simple hash
 }
 
 /* *************************************** */
 
 void Host::resetHostContacts() {
-  ndpi_hll_reset(&outgoing_hosts_tcp_udp_port_with_no_tx_hll);
-  ndpi_hll_reset(&incoming_hosts_tcp_udp_port_with_no_tx_hll);
-  ndpi_bitmap_clear(tcp_udp_contacted_ports_no_tx);
+  if(!ntop->getPrefs()->limitResourcesUsage()) {
+    ndpi_hll_reset(&outgoing_hosts_tcp_udp_port_with_no_tx_hll);
+    ndpi_hll_reset(&incoming_hosts_tcp_udp_port_with_no_tx_hll);
+
+    if(tcp_udp_contacted_ports_no_tx)
+      ndpi_bitmap_free(tcp_udp_contacted_ports_no_tx);
+    
+    tcp_udp_contacted_ports_no_tx = ndpi_bitmap_alloc();
+  }
+}
+
+/* *************************************** */
+
+u_int32_t Host::getNumContactedPeersAsClientTCPUDPNoTX() {
+  return (!ntop->getPrefs()->limitResourcesUsage() ? (u_int32_t)ndpi_hll_count(&outgoing_hosts_tcp_udp_port_with_no_tx_hll) : 0);
+};
+
+/* *************************************** */
+
+u_int32_t Host::getNumContactsFromPeersAsServerTCPUDPNoTX() {
+  return (!ntop->getPrefs()->limitResourcesUsage() ? (u_int32_t)ndpi_hll_count(&incoming_hosts_tcp_udp_port_with_no_tx_hll) : 0);
+};
+
+/* *************************************** */
+
+void Host::toggleRxOnlyHost(bool rx_only) {
+  if(is_rx_only == rx_only)
+    return; /* Nothing to do */
+    
+  if(rx_only == false) { /* Rx-only -> Not-Rx-only */
+    if(isUnicastHost()) {
+      iface->decNumHosts(isLocalHost(), true /* rx-only */);
+      iface->incNumHosts(isLocalHost(), false /* not-rx-only */);
+    }
+  } else {
+    /* Not-Rx-only -> Rx-only: this should happen during initialization only */
+  }
+  
+  is_rx_only = rx_only;
 }
