@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 
 HostChecksExecutor::HostChecksExecutor(HostChecksLoader *fcl,
                                        NetworkInterface *_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   iface = _iface;
   memset(host_cb_arr, 0, sizeof(host_cb_arr));
   loadHostChecks(fcl);
@@ -33,6 +34,8 @@ HostChecksExecutor::HostChecksExecutor(HostChecksLoader *fcl,
 /* **************************************************** */
 
 HostChecksExecutor::~HostChecksExecutor() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if (periodic_host_cb) delete periodic_host_cb;
 };
 
