@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,11 +24,15 @@
 
 /* **************************************************** */
 
-HostChecksLoader::HostChecksLoader() : ChecksLoader() {}
+HostChecksLoader::HostChecksLoader() : ChecksLoader() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+}
 
 /* **************************************************** */
 
 HostChecksLoader::~HostChecksLoader() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   for (std::map<std::string, HostCheck *>::const_iterator it = cb_all.begin();
        it != cb_all.end(); ++it)
     delete it->second;
@@ -38,11 +42,19 @@ HostChecksLoader::~HostChecksLoader() {
 
 void HostChecksLoader::registerCheck(HostCheck *cb) {
   if (cb_all.find(cb->getName()) != cb_all.end()) {
-    ntop->getTrace()->traceEvent(
-        TRACE_ERROR, "Ignoring duplicate host check %s", cb->getName().c_str());
+    ntop->getTrace()->traceEvent(TRACE_ERROR, "Ignoring duplicate host check %s", cb->getName().c_str());
     delete cb;
-  } else
+  } else {
+    /*
+      The registered name has a companion lua scaript that can be found at:
+      
+      - /usr/share/ntopng/scripts/lua/modules/alert_definitions/host/<name>.lua
+      - /usr/share/ntopng/scripts/lua/modules/check_definitions/host/<name>.lua 
+    */
+    ntop->getTrace()->traceEvent(TRACE_INFO, "Registering %s", cb->getName().c_str());
+    
     cb_all[cb->getName()] = cb;
+  }
 }
 
 /* **************************************************** */
@@ -51,32 +63,31 @@ void HostChecksLoader::registerChecks() {
   /* TODO: implement dynamic loading */
   HostCheck *fcb;
 
-  if ((fcb = new CountriesContacts())) registerCheck(fcb);
+  if ((fcb = new CountriesContacts()))   registerCheck(fcb);
   if ((fcb = new CustomHostLuaScript())) registerCheck(fcb);
-  if ((fcb = new FlowFlood())) registerCheck(fcb);
-  if ((fcb = new SYNScan())) registerCheck(fcb);
-  if ((fcb = new SYNFlood())) registerCheck(fcb);
-  if ((fcb = new FINScan())) registerCheck(fcb);
-  if ((fcb = new RSTScan())) registerCheck(fcb);
-  if ((fcb = new DNSServerContacts())) registerCheck(fcb);
-  if ((fcb = new SMTPServerContacts())) registerCheck(fcb);
-  if ((fcb = new NTPServerContacts())) registerCheck(fcb);
-  if ((fcb = new NTPTraffic())) registerCheck(fcb);
-  if ((fcb = new P2PTraffic())) registerCheck(fcb);
-  if ((fcb = new DNSTraffic())) registerCheck(fcb);
-  if ((fcb = new RemoteConnection())) registerCheck(fcb);
-  if ((fcb = new DangerousHost())) registerCheck(fcb);
+  if ((fcb = new FlowFlood()))           registerCheck(fcb);
+  if ((fcb = new SYNScan()))             registerCheck(fcb);
+  if ((fcb = new SYNFlood()))            registerCheck(fcb);
+  if ((fcb = new FINScan()))             registerCheck(fcb);
+  if ((fcb = new RSTScan()))             registerCheck(fcb);
+  if ((fcb = new DNSServerContacts()))   registerCheck(fcb);
+  if ((fcb = new SMTPServerContacts()))  registerCheck(fcb);
+  if ((fcb = new NTPServerContacts()))   registerCheck(fcb);
+  if ((fcb = new RemoteConnection()))    registerCheck(fcb);
+  if ((fcb = new DangerousHost()))       registerCheck(fcb);
   if ((fcb = new DomainNamesContacts())) registerCheck(fcb);
-  if ((fcb = new ScoreThreshold())) registerCheck(fcb);
-  if ((fcb = new ICMPFlood())) registerCheck(fcb);
-  if ((fcb = new PktThreshold())) registerCheck(fcb);
-  if ((fcb = new ScanDetection())) registerCheck(fcb);
+  if ((fcb = new ScoreThreshold()))      registerCheck(fcb);
+  if ((fcb = new ICMPFlood()))           registerCheck(fcb);
+  if ((fcb = new ScanDetection()))       registerCheck(fcb);
 
 #ifdef NTOPNG_PRO
-  if ((fcb = new ScoreAnomaly())) registerCheck(fcb);
-  if ((fcb = new DNSFlood())) registerCheck(fcb);
-  if ((fcb = new SNMPFlood())) registerCheck(fcb);
-  if ((fcb = new FlowAnomaly())) registerCheck(fcb);
+  if ((fcb = new ScoreAnomaly()))        registerCheck(fcb);
+  if ((fcb = new DNSFlood()))            registerCheck(fcb);
+  if ((fcb = new SNMPFlood()))           registerCheck(fcb);
+  if ((fcb = new FlowAnomaly()))         registerCheck(fcb);
+  if ((fcb = new HostScanner()))         registerCheck(fcb);
+  if ((fcb = new RXOnlyHostScan()))      registerCheck(fcb);
+  if ((fcb = new ServerPortsContacts())) registerCheck(fcb);
 #endif
 
   // printChecks();
@@ -207,7 +218,7 @@ void HostChecksLoader::loadConfiguration() {
           }
         } else {
           ntop->getTrace()->traceEvent(
-              TRACE_NORMAL, "Unable to find host check %s", check_key);
+              TRACE_DEBUG, "Unable to find host check %s", check_key);
         }
       }
     }
