@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 /* *************************************** */
 
 HostStats::HostStats(Host* _host) : GenericTrafficElement() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   host = _host;
 
   alerted_flows_as_client = alerted_flows_as_server = 0;
@@ -322,6 +323,9 @@ void HostStats::luaStats(lua_State* vm, NetworkInterface* iface,
   lua_push_uint64_table_entry(vm, "total_flows.as_server",
                               total_num_flows_as_server);
 
+  if (getResetFlow() > 0)
+    lua_push_uint64_table_entry(vm, "num_reset_flows", getResetFlow());
+  
   host->lua_get_score(vm);
 
   if (verbose) {
@@ -404,20 +408,9 @@ void HostStats::incStats(time_t when, u_int8_t l4_proto, u_int ndpi_proto,
                          u_int64_t sent_bytes, u_int64_t sent_goodput_bytes,
                          u_int64_t rcvd_packets, u_int64_t rcvd_bytes,
                          u_int64_t rcvd_goodput_bytes, bool peer_is_unicast) {
-  if ((getNumPktsSent() == 0) /* Current count */
-      && (!host->isBroadcastHost()) && (!host->isMulticastHost()) &&
-      (sent_packets > 0)) {
-    /*
-      This is a host (non broadcast/multicast host)
-      that used to be rcvdOnly and that has now sent traffic
-    */
 
-    host->getInterface()->decNumSentRcvdHosts(host->isLocalHost());
-    host->setRxOnlyHost(false /* no longer RX-only */);
-  }
-
-  sent.incStats(when, sent_packets, sent_bytes),
-      rcvd.incStats(when, rcvd_packets, rcvd_bytes);
+  sent.incStats(when, sent_packets, sent_bytes);
+  rcvd.incStats(when, rcvd_packets, rcvd_bytes);
 
   if (ndpiStats) {
     ndpiStats->incStats(when, ndpi_proto, sent_packets, sent_bytes,
@@ -443,6 +436,9 @@ void HostStats::incStats(time_t when, u_int8_t l4_proto, u_int ndpi_proto,
   /* Packet stats sent_stats and rcvd_stats are incremented in Flow::incStats */
   l4stats.incStats(when, l4_proto, rcvd_packets, rcvd_bytes, sent_packets,
                    sent_bytes);
+
+  if (host->isRxOnlyHost() && !isReceiveOnly()) /* no longer RX-only */
+    host->toggleRxOnlyHost(false);
 }
 
 #ifdef NTOPNG_PRO
