@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,12 +24,14 @@
 /* *************************************** */
 
 ICMPinfo::ICMPinfo() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   unreach = NULL;
   reset();
 }
 /* *************************************** */
 
 ICMPinfo::ICMPinfo(const ICMPinfo &_icmp_info) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   unreach = NULL;
   reset();
 
@@ -57,6 +59,7 @@ void ICMPinfo::reset() {
 /* *************************************** */
 
 ICMPinfo::~ICMPinfo() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   if (unreach) free(unreach);
 }
 
@@ -100,25 +103,20 @@ void ICMPinfo::dissectICMP(u_int16_t const payload_len,
     icmp_type = payload_data[0], icmp_code = payload_data[1];
 
     if (icmp_type == ICMP_DEST_UNREACH && icmp_code == ICMP_PORT_UNREACH &&
-        payload_len >= sizeof(struct ndpi_iphdr)) {
-      struct ndpi_iphdr *icmp_port_unreach_ip =
-          (struct ndpi_iphdr *)&payload_data[8];
-      u_short icmp_port_unreach_iph_len =
-          (u_short)(icmp_port_unreach_ip->ihl * 4);
-
-      if (payload_len >=
-              icmp_port_unreach_iph_len + sizeof(struct ndpi_udphdr) &&
-          icmp_port_unreach_ip->protocol == IPPROTO_UDP &&
-          (unreach ||
-           (unreach = (unreachable_t *)calloc(1, sizeof(*unreach))))) {
-        struct ndpi_udphdr *icmp_port_unreach_udp =
-            (struct ndpi_udphdr *)&payload_data[8 + icmp_port_unreach_iph_len];
+        payload_len >= (sizeof(struct ndpi_iphdr) + 8)) {
+      struct ndpi_iphdr *icmp_port_unreach_ip = (struct ndpi_iphdr *)&payload_data[8];
+      u_short icmp_port_unreach_iph_len = (u_short)(icmp_port_unreach_ip->ihl * 4);
 
+      if ((payload_len >= (8 + icmp_port_unreach_iph_len + sizeof(struct ndpi_udphdr)))
+	  && (icmp_port_unreach_ip->protocol == IPPROTO_UDP)
+	  && (unreach || (unreach = (unreachable_t *)calloc(1, sizeof(*unreach))))) {
+        struct ndpi_udphdr *icmp_port_unreach_udp = (struct ndpi_udphdr *)&payload_data[8 + icmp_port_unreach_iph_len];
+	
         unreach->src_ip.set(icmp_port_unreach_ip->saddr),
-            unreach->dst_ip.set(icmp_port_unreach_ip->daddr),
-            unreach->src_port = icmp_port_unreach_udp->source,
-            unreach->dst_port = icmp_port_unreach_udp->dest,
-            unreach->protocol = icmp_port_unreach_ip->protocol;
+	  unreach->dst_ip.set(icmp_port_unreach_ip->daddr),
+	  unreach->src_port = icmp_port_unreach_udp->source,
+	  unreach->dst_port = icmp_port_unreach_udp->dest,
+	  unreach->protocol = icmp_port_unreach_ip->protocol;
       }
     } else if ((icmp_type == ICMP_ECHO || icmp_type == ICMP_ECHOREPLY ||
                 icmp_type == ICMP_TIMESTAMP ||
