@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,6 +33,8 @@
 /* *************************************** */
 
 IEC104Stats::IEC104Stats() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   memset(&pkt_lost, 0, sizeof(pkt_lost));
   last_type_i = 0;
   memset(&last_i_apdu, 0, sizeof(last_i_apdu));
@@ -46,13 +48,16 @@ IEC104Stats::IEC104Stats() {
 
 /* *************************************** */
 
-IEC104Stats::~IEC104Stats() { ndpi_free_data_analysis(i_s_apdu, 1); }
+IEC104Stats::~IEC104Stats() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  ndpi_free_data_analysis(i_s_apdu, 1);
+}
 
 /* *************************************** */
 
 void IEC104Stats::processPacket(Flow *f, bool tx_direction,
                                 const u_char *payload, u_int16_t payload_len,
-                                struct timeval *packet_time) {
+				const struct pcap_pkthdr *h) {
   if ((payload_len >= 6) && (payload[0] == 0x68 /* IEC magic byte */)) {
     u_int offset = 1 /* Skip magic byte */;
     u_int64_t *allowedTypeIDs = ntop->getPrefs()->getIEC104AllowedTypeIDs();
@@ -65,13 +70,11 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
     else
       stats.reverse_msgs++;
 
-    while (offset /* Skip START byte */ < payload_len) {
+    while ((offset+1) /* Skip START byte */ < payload_len) {
       /* https://infosys.beckhoff.com/english.php?content=../content/1033/tcplclibiec870_5_104/html/tcplclibiec870_5_104_objref_overview.htm&id
        */
-      u_int8_t len = payload[offset],
-               pdu_type = ((payload[offset + 1] & 0x01) == 0)
-                              ? 0
-                              : (payload[offset + 1] & 0x03);
+      u_int8_t len = payload[offset];
+      u_int8_t pdu_type = ((payload[offset + 1] & 0x01) == 0) ? 0 : (payload[offset + 1] & 0x03);
 
 #ifdef DEBUG_IEC60870
       ntop->getTrace()->traceEvent(TRACE_WARNING, "[%s] %02X %02X %02X %02X",
@@ -90,7 +93,7 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
 
       switch (pdu_type) {
         case 0x03: /* U */
-        {
+	{
           u_int8_t u_type = (payload[offset + 1] & 0xFC) >> 2;
           const char *u_type_str;
 
@@ -133,37 +136,38 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
 
           snprintf(infobuf, sizeof(infobuf) - 1, "%s U (%s)",
                    tx_direction ? "->" : "<-", u_type_str);
-        } break;
+        }
+	break;
 
         case 0x01: /* S */
-          if (len >= 4) {
-            u_int16_t rx = ((((u_int16_t)payload[offset + 4]) << 8) +
-                            payload[offset + 3]) >>
-                           1;
+	  if((offset+4) < payload_len) {
+	    if (len >= 4) {
+	      u_int16_t rx = ((((u_int16_t)payload[offset + 4]) << 8) + payload[offset + 3]) >> 1;
 
-            if (last_i_apdu.tv_sec != 0) {
-              float ms = Utils::msTimevalDiff(packet_time, &last_i_apdu);
+	      if (last_i_apdu.tv_sec != 0) {
+		float ms = Utils::msTimevalDiff(&h->ts, &last_i_apdu);
 
 #ifdef IEC60870_TRACE
-              ntop->getTrace()->traceEvent(
+		ntop->getTrace()->traceEvent(
                   TRACE_NORMAL,
                   "A-PDU S [last I-TX: %u][S RX ack: %u][tdiff: %.2f msec]",
                   tx_seq_num, rx, ms);
 #endif
-              /*
-                In theory if all is in good shape
-                (rx + 1) == tx_seq_num
-              */
+		/*
+		  In theory if all is in good shape
+		  (rx + 1) == tx_seq_num
+		*/
 
-              ndpi_data_add_value(i_s_apdu, ms);
-            }
+		ndpi_data_add_value(i_s_apdu, ms);
+	      }
 
-            /* No rx and tx to be updated */
-            snprintf(infobuf, sizeof(infobuf) - 1, "%s S, RX %u",
-                     tx_direction ? "->" : "<-", rx);
-          }
+	      /* No rx and tx to be updated */
+	      snprintf(infobuf, sizeof(infobuf) - 1, "%s S, RX %u",
+		       tx_direction ? "->" : "<-", rx);
+	    }
 
-          stats.type_s++;
+	    stats.type_s++;
+	  }
           break;
       }
 
@@ -174,7 +178,7 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
       }
 
       /* From now on, only Type I packets are processed */
-      memcpy(&last_i_apdu, packet_time, sizeof(struct timeval));
+      memcpy(&last_i_apdu, &h->ts, sizeof(struct timeval));
       stats.type_i++;
 
       if(((offset + 6) < payload_len) && (len >= 6 /* Ignore 4 bytes APDUs */)) {
@@ -282,7 +286,8 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
 
                 if ((!ntop->getRedis()->get(key, rsp, sizeof(rsp))) &&
                     ((rsp[0] != '\0') && (!strcmp(rsp, "1"))))
-                  alert = new IECInvalidTransitionAlert(NULL, f, packet_time,
+                  alert = new IECInvalidTransitionAlert(NULL, f,
+							(struct timeval*)&h->ts,
                                                         last_type_i, type_id);
 
                 if (alert) {
@@ -322,9 +327,9 @@ void IEC104Stats::processPacket(Flow *f, bool tx_direction,
 
               if ((!ntop->getRedis()->get(key, rsp, sizeof(rsp))) &&
                   ((rsp[0] != '\0') && (!strcmp(rsp, "1"))))
-                alert = new IECInvalidCommandTransitionAlert(
-                    NULL, f, packet_time, transitions.m_to_c,
-                    transitions.c_to_m, transitions.c_to_c);
+                alert = new IECInvalidCommandTransitionAlert(NULL, f,
+							     (struct timeval*)&h->ts, transitions.m_to_c,
+							     transitions.c_to_m, transitions.c_to_c);
 
               if (alert) {
                 f->setPredominantAlertInfo(alert);
@@ -484,14 +489,12 @@ void IEC104Stats::lua(lua_State *vm) {
 
 /* *************************************** */
 
-char *IEC104Stats::getFlowInfo(char *buf, u_int buf_len) {
-  if (buf) {
-    lock.rdlock(__FILE__, __LINE__);
-    snprintf(buf, buf_len - 1, "%s", infobuf);
-    lock.unlock(__FILE__, __LINE__);
-  }
+std::string IEC104Stats::getFlowInfo() {
+  lock.rdlock(__FILE__, __LINE__);
+  std::string info_field = std::string(infobuf);
+  lock.unlock(__FILE__, __LINE__);
 
-  return (buf);
+  return info_field;
 }
 
 /* *************************************** */
