@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,8 @@
 /* ******************************************* */
 
 IpAddress::IpAddress() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   ip_key = 0;
   memset(&addr, 0, sizeof(addr));
   compute_key();
@@ -76,12 +78,15 @@ void IpAddress::reloadBlacklist(ndpi_detection_module_struct *ndpi_struct) {
   char ipbuf[64];
   char *ip_str = print(ipbuf, sizeof(ipbuf));
   ndpi_protocol_category_t category;
-
-  if ((ndpi_get_custom_category_match(ndpi_struct,
-				      ip_str, strlen(ip_str),
-				      &category) == 0)
-      && (category == CUSTOM_CATEGORY_MALWARE))
-    addr.blacklistedIP = true;
+  
+  if(ndpi_get_custom_category_match(ndpi_struct,
+				    ip_str, strlen(ip_str),
+				    &category) == 0) {
+    category = (ndpi_protocol_category_t)(category & 0xFF); /* See Ntop::nDPILoadHostnameCategory */
+    
+    if(category == CUSTOM_CATEGORY_MALWARE)
+      addr.blacklistedIP = true;
+  }
 }
 
 /* ******************************************* */
@@ -146,6 +151,8 @@ void IpAddress::checkIP() {
       addr.multicastIP = true;
     else if ((a == 0xFFFFFFFF) || (a == 0))
       addr.broadcastIP = true;
+    else if ((a & 0xFF000000) == 0x7F000000)
+      addr.localIP = true;
     else if (ntop->isLocalAddress(AF_INET, &addr.ipType.ipv4, &local_network_id,
                                   &nmask_bits)) {
       addr.localIP = true;
