@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,7 @@
 
 /* ************************************************ */
 
-void ListeningPorts::parsePortInfo(
-    json_object *z, std::map<u_int16_t, ListeningPortInfo> *info) {
+void ListeningPorts::parsePortInfo(json_object *z, std::map<u_int16_t, ListeningPortInfo> *info) {
   json_object *p;
   ListeningPortInfo pinfo;
   u_int16_t port = 0;
