@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,13 @@
 
 /* *************************************** */
 
-LocalHost::LocalHost(NetworkInterface *_iface, Mac *_mac, u_int16_t _vlanId,
+LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
+		     Mac *_mac, u_int16_t _vlanId,
                      u_int16_t _observation_point_id, IpAddress *_ip)
-    : Host(_iface, _mac, _vlanId, _observation_point_id, _ip) {
+  : Host(_iface, _iface_idx, _mac, _vlanId, _observation_point_id, _ip),
+    contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"), usedPorts(this) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+
 #ifdef LOCALHOST_DEBUG
   char buf[48];
 
@@ -37,18 +41,25 @@ LocalHost::LocalHost(NetworkInterface *_iface, Mac *_mac, u_int16_t _vlanId,
 
 /* *************************************** */
 
-LocalHost::LocalHost(NetworkInterface *_iface, char *ipAddress,
-                     u_int16_t _vlanId, u_int16_t _observation_point_id)
-    : Host(_iface, ipAddress, _vlanId, _observation_point_id) {
+LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
+		     char *ipAddress, u_int16_t _vlanId,
+		     u_int16_t _observation_point_id)
+  : Host(_iface, _iface_idx, ipAddress, _vlanId, _observation_point_id),
+  contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"), usedPorts(this) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   initialize();
 }
 
 /* *************************************** */
 
 LocalHost::~LocalHost() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   addInactiveData();
   if (initial_ts_point) delete (initial_ts_point);
   freeLocalHostData();
+  /* Decrease number of active hosts */
+  if(isUnicastHost())
+    iface->decNumHosts(isLocalHost(), is_rx_only);
 }
 
 /* *************************************** */
@@ -77,20 +88,20 @@ void LocalHost::set_hash_entry_state_idle() {
     }
   }
 
-  iface->decNumHosts(true /* A local host */, isRxOnlyHost());
-
-  if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
-    ns->decNumHosts();
+  /* Only increase the number of host if it's a unicast host */
+  if(isUnicastHost()) {
+    if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
+      ns->decNumHosts();
+  }
 
   GenericHashEntry::set_hash_entry_state_idle();
 }
 
 /* *************************************** */
 
-/* NOTE: Host::initialize will be called from the Host initializator */
+/* NOTE: Host::initialize will be called by the constructor after the Host initializator */
 void LocalHost::initialize() {
   char buf[64], host[96], rsp[256];
-
   stats = allocateStats();
   updateHostPool(true /* inline with packet processing */,
                  true /* first inc */);
@@ -105,8 +116,7 @@ void LocalHost::initialize() {
   /* Clone the initial point. It will be written to the timeseries DB to
    * address the first point problem
    * (https://github.com/ntop/ntopng/issues/2184). */
-  initial_ts_point =
-      new (std::nothrow) LocalHostStats(*(LocalHostStats *)stats);
+  initial_ts_point = new (std::nothrow) LocalHostStats(*(LocalHostStats *)stats);
   initialization_time = time(NULL);
 
   char *strIP = ip.print(buf, sizeof(buf));
@@ -125,14 +135,17 @@ void LocalHost::initialize() {
     }
   }
 
-  INTERFACE_PROFILING_SUB_SECTION_ENTER(
-      iface, "LocalHost::initialize: updateHostTrafficPolicy", 18);
+  INTERFACE_PROFILING_SUB_SECTION_ENTER(iface, "LocalHost::initialize: updateHostTrafficPolicy", 18);
   updateHostTrafficPolicy(host);
   INTERFACE_PROFILING_SUB_SECTION_EXIT(iface, 18);
 
-  iface->incNumHosts(true /* Local Host */, isRxOnlyHost());
-  if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
-    ns->incNumHosts();
+  /* Only increase the number of host if it's a unicast host */
+  if(isUnicastHost()) {
+    if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
+      ns->incNumHosts();
+
+    iface->incNumHosts(true /* isLocalHost() */, true /* Initialization: bytes are 0, considered RX only */);
+  }
 
 #ifdef LOCALHOST_DEBUG
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s is %s [%p]",
@@ -141,11 +154,24 @@ void LocalHost::initialize() {
 #endif
 
   router_mac_set = 0, memset(router_mac, 0, sizeof(router_mac));
-  setRxOnlyHost(true);
 
 #ifdef HAVE_NEDGE
   drop_all_host_traffic = 0;
 #endif
+
+  if (ntop->getPrefs()->enableFingerprintStats())
+    fingerprints = new (std::nothrow) HostFingerprints();
+  else
+    fingerprints = NULL;
+
+
+#ifdef NTOPNG_PRO
+  if ((!(isBroadcastHost() || isMulticastHost()))
+      && ntop->getPrefs()->is_enterprise_xl_edition()
+      && (ntop->getPrefs()->isAssetInventoryEnabled() || ntop->getPrefs()->isNetBoxEnabled()))
+    dumpAssetInfo();
+#endif
+
 }
 
 /* *************************************** */
@@ -178,13 +204,13 @@ void LocalHost::addInactiveData() {
     return;
 
 #if 0
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, 
+  ntop->getTrace()->traceEvent(TRACE_NORMAL,
     "Adding Host %s to inactive hosts Interace %d, with MAC: %s",
     ip.print(buf, sizeof(buf)),
     iface->get_id(),
     cur_mac->print(buf, sizeof(buf)));
-#endif                               
- 
+#endif
+
   ndpi_init_serializer(&host_json, ndpi_serialization_format_json);
   ndpi_serialize_string_string(&host_json, "ip", ip.print(buf, sizeof(buf)));
 
@@ -199,9 +225,9 @@ void LocalHost::addInactiveData() {
   ndpi_serialize_string_uint32(&host_json, "vlan", (u_int16_t) get_vlan_id());
   ndpi_serialize_string_uint32(&host_json, "network", (u_int16_t) get_local_network_id());
   ndpi_serialize_string_string(&host_json, "name", get_name(buf, sizeof(buf), false));
-  
 
-  
+
+
   json_str = ndpi_serializer_get_buffer(&host_json, &json_str_len);
   if ((json_str != NULL) && (json_str_len > 0)) {
     char key[128], redis_key[64];
@@ -216,7 +242,7 @@ void LocalHost::addInactiveData() {
 
 void LocalHost::removeInactiveData() {
   char key[128], redis_key[64];
-  
+
   /* Remove the key from the hash, used to get the offline hosts */
   if(!ntop->getRedis() || !isLocalUnicastHost())
     return;
@@ -472,10 +498,12 @@ void LocalHost::freeLocalHostData() {
     os_detail = NULL;
   }
 
-  for (std::unordered_map<u_int32_t, DoHDoTStats *>::iterator it =
-           doh_dot_map.begin();
+  for (std::unordered_map<u_int32_t, DoHDoTStats *>::iterator it = doh_dot_map.begin();
        it != doh_dot_map.end(); ++it)
     delete it->second;
+
+  if(fingerprints)
+    delete fingerprints;
 }
 
 /* *************************************** */
@@ -591,8 +619,8 @@ void LocalHost::setRouterMac(Mac *gw) {
 
 /* *************************************** */
 
-void LocalHost::setRxOnlyHost(bool set_it) {
-  is_rx_only = set_it;
+void LocalHost::toggleRxOnlyHost(bool rx_only) {
+  Host::toggleRxOnlyHost(rx_only);
 
   if (isLocalUnicastHost()) {
     char hostbuf[64], *member;
@@ -611,3 +639,86 @@ void LocalHost::setRxOnlyHost(bool set_it) {
     }
   }
 }
+
+/* ***************************************************** */
+
+void LocalHost::setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto, time_t when) {
+  bool set_port_status = usedPorts.setServerPort(isTCP, port, proto);
+
+  if (set_port_status
+      && ntop->getPrefs()->is_enterprise_l_edition()) {
+    /* If the port is set for the first time set_port_status == true */
+    u_int32_t learning_period = ntop->getPrefs()->hostPortLearningPeriod();
+
+    if (when - get_first_seen() > learning_period) {
+      if (!contacted_server_ports.isFull()) {
+	/* ntop->getTrace()->traceEvent(TRACE_NORMAL, "*** port %u ***", port); */
+        contacted_server_ports.enqueue({port, proto->app_protocol}, true);
+      } else {
+	char ip_buf[64];
+
+        ntop->getTrace()->traceEvent(TRACE_INFO,
+				     "Server port %s:%d contacted but not reported: exceeded max number",
+				     printMask(ip_buf, sizeof(ip_buf)), port);
+      }
+
+    }
+  }
+}
+
+/* ***************************************************** */
+
+void LocalHost::lua_get_fingerprints(lua_State *vm) {
+  if(fingerprints) {
+    fingerprints->ja4.lua("ja4_fingerprint", vm);
+    fingerprints->hassh.lua("hassh_fingerprint", vm);
+  }
+}
+
+/* *************************************** */
+
+#ifdef NTOPNG_PRO
+void LocalHost::dumpAssetInfo() {
+  char buf[64], mac_buf[32], *json_str = NULL, *ip = printMask(buf, sizeof(buf)), *mac_ptr;
+  ndpi_serializer device_json;
+  u_int32_t json_str_len = 0;
+
+  ndpi_init_serializer(&device_json, ndpi_serialization_format_json);
+
+  mac_ptr = Utils::formatMac(getMac()->get_mac(), mac_buf, sizeof(mac_buf));
+
+  if (getMac() && serializeByMac()) {
+    /* DHCP */
+    ndpi_serialize_string_string(&device_json, "key", mac_ptr);
+
+    ndpi_serialize_string_uint32(&device_json, "role", mac->getDeviceType());
+  } else {
+    /* IP */
+    ndpi_serialize_string_string(&device_json, "key", ip);
+    ndpi_serialize_string_uint32(&device_json, "role", getDeviceType());
+  }
+
+  ndpi_serialize_string_string(&device_json, "mac", mac_ptr);
+  if(mac->get_manufacturer())
+    ndpi_serialize_string_string(&device_json, "manufacturer", mac->get_manufacturer());
+
+  if(isIPv6())
+    ndpi_serialize_string_string(&device_json, "ipv6", ip);
+  else
+    ndpi_serialize_string_string(&device_json, "ipv4", ip);
+
+  ndpi_serialize_string_string(&device_json, "source", "traffic");
+  ndpi_serialize_string_uint32(&device_json, "first_seen", first_seen);
+  ndpi_serialize_string_uint32(&device_json, "last_seen", last_seen);
+
+  json_str = ndpi_serializer_get_buffer(&device_json, &json_str_len);
+
+  if((json_str != NULL) && (json_str_len > 0)) {
+    char key[64];
+    snprintf(key, sizeof(key), ASSET_LIST_INSERTION_KEY, iface->get_id());
+    ntop->getRedis()->rpush(key, json_str, 1024);
+  }
+
+  ndpi_term_serializer(&device_json);
+}
+#endif
