@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,8 @@
 #endif
 
 struct keyval string_to_replace[MAX_NUM_HTTP_REPLACEMENTS] = {
-    {NULL, NULL}}; /* TODO remove */
+  { NULL, NULL }
+}; /* TODO remove */
 
 extern luaL_Reg *ntop_interface_reg;
 extern luaL_Reg *ntop_reg;
@@ -38,17 +39,22 @@ extern luaL_Reg *ntop_network_reg;
 extern luaL_Reg *ntop_flow_reg;
 extern luaL_Reg *ntop_host_reg;
 
-#define HTTP_MAX_UPLOAD_DATA_LEN \
-  25000000 /* ~25MB (see also upload_pcap.template) */
+#ifdef HAVE_NTOP_CLOUD
+extern luaL_Reg *ntop_cloud_reg;
+#endif
+
+#define HTTP_MAX_UPLOAD_DATA_LEN  25000000 /* ~25MB (see also upload_pcap.template) */
+
+/* #define TRACE_VM_ENGINES */
 
 /* ******************************* */
 
-struct ntopngLuaContext *getUserdata(struct lua_State *vm) {
+NtopngLuaContext *getUserdata(struct lua_State *vm) {
   if (vm) {
-    struct ntopngLuaContext *userdata;
-
+    NtopngLuaContext *userdata;
+    
     lua_getglobal(vm, "userdata");
-    userdata = (struct ntopngLuaContext *)lua_touserdata(vm, lua_gettop(vm));
+    userdata = (NtopngLuaContext *)lua_touserdata(vm, lua_gettop(vm));
     lua_pop(vm, 1);  // undo the push done by lua_getglobal
 
     return (userdata);
@@ -93,77 +99,108 @@ static void stackDump(lua_State *L) {
 
 /* ******************************* */
 
-LuaEngine::LuaEngine(lua_State *vm) {
-  std::bad_alloc bax;
-  void *ctx;
+static u_int32_t upper_power_of_two(u_int32_t n) {
+  n--;
+  n |= n >> 1;
+  n |= n >> 2;
+  n |= n >> 4;
+  n |= n >> 8;
+  n |= n >> 16;
+  n++;
+  
+  return n;
+}
 
+/* Custom memory allocator */
+static void *l_alloc(void *ud, void *ptr, size_t old_size, size_t new_size) {
+  LuaEngine *le = (LuaEngine*)ud;
+
+  le->incMemUsed(new_size - old_size);
+
+  if(new_size == 0) {
+#if 0
+    ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				 "[Lua free] old size: %d ptr %p / tot: %d",
+				 old_size, ptr, le->getMemUsed());
+#endif
+
+    free(ptr);
+    return(NULL);
+  } else {
+    if(new_size < 32)
+      new_size = 32;
+    else
+      new_size = upper_power_of_two(new_size);
+    
+#if 0
+    ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				 "[Lua realloc] new size: %d ptr %p / tot: %d",
+				 new_size, ptr, le->getMemUsed());
+#endif 
+
+    return(realloc(ptr, new_size));
+  }
+}
+
+/* ******************************* */
+
+LuaEngine::LuaEngine() {
+  std::bad_alloc bax;
+
+  // if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
+  ntop->incNumLuaVMs();
+  start_epoch= (u_int32_t)time(NULL);
+  
   loaded_script_path = NULL;
   is_system_vm = false;
-
-  L = luaL_newstate();
+  mem_used = 0;
+  
+  L = lua_newstate(l_alloc, this);
 
   if (!L) {
-    ntop->getTrace()->traceEvent(TRACE_ERROR,
-                                 "Unable to create a new Lua state.");
+    ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to create a new Lua state.");
     throw bax;
   }
 
-  ctx = (void *)calloc(1, sizeof(struct ntopngLuaContext));
+  lua_context = new NtopngLuaContext;
 
-  if (!ctx) {
+  if (!lua_context) {
     ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to create a context for the new Lua state.");
     lua_close(L);
     throw bax;
   }
 
-  lua_pushlightuserdata(L, ctx);
+  lua_pushlightuserdata(L, (void*)lua_context);
   lua_setglobal(L, "userdata");
-
-  if (vm) setThreadedActivityData(vm);
 }
 
 /* ******************************* */
 
 LuaEngine::~LuaEngine() {
+  // if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if (L) {
-    struct ntopngLuaContext *ctx;
+    lua_settop(L, 0);
 
 #ifdef DUMP_STACK
     stackDump(L);
 #endif
+    
+    if(lua_context)
+      delete lua_context;     
+    
+    ntop->decNumLuaVMs();
 
-    ctx = getLuaVMContext(L);
-
-    if (ctx) {
-      if (ctx->snmpBatch) delete ctx->snmpBatch;
-
-      for (u_int8_t slot_id = 0; slot_id < MAX_NUM_ASYNC_SNMP_ENGINES;
-           slot_id++) {
-        if (ctx->snmpAsyncEngine[slot_id] != NULL)
-          delete ctx->snmpAsyncEngine[slot_id];
-      }
-
-      if (ctx->pkt_capture.end_capture > 0) {
-        ctx->pkt_capture.end_capture = 0; /* Force stop */
-        pthread_join(ctx->pkt_capture.captureThreadLoop, NULL);
-      }
-
-      if ((ctx->iface != NULL) && ctx->live_capture.pcaphdr_sent)
-        ctx->iface->deregisterLiveCapture(ctx);
-
-      if (ctx->addr_tree != NULL) delete ctx->addr_tree;
-
-      if (ctx->sqlite_hosts_filter) free(ctx->sqlite_hosts_filter);
-
-      if (ctx->sqlite_flows_filter) free(ctx->sqlite_flows_filter);
-
-#if defined(NTOPNG_PRO)
-      if (ctx->bin) delete ctx->bin;
+#ifdef TRACE_VM_ENGINES
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Terminated VM [# LuaVMs: %u][Duration: %u sec][Memory: %u][%s]",
+				 ntop->getNumActiveLuaVMs(),
+				 (u_int32_t)time(NULL)-start_epoch+1,
+				 getMemUsed(),
+				 loaded_script_path ? loaded_script_path : "");
 #endif
-      free(ctx);
-    }
 
-    lua_close(L);
+    lua_close(L); /* Free memory */
   }
 
   if (loaded_script_path) free(loaded_script_path);
@@ -222,8 +259,7 @@ int ntop_lua_return_value(lua_State *vm, const char *function_name, int val) {
                                    "https://github.com/ntop/ntopng/issues");
     }
 
-    lua_pushnil(
-        vm); /* Add dummy push to make sure the stack has a return value */
+    lua_pushnil(vm); /* Add dummy push to make sure the stack has a return value */
   }
 
   return (val);
@@ -299,6 +335,7 @@ static int ntop_lua_http_print(lua_State *vm) {
           mg_printf(conn, "%s", key);
           // PrintTable(vm);
         }
+	
         lua_pop(vm, 1);
       }
     } break;
@@ -344,6 +381,35 @@ int ntop_lua_cli_print(lua_State *vm) {
 
 /* ****************************************** */
 
+int ntop_lua_cloud_print(lua_State *vm) {
+  int t;
+  LuaEngine *engine = getLuaVMUserdata(vm, engine);
+  
+  ntop->getTrace()->traceEvent(TRACE_DEBUG, "%s() called", __FUNCTION__);
+
+  switch (t = lua_type(vm, 1)) {
+    case LUA_TSTRING: {
+      char *str = (char *)lua_tostring(vm, 1);
+
+      if (str && (strlen(str) > 0))
+        engine->pushResultString(str);
+    } break;
+
+    case LUA_TNUMBER:
+      engine->pushResultNumber((float)lua_tonumber(vm, 1));
+      break;
+
+    default:
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "%s(): Lua type %d is not handled", __FUNCTION__, t);
+      return (CONST_LUA_ERROR);
+  }
+
+  lua_pushnil(vm);
+  return (CONST_LUA_OK);
+}
+
+/* ****************************************** */
+
 #if defined(NTOPNG_PRO) || defined(HAVE_NEDGE)
 
 static int __ntop_lua_handlefile(lua_State *L, char *script_path, bool ex) {
@@ -364,23 +430,30 @@ static int __ntop_lua_handlefile(lua_State *L, char *script_path, bool ex) {
 /* This function is called by Lua scripts when the call require(...) */
 static int ntop_lua_require(lua_State *L) {
   char *script_name;
+  LuaEngine *engine = getUserdata(L)->engine;
 
-  if (lua_type(L, 1) != LUA_TSTRING ||
-      (script_name = (char *)lua_tostring(L, 1)) == NULL)
+  if (lua_type(L, 1) != LUA_TSTRING
+      || (script_name = (char *)lua_tostring(L, 1)) == NULL)
     return 0;
 
-  ntop->getTrace()->traceEvent(TRACE_DEBUG, "%s(%s)", __FUNCTION__,
-                               script_name);
+  if(engine->require(std::string(script_name))) {    
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Circular dependency found %s\n", script_name);
+    // return(0); /* Already loaded */
+  }
+  
+  ntop->getTrace()->traceEvent(TRACE_DEBUG, "%s(%s)", __FUNCTION__, script_name);
 
   lua_getglobal(L, "package");
   lua_getfield(L, -1, "path");
 
   string cur_path = lua_tostring(L, -1), parsed, script_path = "";
   stringstream input_stringstream(cur_path);
+
   while (getline(input_stringstream, parsed, ';')) {
     /* Example: package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;"
      * .. package.path */
     unsigned found = parsed.find_last_of("?");
+    
     if (found) {
       string s = parsed.substr(0, found) + script_name + ".lua";
       size_t first_dot = s.find("."), last_dot = s.rfind(".");
@@ -438,6 +511,10 @@ static int ntop_lua_xfile(lua_State *L, bool ex) {
   if (ret && (!lua_isnil(L, -1))) {
     const char *msg = lua_tostring(L, -1);
     ntop->getTrace()->traceEvent(TRACE_WARNING, "Script failure %s", msg);
+    if(ntop->getRedis()) {
+      /* Push the alert into this queue, used by the alert */
+      ntop->getRedis()->lpush(ALERT_TRACE_ERRORS, msg, 50 /* No Trim */);
+    }
   }
 
   return !ret;
@@ -455,24 +532,37 @@ static int ntop_lua_loadfile(lua_State *L) { return ntop_lua_xfile(L, false); }
 
 /* ****************************************** */
 
-void LuaEngine::lua_register_classes(lua_State *L, bool http_mode) {
+void LuaEngine::lua_register_classes(lua_State *L, LuaEngineMode mode) {
   if (!L) return;
 
+  getLuaVMContext(L)->engine = this;
+    
   /* ntop add-ons */
   luaRegister(L, "interface", ntop_interface_reg);
-  luaRegister(L, "ntop", ntop_reg);
-  luaRegister(L, "network", ntop_network_reg);
-  luaRegister(L, "flow", ntop_flow_reg);
-  luaRegister(L, "host", ntop_host_reg);
-
-  if (http_mode) {
+  luaRegister(L, "ntop",      ntop_reg);
+  luaRegister(L, "network",   ntop_network_reg);
+  luaRegister(L, "flow",      ntop_flow_reg);
+  luaRegister(L, "host",      ntop_host_reg);
+#ifdef HAVE_NTOP_CLOUD
+  luaRegister(L, "cloud",     ntop_cloud_reg);
+#endif
+  
+  switch(mode) {
+  case lua_engine_mode_http:
     /* Overload the standard Lua print() with ntop_lua_http_print that dumps
      * data on HTTP server */
     lua_register(L, "print", ntop_lua_http_print);
-  } else {
+    break;
+    
+  case lua_engine_mode_callback:
     lua_register(L, "print", ntop_lua_cli_print);
-  }
+    break;
 
+  case lua_engine_mode_cloud:
+    lua_register(L, "print", ntop_lua_cloud_print);    
+    break;
+  }
+  
 #if defined(NTOPNG_PRO) || defined(HAVE_NEDGE)
   if (ntop->getPro()->has_valid_license()) {
     lua_register(L, "ntopRequire", ntop_lua_require);
@@ -531,7 +621,9 @@ static int post_iterator(void *cls,
 /* ****************************************** */
 
 /* Loads a script into the engine from within ntopng (no HTTP GUI). */
-int LuaEngine::load_script(char *script_path, NetworkInterface *iface) {
+int LuaEngine::load_script(char *script_path,
+			   LuaEngineMode mode,
+			   NetworkInterface *iface) {
   int rc = 0;
   bool initialized;
 
@@ -545,7 +637,7 @@ int LuaEngine::load_script(char *script_path, NetworkInterface *iface) {
   try {
     if (!initialized) {
       luaL_openlibs(L);               /* Load base libraries */
-      lua_register_classes(L, false); /* Load custom classes */
+      lua_register_classes(L, mode);  /* Load custom classes */
     } else
       lua_settop(L, lua_gettop(L)); /* Reset the stack */
 
@@ -592,6 +684,7 @@ int LuaEngine::load_script(char *script_path, NetworkInterface *iface) {
 int LuaEngine::run_loaded_script() {
   int rv = 0;
 
+  ntop->getTrace()->traceEvent(TRACE_INFO, "Running %s", loaded_script_path);
   if (!loaded_script_path) return (-1);
 
   /* Copy the lua_chunk to be able to possibly run it again next time */
@@ -601,13 +694,14 @@ int LuaEngine::run_loaded_script() {
     getLuaVMUservalue(L, capabilities) = (u_int64_t)-1; /* All set */
 
   /* Perform the actual call */
-  if (lua_pcall(L, 0, LUA_MULTRET /* Allow the script to be called multiple times */,
-                0) != 0) {
+  if (lua_pcall(L, 0, LUA_MULTRET /* Allow the script to be called multiple times (used with cusotm host/flow scrips) */, 0) != 0) {
     if (lua_type(L, -1) == LUA_TSTRING) {
       const char *err = lua_tostring(L, -1);
 
-      if(err)
-	ntop->getTrace()->traceEvent(TRACE_WARNING, "%s", err);
+      if(err) {
+        ntop->getTrace()->traceEvent(TRACE_WARNING, "%s [%s]", err, loaded_script_path);
+        ntop->getRedis()->lpush(ALERT_TRACE_ERRORS, err, 50 /* No Trim */);   
+      }
     }
 
     rv = -2;
@@ -615,6 +709,10 @@ int LuaEngine::run_loaded_script() {
 
   lua_pop(L, 1);
 
+#ifndef HAS_LUAJIT
+  lua_gc(L, LUA_GCCOLLECT); /* Run garbage collector */
+#endif
+  
   return (rv);
 }
 
@@ -912,10 +1010,9 @@ bool LuaEngine::setParamsTable(lua_State *vm,
               !Utils::dir_exists(decoded_buf) &&
               strcmp(tok, "pid_name") /* This is the only exception */
           )
-            ntop->getTrace()->traceEvent(
-                TRACE_WARNING,
-                "Discarded '%s'='%s' as argument is a valid file path", tok,
-                decoded_buf);
+            ntop->getTrace()->traceEvent(TRACE_WARNING,
+					 "Discarded '%s'='%s' as argument is a valid file path", tok,
+					 decoded_buf);
           else
             lua_push_str_table_entry(vm, tok, decoded_buf);
 
@@ -988,8 +1085,8 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
 
   if (!L) return (-1);
 
-  luaL_openlibs(L);              /* Load base libraries */
-  lua_register_classes(L, true); /* Load custom classes */
+  luaL_openlibs(L);                              /* Load base libraries */
+  lua_register_classes(L, lua_engine_mode_http); /* Load custom classes */
 
   getLuaVMUservalue(L, conn) = conn;
 
@@ -1000,9 +1097,8 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
   /* Check for POST requests */
   if ((strcmp(request_info->request_method, "POST") == 0) &&
       (content_type != NULL)) {
-    int content_len = mg_get_content_len(conn) + 1;
-    bool is_file_upload =
-        (strncmp(content_type, "multipart/form-data", 19) == 0) ? true : false;
+    u_int32_t content_len = mg_get_content_len(conn) + 1;
+    bool is_file_upload = (strncmp(content_type, "multipart/form-data", 19) == 0) ? true : false;
 
     if ((!is_file_upload) && (content_len > HTTP_MAX_POST_DATA_LEN)) {
       ntop->getTrace()->traceEvent(TRACE_WARNING,
@@ -1011,16 +1107,22 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
                                    content_len, HTTP_MAX_POST_DATA_LEN,
                                    request_info->uri);
       valid_csrf = 0;
-    } else {
-      if (is_file_upload) {
-        if ((!is_file_upload) && (content_len > HTTP_MAX_UPLOAD_DATA_LEN)) {
+
+    } else { /* Content Len Ok or File Upload */
+
+      if (is_file_upload) { /* File Upload */
+
+        if (content_len > HTTP_MAX_UPLOAD_DATA_LEN) { /* Content Len Too Big */
+
           ntop->getTrace()->traceEvent(TRACE_WARNING,
                                        "You are uploading a file that is too "
                                        "big [len: %u][max len: %u][URI: %s]",
                                        content_len, HTTP_MAX_UPLOAD_DATA_LEN,
                                        request_info->uri);
           valid_csrf = 0;
-        } else {
+
+        } else { /* Content Len Ok */
+
           char fname[1024], upload_dir[512];
 
           snprintf(upload_dir, sizeof(upload_dir), "%s/tmp/upload",
@@ -1089,7 +1191,7 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
         } else {
           /* If here, authentication has taken place using a session, thus CSRF
              is mandatory in POST request and must be checked for validity. Note
-             that session_csrf is trusted, that it it comes from ntopng, whereas
+             that session_csrf is trusted, that it comes from ntopng, whereas
              csrf read from the POST is untrusted. */
           if (strstr(content_type, "application/json") == content_type) {
             /*
@@ -1150,11 +1252,10 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
                                             _POST table with POST parameters */
         else {
           /* application/json */
-
           lua_newtable(L);
-          lua_push_str_table_entry(
-              L, "payload", post_data); /* This payload is NOT parsed, checked
-                                           or verified against attacks */
+
+	  /* This payload is NOT parsed, checked or verified against attacks */
+          lua_push_str_table_entry(L, "payload", post_data); 
           lua_setglobal(L, "_POST");
         }
 
@@ -1390,11 +1491,14 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
 #endif
     rc = luaL_dofile(L, script_path);
 
+  //    lua_settop(L, 0);
+
   if (rc != 0) {
     const char *err = lua_tostring(L, -1);
 
     ntop->getTrace()->traceEvent(TRACE_WARNING, "Script failure [%s][%s]",
-                                 script_path, err);
+                                 script_path, err ? err : "Unknown error");
+    
     return (redirect_to_error_page(conn, request_info, "internal_error",
                                    script_path, (char *)err));
   }
@@ -1405,7 +1509,7 @@ int LuaEngine::handle_script_request(struct mg_connection *conn,
 /* ****************************************** */
 
 void LuaEngine::setHost(Host *h) {
-  struct ntopngLuaContext *c = getLuaVMContext(L);
+  NtopngLuaContext *c = getLuaVMContext(L);
 
   if (c) {
     c->host = h;
@@ -1417,7 +1521,7 @@ void LuaEngine::setHost(Host *h) {
 /* ****************************************** */
 
 void LuaEngine::setNetwork(NetworkStats *ns) {
-  struct ntopngLuaContext *c = getLuaVMContext(L);
+  NtopngLuaContext *c = getLuaVMContext(L);
 
   if (c) {
     c->network = ns;
@@ -1427,7 +1531,7 @@ void LuaEngine::setNetwork(NetworkStats *ns) {
 /* ****************************************** */
 
 void LuaEngine::setFlow(Flow *f) {
-  struct ntopngLuaContext *c = getLuaVMContext(L);
+  NtopngLuaContext *c = getLuaVMContext(L);
 
   if (c) {
     c->flow = f;
@@ -1437,24 +1541,10 @@ void LuaEngine::setFlow(Flow *f) {
 
 /* ****************************************** */
 
-void LuaEngine::setThreadedActivityData(lua_State *from) {
-  struct ntopngLuaContext *cur_ctx, *from_ctx;
-  lua_State *cur_state = getState();
-
-  if (from && (cur_ctx = getLuaVMContext(cur_state)) &&
-      (from_ctx = getLuaVMContext(from))) {
-    cur_ctx->deadline = from_ctx->deadline;
-    cur_ctx->threaded_activity = from_ctx->threaded_activity;
-    cur_ctx->threaded_activity_stats = from_ctx->threaded_activity_stats;
-  }
-}
-
-/* ****************************************** */
-
 void LuaEngine::setThreadedActivityData(const ThreadedActivity *ta,
                                         ThreadedActivityStats *tas,
                                         time_t deadline) {
-  struct ntopngLuaContext *cur_ctx;
+  NtopngLuaContext *cur_ctx;
   lua_State *cur_state = getState();
 
   if ((cur_ctx = getLuaVMContext(cur_state))) {
@@ -1463,3 +1553,43 @@ void LuaEngine::setThreadedActivityData(const ThreadedActivity *ta,
     cur_ctx->threaded_activity_stats = tas;
   }
 }
+
+/* ****************************************** */
+
+void LuaEngine::pushResultString(char *str) {
+  cloud_string.append(str);
+}
+
+/* ****************************************** */
+
+void LuaEngine::pushResultNumber(float f) {
+  char buf[32];
+
+  snprintf(buf, sizeof(buf), "%f", f);
+  cloud_string.append(buf);
+}
+
+/* ****************************************** */
+
+Host* LuaEngine::getHost() {
+  return (getLuaVMContext(L)->host);
+}
+
+/* ****************************************** */
+
+NetworkInterface* LuaEngine::getNetworkInterface() {
+  return (getLuaVMContext(L)->iface);
+}
+  
+/* ****************************************** */
+
+bool LuaEngine::require(std::string name) {  
+  std::set<std::string>::iterator it = require_list.find(name);
+
+  if(it != require_list.end())
+    return(true);
+  
+  require_list.insert(name);
+  return(false);
+}
+  
