@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 
 Mac::Mac(NetworkInterface *_iface, u_int8_t _mac[6])
     : GenericHashEntry(_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   memcpy(mac, _mac, 6);
 
   broadcast_mac = Utils::isBroadcastMac(mac);
@@ -67,6 +68,14 @@ Mac::Mac(NetworkInterface *_iface, u_int8_t _mac[6])
                                iface->getNumL2Devices());
 #endif
 
+#ifdef NTOPNG_PRO
+  if ((!special_mac)
+      && (!broadcast_mac)
+      && ntop->getPrefs()->is_enterprise_xl_edition()
+      && (ntop->getPrefs()->isAssetInventoryEnabled() || ntop->getPrefs()->isNetBoxEnabled()))
+    dumpAssetInfo();
+#endif
+
   updateHostPool(true /* inline with packet processing */,
                  true /* first inc */);
 }
@@ -74,10 +83,12 @@ Mac::Mac(NetworkInterface *_iface, u_int8_t _mac[6])
 /* *************************************** */
 
 Mac::~Mac() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+
   /* Serialize Mac before shutdown */
   if((!broadcast_mac) && (!special_mac))
     dumpToRedis();
-  
+
   if (!special_mac && ntop->getRedis() && ntop->getPrefs()->is_pro_edition()) {
     char mac_addr[64], mac_disconnection_key[128];
     snprintf(mac_disconnection_key, sizeof(mac_disconnection_key),
@@ -298,6 +309,18 @@ char *Mac::getDHCPName(char *const buf, ssize_t buf_size) {
 
 /* *************************************** */
 
+char *Mac::getDHCPNameNotLowerCase(char *const buf, ssize_t buf_size) {
+  if (buf && buf_size) {
+    m.lock(__FILE__, __LINE__);
+    snprintf(buf, buf_size, "%s", names.dhcp ? names.dhcp : "");
+    m.unlock(__FILE__, __LINE__);
+  }
+
+  return ((char*)buf);
+}
+
+/* *************************************** */
+
 void Mac::checkDeviceTypeFromManufacturer() {
   if (isNull()) return;
 
@@ -363,7 +386,7 @@ void Mac::inlineSetSSID(const char *s) {
 
 void Mac::inlineSetDHCPName(const char *dhcp_name) {
   if (!names.dhcp && dhcp_name &&
-      (names.dhcp = Utils::toLowerResolvedNames(dhcp_name)))
+      (names.dhcp = strdup(dhcp_name)))
     ;
 }
 
@@ -453,7 +476,7 @@ u_int64_t Mac::get_mac64() { return Mac::to64(mac); }
 
 void Mac::dumpToRedis() {
   char buf[32], *json_str = NULL;
-  ndpi_serializer mac_json; 
+  ndpi_serializer mac_json;
   u_int32_t json_str_len = 0;
 
   ndpi_init_serializer(&mac_json, ndpi_serialization_format_json);
@@ -463,7 +486,7 @@ void Mac::dumpToRedis() {
   ndpi_serialize_string_uint32(&mac_json, "first", first_seen);
   ndpi_serialize_string_uint32(&mac_json, "last",  last_seen);
   ndpi_serialize_end_of_block(&mac_json);
-  
+
   ndpi_serialize_string_uint32(&mac_json, "devtype", device_type);
   if(model) ndpi_serialize_string_string(&mac_json, "model", model);
   if(ssid) ndpi_serialize_string_string(&mac_json, "ssid", ssid);
@@ -471,15 +494,46 @@ void Mac::dumpToRedis() {
 
   if(stats)
     ((GenericTrafficElement*)stats)->serialize(&mac_json);
-  
+
   json_str = ndpi_serializer_get_buffer(&mac_json, &json_str_len);
   if ((json_str != NULL) && (json_str_len > 0)) {
     u_int expire_secs = 30 * 86400; /* 1 month */
     char key[64];
-    
+
     ntop->getTrace()->traceEvent(TRACE_INFO, "%s", json_str);
     ntop->getRedis()->set(getSerializationKey(key, sizeof(key)), json_str, expire_secs);
   }
 
   ndpi_term_serializer(&mac_json);
 }
+
+/* *************************************** */
+
+#ifdef NTOPNG_PRO
+void Mac::dumpAssetInfo() {
+  char buf[32], *json_str = NULL;
+  ndpi_serializer device_json;
+  u_int32_t json_str_len = 0;
+  char *mac_ptr = Utils::formatMac(get_mac(), buf, sizeof(buf));
+
+  ndpi_init_serializer(&device_json, ndpi_serialization_format_json);
+
+  ndpi_serialize_string_string(&device_json, "key", mac_ptr);
+  ndpi_serialize_string_string(&device_json, "mac", mac_ptr);
+  ndpi_serialize_string_string(&device_json, "source", "traffic");
+  ndpi_serialize_string_uint32(&device_json, "first_seen", first_seen);
+  ndpi_serialize_string_uint32(&device_json, "last_seen", last_seen);
+  ndpi_serialize_string_string(&device_json, "manufacturer", manuf ? manuf : "n/a");
+  ndpi_serialize_string_uint32(&device_json, "role", device_type);
+
+  json_str = ndpi_serializer_get_buffer(&device_json, &json_str_len);
+
+  if((json_str != NULL) && (json_str_len > 0)) {
+    char key[64];
+    snprintf(key, sizeof(key), ASSET_LIST_INSERTION_KEY, iface->get_id());
+    ntop->getRedis()->rpush(key, json_str, 1024);
+  }
+
+  ndpi_term_serializer(&device_json);
+}
+#endif
