@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,7 @@ void *MySQLDB::queryLoop() {
 
     if (rc == 0) {
       queue_not_empty = true;
-      try_exec_sql_query(&mysql, sql);
+      try_exec_sql_query(sql);
     } else {
       queue_not_empty = false;
       _usleep(10000);
@@ -100,7 +100,7 @@ bool MySQLDB::createDBSchema() {
     /* 1 - Create database if missing */
     snprintf(sql, sizeof(sql), "CREATE DATABASE IF NOT EXISTS `%s`",
              ntop->getPrefs()->get_mysql_dbname());
-    rc = exec_sql_query(&mysql, sql, true);
+    rc = exec_sql_query(sql, true);
     if (rc < 0) {
       printFailure(sql, rc);
       return (false);
@@ -150,7 +150,7 @@ bool MySQLDB::createDBSchema() {
         "PARTITIONS 32 */",
         ntop->getPrefs()->get_mysql_tablename());
 
-    rc = exec_sql_query(&mysql, sql, true);
+    rc = exec_sql_query(sql, true);
     if (rc < 0) {
       printFailure(sql, rc);
       return (false);
@@ -193,7 +193,7 @@ bool MySQLDB::createDBSchema() {
         "PARTITIONS 32 */",
         ntop->getPrefs()->get_mysql_tablename());
 
-    rc = exec_sql_query(&mysql, sql, true);
+    rc = exec_sql_query(sql, true);
     if (rc < 0) {
       printFailure(sql, rc);
       return (false);
@@ -206,11 +206,11 @@ bool MySQLDB::createDBSchema() {
     /* Add fields if not present */
     snprintf(sql, sizeof(sql), "ALTER TABLE `%sv4_%u` ADD `INFO` varchar(255)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
 
     snprintf(sql, sizeof(sql), "ALTER TABLE `%sv6_%u` ADD `INFO` varchar(255)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
 
 #ifdef NTOPNG_PRO
     snprintf(sql, sizeof(sql),
@@ -219,14 +219,14 @@ bool MySQLDB::createDBSchema() {
              "ADD INDEX `ix_%sv4_%u_profile` (PROFILE)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     snprintf(sql, sizeof(sql),
              "ALTER TABLE `%sv6_%u` "
              "ADD `PROFILE` varchar(255) DEFAULT NULL,"
              "ADD INDEX `ix_%sv6_%u_profile` (PROFILE)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
 #endif
     snprintf(
         sql, sizeof(sql),
@@ -235,7 +235,7 @@ bool MySQLDB::createDBSchema() {
         "ADD INDEX `ix_%sv4_%u_ntopng_instance_name` (NTOPNG_INSTANCE_NAME)",
         ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
         ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     snprintf(
         sql, sizeof(sql),
         "ALTER TABLE `%sv6_%u` "
@@ -243,21 +243,21 @@ bool MySQLDB::createDBSchema() {
         "ADD INDEX `ix_%sv6_%u_ntopng_instance_name` (NTOPNG_INSTANCE_NAME)",
         ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
         ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     snprintf(sql, sizeof(sql),
              "ALTER TABLE `%sv4_%u` "
              "ADD `INTERFACE` varchar(64) DEFAULT NULL,"
              "ADD INDEX `ix_%sv4_%u_ntopng_interface` (INTERFACE)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     snprintf(sql, sizeof(sql),
              "ALTER TABLE `%sv6_%u` "
              "ADD `INTERFACE` varchar(64) DEFAULT NULL,"
              "ADD INDEX `ix_%sv6_%u_ntopng_interface` (INTERFACE)",
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
 
     // We transfer old table contents into the new schema
     snprintf(sql, sizeof(sql),
@@ -265,22 +265,22 @@ bool MySQLDB::createDBSchema() {
              "SELECT * FROM `%sv4_%u`",
              ntop->getPrefs()->get_mysql_tablename(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     snprintf(sql, sizeof(sql),
              "INSERT IGNORE INTO `%sv6` "
              "SELECT * FROM `%sv6_%u`",
              ntop->getPrefs()->get_mysql_tablename(),
              ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
     // Drop old tables (their contents have been transferred)
   }
 
   snprintf(sql, sizeof(sql), "DROP TABLE IF EXISTS  `%sv4_%u` ",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
   snprintf(sql, sizeof(sql), "DROP TABLE IF EXISTS `%sv6_%u` ",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_id());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
 
   // Add extra indices to speedup queries
   snprintf(sql, sizeof(sql),
@@ -289,27 +289,27 @@ bool MySQLDB::createDBSchema() {
            "IP_SRC_ADDR, IP_DST_ADDR)",
            ntop->getPrefs()->get_mysql_tablename(),
            ntop->getPrefs()->get_mysql_tablename());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
   snprintf(sql, sizeof(sql),
            "ALTER TABLE `%sv6` "
            "ADD INDEX `ix_%sv6_ntopng_first_src_dst` (FIRST_SWITCHED, "
            "IP_SRC_ADDR, IP_DST_ADDR)",
            ntop->getPrefs()->get_mysql_tablename(),
            ntop->getPrefs()->get_mysql_tablename());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
 
   // Add an extra column with the interface id to speed up certain query
   snprintf(
       sql, sizeof(sql),
       "ALTER TABLE `%sv4` ADD COLUMN INTERFACE_ID SMALLINT(5) DEFAULT NULL",
       ntop->getPrefs()->get_mysql_tablename());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
 
   snprintf(
       sql, sizeof(sql),
       "ALTER TABLE `%sv6` ADD COLUMN INTERFACE_ID SMALLINT(5) DEFAULT NULL",
       ntop->getPrefs()->get_mysql_tablename());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
 
   // Populate the brand new column INTERFACE_ID with the ids of interfaces
   // and set to NULL the column INTERFACE
@@ -317,7 +317,7 @@ bool MySQLDB::createDBSchema() {
            "UPDATE `%sv4` SET INTERFACE_ID = %u WHERE INTERFACE ='%s'",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
            iface->get_name());
-  if (exec_sql_query(&mysql, sql, true, true) == 0) {
+  if (exec_sql_query(sql, true, true) == 0) {
     // change succeeded, we have to flush possibly existing mysql queues
     // that may have different format
     ntop->getRedis()->del((char *)CONST_SQL_QUEUE);
@@ -327,32 +327,32 @@ bool MySQLDB::createDBSchema() {
            "UPDATE `%sv6` SET INTERFACE_ID = %u WHERE INTERFACE ='%s'",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_id(),
            iface->get_name());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
   snprintf(sql, sizeof(sql),
            "UPDATE `%sv4` SET INTERFACE = NULL WHERE INTERFACE ='%s'",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_name());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
   snprintf(sql, sizeof(sql),
            "UPDATE `%sv6` SET INTERFACE = NULL WHERE INTERFACE ='%s'",
            ntop->getPrefs()->get_mysql_tablename(), iface->get_name());
-  exec_sql_query(&mysql, sql, true, true);
+  exec_sql_query(sql, true, true);
 
   // Check if the INTERFACE column can be dropped
   snprintf(sql, sizeof(sql),
            "SELECT 1 FROM `%sv4` WHERE INTERFACE IS NOT NULL LIMIT 1",
            ntop->getPrefs()->get_mysql_tablename());
-  if (exec_sql_query(&mysql, sql, true, true) == 0) {
+  if (exec_sql_query(sql, true, true) == 0) {
     snprintf(sql, sizeof(sql), "ALTER TABLE `%sv4` DROP COLUMN INTERFACE",
              ntop->getPrefs()->get_mysql_tablename());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
   }
   snprintf(sql, sizeof(sql),
            "SELECT 1 FROM `%sv6` WHERE INTERFACE IS NOT NULL LIMIT 1",
            ntop->getPrefs()->get_mysql_tablename());
-  if (exec_sql_query(&mysql, sql, true, true) == 0) {
+  if (exec_sql_query(sql, true, true) == 0) {
     snprintf(sql, sizeof(sql), "ALTER TABLE `%sv6` DROP COLUMN INTERFACE",
              ntop->getPrefs()->get_mysql_tablename());
-    exec_sql_query(&mysql, sql, true, true);
+    exec_sql_query(sql, true, true);
   }
 
   // Move column BYTES to BYTES_IN and add BYTES_OUT
@@ -368,7 +368,7 @@ bool MySQLDB::createDBSchema() {
              "AND COLUMN_NAME='BYTES' ",
              ntop->getPrefs()->get_mysql_dbname(),
              ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-    if (exec_sql_query(&mysql, sql, true, true) > 0) {
+    if (exec_sql_query(sql, true, true) > 0) {
       // if here, the column BYTES exists so we want to alter the table
       ntop->getTrace()->traceEvent(
           TRACE_NORMAL,
@@ -381,7 +381,7 @@ bool MySQLDB::createDBSchema() {
                "CHANGE BYTES IN_BYTES BIGINT DEFAULT 0, "
                "ADD OUT_BYTES BIGINT DEFAULT 0 AFTER IN_BYTES",
                ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-      exec_sql_query(&mysql, sql, true, true);
+      exec_sql_query(sql, true, true);
     }
   }
 
@@ -396,7 +396,7 @@ bool MySQLDB::createDBSchema() {
              "AND ENGINE='InnoDB' ",
              ntop->getPrefs()->get_mysql_dbname(),
              ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-    if (exec_sql_query(&mysql, sql, true, true) > 0) {
+    if (exec_sql_query(sql, true, true) > 0) {
       // if here, the table has engine InnoDB so we want to modify that to
       // MyISAM
       ntop->getTrace()->traceEvent(TRACE_INFO, "%s", sql);
@@ -408,7 +408,7 @@ bool MySQLDB::createDBSchema() {
 
       snprintf(sql, sizeof(sql), "ALTER TABLE `%sv%hu` ENGINE='MyISAM'",
                ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-      exec_sql_query(&mysql, sql, true, true);
+      exec_sql_query(sql, true, true);
     }
   }
 
@@ -422,7 +422,7 @@ bool MySQLDB::createDBSchema() {
              "GROUP BY TABLE_NAME HAVING COUNT(*) = 32 ",
              ntop->getPrefs()->get_mysql_dbname(),
              ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-    if (exec_sql_query(&mysql, sql, true, true) > 0) {
+    if (exec_sql_query(sql, true, true) > 0) {
       // if here, the table has 32 partitions and we want to convert them to 8
       ntop->getTrace()->traceEvent(TRACE_INFO, "%s", sql);
       ntop->getTrace()->traceEvent(
@@ -436,7 +436,7 @@ bool MySQLDB::createDBSchema() {
           "ALTER TABLE `%sv%hu` PARTITION BY HASH(FIRST_SWITCHED) PARTITIONS 8",
           ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
       ntop->getTrace()->traceEvent(TRACE_INFO, "%s", sql);
-      exec_sql_query(&mysql, sql, true, true);
+      exec_sql_query(sql, true, true);
     }
   }
 
@@ -454,7 +454,7 @@ bool MySQLDB::createDBSchema() {
                ntop->getPrefs()->get_mysql_dbname(),
                ntop->getPrefs()->get_mysql_tablename(), ipvers[i],
                counter_fields[j]);
-      if (exec_sql_query(&mysql, sql, true, true) > 0) {
+      if (exec_sql_query(sql, true, true) > 0) {
         // if here we have to convert the type to unsigned
         ntop->getTrace()->traceEvent(
             TRACE_NORMAL,
@@ -467,10 +467,11 @@ bool MySQLDB::createDBSchema() {
                  "ALTER TABLE `%sv%hu` MODIFY COLUMN `%s` int(10) unsigned",
                  ntop->getPrefs()->get_mysql_tablename(), ipvers[i],
                  counter_fields[j]);
-        exec_sql_query(&mysql, sql, true, true);
+        exec_sql_query(sql, true, true);
       }
     }
   }
+
   for (u_int16_t i = 0; i < sizeof(ipvers) / sizeof(u_int16_t); i++) {
     snprintf(sql, sizeof(sql),
              "SELECT 1 "
@@ -482,7 +483,7 @@ bool MySQLDB::createDBSchema() {
              "'auto_increment') ",
              ntop->getPrefs()->get_mysql_dbname(),
              ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-    if (exec_sql_query(&mysql, sql, true, true) > 0) {
+    if (exec_sql_query(sql, true, true) > 0) {
       // if here we have to convert the type to unsigned
       ntop->getTrace()->traceEvent(
           TRACE_NORMAL,
@@ -494,7 +495,7 @@ bool MySQLDB::createDBSchema() {
                "ALTER TABLE `%sv%hu` MODIFY COLUMN `idx` bigint NOT NULL "
                "AUTO_INCREMENT",
                ntop->getPrefs()->get_mysql_tablename(), ipvers[i]);
-      exec_sql_query(&mysql, sql, true, true);
+      exec_sql_query(sql, true, true);
     }
   }
 
@@ -506,6 +507,7 @@ bool MySQLDB::createDBSchema() {
 /* ******************************************* */
 
 MySQLDB::MySQLDB(NetworkInterface *_iface) : DB(_iface) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   mysqlEnqueuedFlows = 0;
   log_fd = NULL;
   open_log();
@@ -517,6 +519,8 @@ MySQLDB::MySQLDB(NetworkInterface *_iface) : DB(_iface) {
 /* ******************************************* */
 
 MySQLDB::~MySQLDB() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   shutdown();
   disconnectFromDB(&mysql);
 
@@ -608,7 +612,7 @@ char *MySQLDB::escapeAphostrophes(const char *unescaped) {
 
 int MySQLDB::flow2InsertValues(Flow *f, char *json, char *values_buf,
                                size_t values_buf_len) {
-  char cli_str[64], srv_str[64], *json_buf, *info_buf, buf[64];
+  char cli_str[64], srv_str[64], *json_buf, *info_buf;
   u_int32_t packets, first_seen, last_seen;
   u_int64_t bytes_cli2srv, bytes_srv2cli;
   size_t len;
@@ -617,7 +621,7 @@ int MySQLDB::flow2InsertValues(Flow *f, char *json, char *values_buf,
 
   json_buf = escapeAphostrophes((const char *)json);
   info_buf =
-      escapeAphostrophes((const char *)f->getFlowInfo(buf, sizeof(buf), false));
+      escapeAphostrophes((const char *)f->getFlowInfo(false).c_str());
 
   /* Prevents ERROR 1406 (22001): Data too long for column 'INFO' at row 1 */
   if (info_buf && strlen(info_buf) > 254) info_buf[255] = '\0';
@@ -668,7 +672,8 @@ int MySQLDB::flow2InsertValues(Flow *f, char *json, char *values_buf,
 
 /* ******************************************* */
 
-void MySQLDB::try_exec_sql_query(MYSQL *conn, char *sql) {
+void MySQLDB::try_exec_sql_query(char *sql) {
+  MYSQL *conn = &mysql;
   int rc;
 
   if (!db_operational) {
@@ -682,7 +687,7 @@ void MySQLDB::try_exec_sql_query(MYSQL *conn, char *sql) {
     ntop->getTrace()->traceEvent(
         TRACE_WARNING, "Tried to execute a query longer than %u. Skipping.",
         CONST_MAX_SQL_QUERY_LEN - 2);
-  } else if ((rc = exec_sql_query(conn, sql, true /* Attempt to reconnect */,
+  } else if ((rc = exec_sql_query(sql, true /* Attempt to reconnect */,
                                   true /* Don't print errors */, false)) < 0) {
     ntop->getTrace()->traceEvent(TRACE_ERROR, "MySQL error: %s [rc=%d]",
                                  get_last_db_error(conn), rc);
@@ -723,7 +728,7 @@ bool MySQLDB::dumpFlow(time_t when, Flow *f, char *json) {
      is not an issue and also avoids flows drops due to the redis queue
      maximum length
     */
-    try_exec_sql_query(&mysql, sql);
+    try_exec_sql_query(sql);
   } else {
     if (ntop->getRedis()->llen(CONST_SQL_QUEUE) < CONST_MAX_MYSQL_QUEUE_LEN) {
       /*
@@ -748,9 +753,9 @@ bool MySQLDB::dumpFlow(time_t when, Flow *f, char *json) {
 void MySQLDB::disconnectFromDB(MYSQL *conn) {
   if (conn != NULL) {
     mysql_close(conn);
-    ntop->getTrace()->traceEvent(
-        TRACE_NORMAL, "Disconnected from MySQL for interface %s...",
-        iface->get_name() ? iface->get_name() : "<unknown>");
+    ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				 "Disconnected from MySQL for interface %s...",
+				 iface->get_name() ? iface->get_name() : "<unknown>");
   }
 }
 
@@ -763,21 +768,48 @@ MYSQL *MySQLDB::mysql_try_connect(MYSQL *conn, const char *dbname) {
   char *user = ntop->getPrefs()->get_mysql_user();
   u_int port = ntop->getPrefs()->get_mysql_port();
   unsigned int connection_timeout = 5 /* sec */;
-  
+
   if (!host) return (NULL);
 
   /* Set the maximum database connection timeout */
   mysql_options(conn, MYSQL_OPT_CONNECT_TIMEOUT, &connection_timeout);
-  
-  if ((!ntop->getPrefs()->do_dump_flows_on_clickhouse()) &&
-      (host[0] == '/') /* Use socketD */)
+
+  if(ntop->getPrefs()->is_mysql_port_secure()) {
+#ifndef LIBMARIADB
+    /* MySQL */
+#if MYSQL_VERSION_ID > 50710
+    unsigned int opt_use_ssl = SSL_MODE_REQUIRED;
+
+    if(mysql_options(conn, MYSQL_OPT_SSL_MODE, (unsigned int const*) &opt_use_ssl) == 0)
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Enabled TLS support in MySQL client connection");
+    else
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unable to enable TLS support in MySQL: %s", mysql_error(conn));
+#else
+    ntop->getTrace()->traceEvent(TRACE_WARNING, "TLS not supported in this MySQL client version");
+#endif
+#else
+    /*
+       MariaDB [https://mariadb.com/kb/en/mysql_optionsv/]
+
+       MYSQL_OPT_SSL_ENFORCE: Whether to force TLS. This enables TLS with the default system settings.
+       It does not prevent the connection from being created if the server does not support TLS.
+    */
+    my_bool enforce_tls = 1;
+
+    if(mysql_optionsv(conn, MYSQL_OPT_SSL_ENFORCE, (void *)&enforce_tls) == 0)
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Enabled TLS support in MariaDB client connection (if server supports TLS)");
+    else
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unable to enable TLS support in MariaDB: %s", mysql_error(conn));
+#endif
+  }
+
+  if ((!ntop->getPrefs()->do_dump_flows_on_clickhouse()) && (host[0] == '/') /* Use socketD */)
     rc = mysql_real_connect(conn, NULL, /* Host */
                             user, ntop->getPrefs()->get_mysql_pw(), dbname, 0,
                             host /* socket */, flags);
   else {
-    ntop->getTrace()->traceEvent(
-        TRACE_INFO, "ClickHouse Connecting to %s:%u [user: %s][db: %s]", host,
-        port, user, dbname ? dbname : "");
+    ntop->getTrace()->traceEvent(TRACE_INFO, "ClickHouse Connecting to %s:%u [user: %s][db: %s]", host,
+				 port, user, dbname ? dbname : "");
     rc = mysql_real_connect(conn, host, user, ntop->getPrefs()->get_mysql_pw(),
                             dbname, port, NULL /* socket */, flags);
   }
@@ -848,20 +880,17 @@ bool MySQLDB::connectToDB(MYSQL *conn, bool select_db) {
   db_operational = false;
 
   if ((host == NULL) || (user == NULL)) {
-    ntop->getTrace()->traceEvent(
-        TRACE_WARNING, "%s not configured: connection failed", getEngineName());
+    ntop->getTrace()->traceEvent(TRACE_WARNING, "%s not configured: connection failed", getEngineName());
     return (db_operational);
   }
 
-  ntop->getTrace()->traceEvent(
-      TRACE_INFO, "Attempting to connect to %s for interface %s...",
-      getEngineName(), iface->get_name());
+  ntop->getTrace()->traceEvent(TRACE_INFO, "Attempting to connect to %s for interface %s...",
+			       getEngineName(), iface->get_name());
 
   m.lock(__FILE__, __LINE__);
 
   if (mysql_init(conn) == NULL) {
-    ntop->getTrace()->traceEvent(
-        TRACE_ERROR, "Failed to initialize %s connection", getEngineName());
+    ntop->getTrace()->traceEvent(TRACE_ERROR, "Failed to initialize %s connection", getEngineName());
     m.unlock(__FILE__, __LINE__);
     return (db_operational);
   }
@@ -878,13 +907,13 @@ bool MySQLDB::connectToDB(MYSQL *conn, bool select_db) {
 
   if(ntop->getPrefs()->do_dump_flows_on_clickhouse()) {
     if(!ntop->getPrefs()->is_enterprise_m_edition() && !ntop->getPrefs()->is_nedge_enterprise_edition()) {
-      ntop->getTrace()->traceEvent(TRACE_ERROR, "Enterprise license is required in order to use ClickHouse");      
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Enterprise license is required in order to use ClickHouse");
       m.unlock(__FILE__, __LINE__);
       return (db_operational);
     }
-    
+
     int rc = mysql_query(conn, "SELECT VERSION()");
-    
+
     if (rc < 0) {
       ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to read ClickHouse version");
       m.unlock(__FILE__, __LINE__);
@@ -892,14 +921,14 @@ bool MySQLDB::connectToDB(MYSQL *conn, bool select_db) {
     } else {
       MYSQL_RES *result = mysql_store_result(conn);
       MYSQL_ROW row = result ? mysql_fetch_row(result) : NULL;
-      
+
       if(!row) {
 	if(result) mysql_free_result(result);
 	m.unlock(__FILE__, __LINE__);
-	return (false);	
+	return (false);
       } else {
 	int clickhouse_version = atoi(row[0]);
-	int min_clickhouse_version = 22; /* See https://www.ntop.org/guides/ntopng/clickhouse/installation.html */       
+	int min_clickhouse_version = 22; /* See https://www.ntop.org/guides/ntopng/clickhouse/installation.html */
 
 	if(clickhouse_version < min_clickhouse_version) {
 	  ntop->getTrace()->traceEvent(TRACE_ERROR, "Your ClickHouse server v.%s is too old (< %u.X.X.X): please update",
@@ -910,19 +939,18 @@ bool MySQLDB::connectToDB(MYSQL *conn, bool select_db) {
 	} else
 	  ntop->getTrace()->traceEvent(TRACE_INFO, "Succesfully connected to ClickHouse server v.%s", row[0]);
       }
-      
+
       mysql_free_result(result);
     }
   }
-  
+
   db_operational = true;
 
-  ntop->getTrace()->traceEvent(
-      TRACE_NORMAL,
-      "Successfully connected to %s [%s@%s:%i][dbname: %s] for interface %s",
-      getEngineName(), user, host, port, dbname ? dbname : "",
-      iface->get_name());
-
+  ntop->getTrace()->traceEvent(TRACE_NORMAL,
+			       "Successfully connected to %s [%s@%s:%i][dbname: %s] for interface %s",
+			       getEngineName(), user, host, port, dbname ? dbname : "<no db>",
+			       iface->get_name());
+  
   m.unlock(__FILE__, __LINE__);
   return (db_operational);
 }
@@ -978,11 +1006,13 @@ int MySQLDB::exec_single_query(lua_State *vm, char *sql) {
   Locking is necessary when multiple queries are executed
   simultaneously (e.g. via Lua)
 */
-int MySQLDB::exec_sql_query(MYSQL *conn, const char *sql, bool doReconnect,
-                            bool ignoreErrors, bool doLock) {
-  int rc;
+int MySQLDB::exec_sql_query(const char *sql, bool doReconnect,
+                            bool ignoreErrors, bool doLock,
+                            db_result_row_callback *cb, void *cb_user_data) {
+  MYSQL *conn = &mysql;
   MYSQL_RES *result;
   struct timeval begin, end;
+  int rc;
 
   if (enable_db_traces) {
     ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s", sql);
@@ -1011,7 +1041,7 @@ int MySQLDB::exec_sql_query(MYSQL *conn, const char *sql, bool doReconnect,
 
           connectToDB(conn, true);
 
-          return (exec_sql_query(conn, sql, false));
+          return (exec_sql_query(sql, false));
         } else
           ntop->getTrace()->traceEvent(TRACE_INFO, "[%s][%s]",
                                        get_last_db_error(conn), sql);
@@ -1034,6 +1064,33 @@ int MySQLDB::exec_sql_query(MYSQL *conn, const char *sql, bool doReconnect,
       rc = mysql_num_rows(result);
       ntop->getTrace()->traceEvent(
           TRACE_INFO, "Current result set has %lu rows", (unsigned long)rc);
+
+      /* Callback - passing data row by row */
+      if (cb) {
+        MYSQL_ROW row;
+        int num_fields = mysql_field_count(&mysql);
+        char *fields[MYSQL_MAX_NUM_FIELDS] = { NULL };
+        int num = 0;
+        int ret;
+
+        if (num_fields > MYSQL_MAX_NUM_FIELDS)
+          num_fields = MYSQL_MAX_NUM_FIELDS;
+
+        while ((row = mysql_fetch_row(result))) {
+          if (num == 0) {
+            for (int i = 0; i < num_fields; i++) {
+              MYSQL_FIELD *field = mysql_fetch_field(result);
+              fields[i] = field->name;
+            }
+          }
+
+          ret = cb(row, fields, num_fields, cb_user_data);
+          if (ret != 0) break;
+
+          num++;
+        }
+      }
+
       mysql_free_result(result);
     }
   }
@@ -1061,8 +1118,8 @@ int MySQLDB::exec_sql_query(lua_State *vm, char *sql, bool limitRows,
   if (!ntop->getPrefs()->do_dump_flows_on_clickhouse()) {
     if (wait_for_db_created &&
         (!db_created /* Make sure the db exists before doing queries */)) {
-      ntop->getTrace()->traceEvent(
-          TRACE_NORMAL, "Unable to perform query: database being created");
+      ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				   "Unable to perform query: database being created");
       return (-2);
     }
   }
@@ -1224,9 +1281,8 @@ int MySQLDB::exec_quick_sql_query(char *sql, char *out, u_int out_len) {
 
   if (enable_db_traces) {
     gettimeofday(&end, NULL);
-    ntop->getTrace()->traceEvent(
-        TRACE_NORMAL, "Query completed in %.3f sec",
-        Utils::usecTimevalDiff(&end, &begin) / 1000000.);
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Query completed in %.3f sec",
+				 Utils::usecTimevalDiff(&end, &begin) / 1000000.);
   }
 
   if ((result == NULL) || (mysql_field_count(&mysql) == 0)) {
