@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,21 +21,23 @@
 
 #include "ntop_includes.h"
 
-// #define DEBUG_DISCOVERY
-
 /* ******************************* */
 
 NetworkDiscovery::NetworkDiscovery(NetworkInterface *_iface) {
   char errbuf[PCAP_ERRBUF_SIZE];
   const char *ifname;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   iface = _iface;
   ifname = iface->altDiscoverableName();
 
   if (ifname == NULL) ifname = iface->get_name();
 
   mdns_vm = NULL;
-  has_bpf_filter = false;
+  debug_mode = false;
+
+  /* Open pcap socket to capture ARP traffic */
 
 #if !defined(__arm__)
   if ((pd = pcap_open_live(ifname, 128 /* snaplen */, 0 /* no promisc */, 5,
@@ -44,7 +46,8 @@ NetworkDiscovery::NetworkDiscovery(NetworkInterface *_iface) {
   /* pcap_next can really block a lot if we do not activate immediate mode! See
    * https://github.com/mfontanini/libtins/issues/180 */
   if (((pd = pcap_create(ifname, errbuf)) == NULL) ||
-      (pcap_set_timeout(pd, 5) != 0) || (pcap_set_snaplen(pd, 128) != 0) ||
+      (pcap_set_timeout(pd, 5) != 0) ||
+      (pcap_set_snaplen(pd, 128) != 0) ||
       (pcap_set_immediate_mode(pd, 1) != 0) || /* enable immediate mode */
       (pcap_activate(pd) != 0))
 #endif
@@ -53,19 +56,23 @@ NetworkDiscovery::NetworkDiscovery(NetworkInterface *_iface) {
                                  "Unable to create pcap socket on %s [%d/%s]",
                                  ifname, errno, strerror(errno));
     udp_sock = -1;
-    throw("Unable to start network discovery");
-  } else {
-    const char *bpfFilter =
-        "arp && arp[6:2] = 2";  // arp[x:y] - from byte 6 for 2 bytes
-                                // (arp.opcode == 2 -> reply)
-
-    /* Set ARP filter */
-    if (pcap_compile(pd, &fcode, bpfFilter, 1, 0xFFFFFF00) == 0) {
-      pcap_setfilter(pd, &fcode);
-      has_bpf_filter = true;
-    }
+    throw("Unable to start Network Discovery");
   }
 
+  /* Set ARP filter */
+  // arp[x:y] - from byte 6 for 2 bytes
+  // (arp.opcode == 2 -> reply)
+  const char *bpfFilter = "arp && arp[6:2] = 2";  
+
+  if (pcap_compile(pd, &fcode, bpfFilter, 1, 0xFFFFFF00) == 0) {
+    if(pcap_setfilter(pd, &fcode) != 0)
+      throw("Unable to set ARP filter for Network Discovery");
+  } else {
+    throw("Failure compiling ARP filter for Network Discovery");
+  }
+
+  /* Open UDP socket */
+
   if ((udp_sock = Utils::openSocket(AF_INET, SOCK_DGRAM, 0,
                                     "NetworkDiscovery UDP")) != -1) {
     int rc;
@@ -85,11 +92,13 @@ NetworkDiscovery::NetworkDiscovery(NetworkInterface *_iface) {
 /* ******************************* */
 
 NetworkDiscovery::~NetworkDiscovery() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   if (pd) pcap_close(pd);
 
   Utils::closeSocket(udp_sock);
 
-  if (has_bpf_filter) pcap_freecode(&fcode);
+  pcap_freecode(&fcode);
 }
 
 /* ******************************************* */
@@ -151,7 +160,7 @@ void NetworkDiscovery::queueMDNSResponse(u_int32_t src_ip_nw_byte_order,
 /* ******************************* */
 
 typedef struct {
-  NetworkDiscovery *discover;
+  NetworkDiscovery *obj;
   int fd;
   int mdns_sock;
   lua_State *vm;
@@ -163,6 +172,7 @@ typedef struct {
   const char *ifname;
 } arp_data;
 
+/* Scan all hosts in a Network */
 static void arp_scan_hosts(ndpi_patricia_node_t *node, void *data,
                            void *user_data) {
   u_int32_t netp, maskp;
@@ -185,7 +195,7 @@ static void arp_scan_hosts(ndpi_patricia_node_t *node, void *data,
     else
       sender_ip.s_addr = 0;
 
-    arp_d->discover->sendArpNetwork(arp_d, netp, maskp, sender_ip.s_addr);
+    arp_d->obj->sendArpNetwork(arp_d, netp, maskp, sender_ip.s_addr);
   }
 }
 
@@ -222,18 +232,17 @@ void NetworkDiscovery::sendArpNetwork(void *data, u_int32_t netp,
 
   if (mdns_sock > max_sock) max_sock = mdns_sock;
 
-#ifdef DEBUG_DISCOVERY
-  {
+  if (debug_mode) {
     char buf0[32], buf1[32], buf2[32];
     u_int32_t first_ip_nbo = htonl(first_ip);
     u_int32_t last_ip_nbo = htonl(last_ip);
 
-    printf("ARP scan [as %s]: %s-%s\n",
+    ntop->getTrace()->traceEvent(TRACE_NORMAL,
+      "ARP scan [as %s]: %s-%s\n",
            inet_ntop(AF_INET, &sender_ip, buf0, sizeof(buf0)),
            inet_ntop(AF_INET, &first_ip_nbo, buf1, sizeof(buf1)),
            inet_ntop(AF_INET, &last_ip_nbo, buf2, sizeof(buf2)));
   }
-#endif
 
   for (int num_runs = 0; num_runs < 2; num_runs++) {
     for (host_ip = first_ip; host_ip < last_ip; host_ip++) {
@@ -269,9 +278,11 @@ void NetworkDiscovery::sendArpNetwork(void *data, u_int32_t netp,
             vm, Utils::formatMac(reply->arph.arp_sha, macbuf, sizeof(macbuf)),
             Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
 
-        ntop->getTrace()->traceEvent(
-            TRACE_INFO, "Received ARP reply from %s",
+        if (debug_mode) {
+          ntop->getTrace()->traceEvent(
+            TRACE_NORMAL, "Received ARP reply from %s",
             Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
+        }
 
         if (mdns_sock != -1) {
           mdns_dest->sin_addr.s_addr = reply->arph.arp_spa, dns_h->tr_id++;
@@ -322,15 +333,21 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
   int fd = -1;
   const char *ifname = iface->altDiscoverableName();
   arp_data arp_d;
+  char val[16];
 
-#ifndef WIN32
-  fd = pcap_get_selectable_fd(pd);
-#endif
+  val[0] = '\0';
+  debug_mode = (ntop->getRedis()->get(
+    (char *)CONST_PREFS_NETWORK_DISCOVERY_DEBUG, val, sizeof(val), true) == 0)
+    && (val[0] == '1');
 
   if (ifname == NULL) ifname = iface->get_name();
 
   if (!pd || !iface->getInterfaceNetworks()) return;
 
+#ifndef WIN32
+  fd = pcap_get_selectable_fd(pd);
+#endif
+
   lua_newtable(vm);
 
   setMDNSvm(vm);
@@ -352,10 +369,13 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
 
   if (ntop->getGlobals()->isShutdown()) return;
 
+  /* Opening MDNS socket */
   if ((mdns_sock = Utils::openSocket(AF_INET, SOCK_DGRAM, 0,
-                                     "NetworkDiscovery MDNS")) == -1)
+                                     "NetworkDiscovery MDNS")) == -1) {
+
     ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to create MDNS socket");
-  else {
+
+  } else {
     const char *anyservices = "_services._dns-sd._udp.local";
     u_int last_dot = 0;
     char *queries;
@@ -420,7 +440,7 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
   mdns_dest.sin_family = AF_INET, mdns_dest.sin_port = htons(5353);
 
   /* Start the polling */
-  arp_d.discover = this;
+  arp_d.obj = this;
   arp_d.fd = fd;
   arp_d.mdns_sock = mdns_sock;
   arp_d.vm = vm;
@@ -431,8 +451,13 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
   arp_d.arp = &arp;
   arp_d.ifname = ifname;
 
+  /* Scan all interface networks */
   iface->getInterfaceNetworks()->walk(arp_scan_hosts, &arp_d);
 
+  if (debug_mode) {
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Collect pending ARP replies");
+  }
+
   /* Collect possibly pending replies */
   while (true) {
     if (fd != -1) {
@@ -446,26 +471,40 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
       if (select(fd + 1, &rset, NULL, NULL, &tv) <= 0) break;
     }
 
-    if ((reply = (struct arp_packet *)pcap_next(pd, &h)) != NULL) {
-      lua_push_str_table_entry(
-          vm, Utils::formatMac(reply->arph.arp_sha, macbuf, sizeof(macbuf)),
-          Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
+    reply = (struct arp_packet *) pcap_next(pd, &h);
 
-      ntop->getTrace()->traceEvent(
-          TRACE_INFO, "Received ARP reply from %s",
-          Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
-      mdns_dest.sin_addr.s_addr = reply->arph.arp_spa, dns_h->tr_id++;
-      if ((sendto(mdns_sock, mdnsbuf, dns_query_len, 0,
-                  (struct sockaddr *)&mdns_dest,
-                  sizeof(struct sockaddr_in)) < 0) &&
-          (errno != 0))
-        ntop->getTrace()->traceEvent(TRACE_ERROR, "Send error [%d/%s]", errno,
-                                     strerror(errno));
-    } else
+    if (reply == NULL)
       break;
+
+    lua_push_str_table_entry(
+        vm, Utils::formatMac(reply->arph.arp_sha, macbuf, sizeof(macbuf)),
+        Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
+
+    if (debug_mode) {
+      ntop->getTrace()->traceEvent(
+        TRACE_NORMAL, "Received ARP reply from %s",
+        Utils::intoaV4(ntohl(reply->arph.arp_spa), ipbuf, sizeof(ipbuf)));
+    }
+
+    mdns_dest.sin_addr.s_addr = reply->arph.arp_spa, dns_h->tr_id++;
+    if ((sendto(mdns_sock, mdnsbuf, dns_query_len, 0,
+                (struct sockaddr *)&mdns_dest,
+                sizeof(struct sockaddr_in)) < 0) &&
+        (errno != 0))
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Send error [%d/%s]", errno,
+                                     strerror(errno));
+  }
+
+  if (debug_mode) {
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Done reading ARP replies");
   }
 
   if (mdns_sock != -1) {
+
+    if (debug_mode) {
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Collect pending MDNS replies");
+    }
+
     while (true) {
       FD_ZERO(&rset);
       FD_SET(mdns_sock, &rset);
@@ -482,7 +521,12 @@ void NetworkDiscovery::arpScan(lua_State *vm) {
         break;
     }
 
+    /* Closing MDNS socket */
     Utils::closeSocket(mdns_sock);
+
+    if (debug_mode) {
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Done reading MDNS replies");
+    }
   }
 
   setMDNSvm(NULL);
@@ -886,10 +930,12 @@ void NetworkDiscovery::discover(lua_State *vm, u_int timeout) {
     int len =
         recvfrom(udp_sock, (char *)msg, sizeof(msg), 0, (sockaddr *)&from, &s);
 
-    ntop->getTrace()->traceEvent(
-        TRACE_INFO, "Received SSDP packet from %s:%u",
+    if (debug_mode) {
+      ntop->getTrace()->traceEvent(
+        TRACE_NORMAL, "Received SSDP packet from %s:%u",
         Utils::intoaV4(ntohl(from.sin_addr.s_addr), ipbuf, sizeof(ipbuf)),
         ntohs(from.sin_port));
+    }
 
     if (len > 0) {
       char src[32],
