@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,9 @@
 
 OtherAlertableEntity::OtherAlertableEntity(NetworkInterface *iface,
                                            AlertEntity entity)
-    : AlertableEntity(iface, entity) {}
+  : AlertableEntity(iface, entity) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+}
 
 /* ****************************************** */
 
@@ -42,12 +44,18 @@ void OtherAlertableEntity::luaAlert(lua_State *vm, const Alert *alert,
   lua_push_int32_table_entry(vm, "score", alert->score);
   lua_push_int32_table_entry(vm, "severity",
                              Utils::mapScoreToSeverity(alert->score));
-  lua_push_str_table_entry(vm, "name", getEntityValue().c_str());
+  if (!(alert->name.empty()))
+    lua_push_str_table_entry(vm, "name", alert->name.c_str());
+  else // leave it for retrocompatibility
+    lua_push_str_table_entry(vm, "name", getEntityValue().c_str());
+
   lua_push_uint64_table_entry(vm, "tstamp", alert->tstamp);
   lua_push_uint64_table_entry(vm, "tstamp_end", time(NULL));
   lua_push_int32_table_entry(vm, "granularity",
                              Utils::periodicityToSeconds((ScriptPeriodicity)p));
   lua_push_str_table_entry(vm, "json", alert->json.c_str());
+  lua_push_str_table_entry(vm, "ip", alert->ip.c_str());
+  lua_push_int32_table_entry(vm, "port", alert->port);
 }
 
 /* ****************************************** */
@@ -58,17 +66,20 @@ void OtherAlertableEntity::luaAlert(lua_State *vm, const Alert *alert,
 bool OtherAlertableEntity::triggerAlert(lua_State *vm, std::string key,
                                         ScriptPeriodicity p, time_t now,
                                         u_int32_t score, AlertType alert_id,
-                                        const char *subtype, const char *json) {
+                                        const char *subtype, const char *json,
+                                        const char *ip, const char *name,
+                                        u_int16_t port) {
   bool rv = false;
-  std::map<std::string, Alert>::iterator it;
+  std::map<u_int32_t /* std::string */, Alert>::iterator it;
 
   if (getEntityValue().empty()) {
-    ntop->getTrace()->traceEvent(
-        TRACE_ERROR, "setEntityValue() not called or empty entity_val");
+    ntop->getTrace()->traceEvent(TRACE_ERROR, "setEntityValue() not called or empty entity_val");
   } else {
+    u_int32_t num_key = ndpi_hash_string(key.c_str());
+    
     engaged_alerts_lock.wrlock(__FILE__, __LINE__);
 
-    it = engaged_alerts[(u_int)p].find(key);
+    it = engaged_alerts[(u_int)p].find(num_key);
 
     if (it == engaged_alerts[(u_int)p].end()) {
       Alert alert;
@@ -78,10 +89,13 @@ bool OtherAlertableEntity::triggerAlert(lua_State *vm, std::string key,
       alert.alert_id = alert_id;
       alert.subtype = subtype;
       alert.json = json;
+      alert.ip = ip ? ip : "";
+      alert.name = name ? name : "";
+      alert.port = port;
 
       incNumAlertsEngaged(Utils::mapScoreToSeverity(score));
 
-      engaged_alerts[(u_int)p][key] = alert;
+      engaged_alerts[(u_int)p][num_key] = alert;
 
       lua_newtable(vm);
       luaAlert(vm, &alert, p);
@@ -101,13 +115,15 @@ bool OtherAlertableEntity::triggerAlert(lua_State *vm, std::string key,
 
 bool OtherAlertableEntity::releaseAlert(lua_State *vm, std::string key,
                                         ScriptPeriodicity p, time_t now) {
-  std::map<std::string, Alert>::iterator it;
+  std::map<u_int32_t /* std::string */, Alert>::iterator it;
   bool rv = false;
 
   if (!engaged_alerts[(u_int)p].empty()) {
+    u_int32_t num_key = ndpi_hash_string(key.c_str());
+    
     engaged_alerts_lock.wrlock(__FILE__, __LINE__);
 
-    it = engaged_alerts[(u_int)p].find(key);
+    it = engaged_alerts[(u_int)p].find(num_key);
 
     if (it != engaged_alerts[(u_int)p].end()) {
       /* Set the release time */
@@ -123,7 +139,6 @@ bool OtherAlertableEntity::releaseAlert(lua_State *vm, std::string key,
       decNumAlertsEngaged(Utils::mapScoreToSeverity(it->second.score));
 
       engaged_alerts[(u_int)p].erase(it);
-
       rv = true; /* Actually released */
     }
 
@@ -138,7 +153,7 @@ bool OtherAlertableEntity::releaseAlert(lua_State *vm, std::string key,
 /* ****************************************** */
 
 void OtherAlertableEntity::countAlerts(grouped_alerts_counters *counters) {
-  std::map<std::string, Alert>::const_iterator it;
+  std::map<u_int32_t /* std::string */, Alert>::const_iterator it;
 
   for (int i = 0; i < MAX_NUM_PERIODIC_SCRIPTS; i++) {
     ScriptPeriodicity p = (ScriptPeriodicity)i;
@@ -146,12 +161,10 @@ void OtherAlertableEntity::countAlerts(grouped_alerts_counters *counters) {
     if (!engaged_alerts[p].empty()) {
       engaged_alerts_lock.rdlock(__FILE__, __LINE__);
 
-      for (it = engaged_alerts[p].begin(); it != engaged_alerts[p].end();
-           ++it) {
+      for (it = engaged_alerts[p].begin(); it != engaged_alerts[p].end(); ++it) {
         const Alert *alert = &it->second;
 
-        counters->severities[std::make_pair(
-            getEntityType(), Utils::mapScoreToSeverity(alert->score))]++;
+        counters->severities[std::make_pair(getEntityType(), Utils::mapScoreToSeverity(alert->score))]++;
         counters->types[std::make_pair(getEntityType(), alert->alert_id)]++;
       }
 
@@ -165,7 +178,7 @@ void OtherAlertableEntity::countAlerts(grouped_alerts_counters *counters) {
 void OtherAlertableEntity::getPeriodicityAlerts(
     lua_State *vm, ScriptPeriodicity p, AlertType type_filter,
     AlertLevel severity_filter, AlertRole role_filter, u_int *idx) {
-  std::map<std::string, Alert>::const_iterator it;
+  std::map<u_int32_t /* std::string */, Alert>::const_iterator it;
 
   if (!engaged_alerts[p].empty()) {
     engaged_alerts_lock.rdlock(__FILE__, __LINE__);
