@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -130,17 +130,20 @@ pfring *PF_RINGInterface::pfringSocketInit(const char *name) {
 /* **************************************************** */
 
 PF_RINGInterface::PF_RINGInterface(const char *_name)
-    : NetworkInterface(_name) {
+  : NetworkInterface(_name) {
   char name[MAX_INTERFACE_NAME_LEN];
   int err;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   num_pfring_handles = 0;
-  pcap_datalink_type = DLT_EN10MB;
   dropped_packets = 0;
-
+  merged_interfaces = strchr(_name, ',') ? true : false;
   strncpy(name, ifname, sizeof(name));
   name[sizeof(name) - 1] = '\0';
 
+  set_datalink(DLT_EN10MB);
+
   if (strchr(name, ':') && strchr(name, ',')) {
     char *item_name, *tmp;
 
@@ -184,6 +187,7 @@ PF_RINGInterface::PF_RINGInterface(const char *_name)
 PF_RINGInterface::~PF_RINGInterface() {
   int i;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
   shutdown();
 
   for (i = 0; i < num_pfring_handles; i++) {
@@ -209,7 +213,8 @@ void PF_RINGInterface::singlePacketPollLoop() {
         Flow *flow = NULL;
 
         if (hdr.ts.tv_sec == 0) gettimeofday(&hdr.ts, NULL);
-        dissectPacket(DUMMY_BRIDGE_INTERFACE_ID,
+        dissectPacket(merged_interfaces ? hdr.extended_hdr.if_index : UNKNOWN_PKT_IFACE_IDX,
+		      DUMMY_BRIDGE_INTERFACE_ID, get_datalink(),
                       (hdr.extended_hdr.rx_direction == 1) ? true /* ingress */
                                                            : false /* egress */,
                       NULL, (const struct pcap_pkthdr *)&hdr, buffer, &p,
@@ -258,7 +263,8 @@ void PF_RINGInterface::multiPacketPollLoop() {
         Flow *flow = NULL;
 
         if (hdr.ts.tv_sec == 0) gettimeofday(&hdr.ts, NULL);
-        dissectPacket(DUMMY_BRIDGE_INTERFACE_ID,
+	dissectPacket(merged_interfaces ? hdr.extended_hdr.if_index : UNKNOWN_PKT_IFACE_IDX,
+		      DUMMY_BRIDGE_INTERFACE_ID, get_datalink(),
                       (idx == 0) /* Assuming 0 ingress, 1 egress (TAP) */, NULL,
                       (const struct pcap_pkthdr *)&hdr, buffer, &p, &srcHost,
                       &dstHost, &flow);
