@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,8 @@
 /* **************************************************** */
 
 Paginator::Paginator() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   /* char* */
   sort_column = strdup("column_thpt");
   country_filter = NULL;
@@ -43,8 +45,8 @@ Paginator::Paginator() {
   /* int */
   max_hits = CONST_MAX_NUM_HITS;
   to_skip = 0;
-  l7proto_filter_master_proto = NDPI_PROTOCOL_UNKNOWN;
-  l7proto_filter_app_proto = NDPI_PROTOCOL_UNKNOWN;
+  l7proto_filter_master_proto = -1;
+  l7proto_filter_app_proto = -1;
   l7category_filter = -1;
   port_filter = 0;
   local_network_filter = CONST_MAX_NUM_NETWORKS + 1;
@@ -63,7 +65,7 @@ Paginator::Paginator() {
   mac_filter = NULL;
   alert_type_filter = ((u_int16_t)-1);
   alert_type_severity_filter = alert_level_group_none;
-
+  iface_index_filter = -1;
   deviceIP = 0;
   inIndex = outIndex = (u_int32_t)-1;
   asn_filter = (u_int32_t)-1;
@@ -228,6 +230,8 @@ void Paginator::readOptions(lua_State* L, int index) {
           icmp_code = lua_tointeger(L, -1);
         else if (!strcmp(key, "dscpFilter"))
           dscp_filter = lua_tointeger(L, -1);
+        else if (!strcmp(key, "ifaceIndex"))
+          iface_index_filter = lua_tointeger(L, -1);
         else if (!strcmp(key, "statusFilter"))
           alert_type_filter = lua_tointeger(L, -1);
         else if (!strcmp(key, "statusSeverityFilter"))
