@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,31 +44,38 @@ static activity_descr ad[] = {
 /* ******************************************* */
 
 PeriodicActivities::PeriodicActivities() {
-  num_activities = 0;
-  memset(activities, 0, sizeof(activities));
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
+  num_sec_min_activities = num_hour_day_activities = 0;
 
   th_pool = new ThreadPool();
   thread_running = false;
+  num_sec_min_activities = 0, num_hour_day_activities = 0;
 }
 
 /* ******************************************* */
 
 PeriodicActivities::~PeriodicActivities() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   delete th_pool;
 
-  /* Now it's safe to delete the activities as no other thread is executing
-   * their code. */
-  for (u_int16_t i = 0; i < num_activities; i++)
-    delete activities[i]; /* This line calls
-                             ThreadedActivity::~ThreadedActivity() */
+  /* Now it's safe to delete the activities as no other thread is executing their code. */
+  for (u_int16_t i = 0; i < num_sec_min_activities; i++)
+    delete sec_min_activities[i]; /* This line calls ThreadedActivity::~ThreadedActivity() */
 
-  num_activities = 0;
+  for (u_int16_t i = 0; i < num_hour_day_activities; i++)
+    delete hour_day_activities[i]; /* This line calls ThreadedActivity::~ThreadedActivity() */
 }
 
 /* ******************************************* */
 
 void PeriodicActivities::lua(NetworkInterface *iface, lua_State *vm) {
-  for (int i = 0; i < num_activities; i++) activities[i]->lua(iface, vm);
+  for (u_int16_t i = 0; i < num_sec_min_activities; i++)
+    sec_min_activities[i]->lua(iface, vm);  
+  
+  for (u_int16_t i = 0; i < num_hour_day_activities; i++)
+    hour_day_activities[i]->lua(iface, vm);      
 }
 
 /* **************************************************** */
@@ -85,18 +92,25 @@ static void *startActivity(void *ptr) {
 
 /* This is the main infinite loop */
 void PeriodicActivities::run() {
-  while (!(ntop->getGlobals()->isShutdownRequested() ||
-           ntop->getGlobals()->isShutdown())) {
+  while (!(ntop->getGlobals()->isShutdownRequested()
+	   || ntop->getGlobals()->isShutdown())) {
     u_int32_t now = (u_int32_t)time(NULL);
 
-    for (u_int16_t i = 0; i < num_activities; i++) activities[i]->schedule(now);
+    for (u_int16_t i = 0; i < num_sec_min_activities; i++)
+      sec_min_activities[i]->schedule(this, now, false);
 
+    if(num_running_hour_day_activities == 0) {
+      /* At most only one concurrent activity */
+      for (u_int16_t i = 0; i < num_hour_day_activities; i++)
+	hour_day_activities[i]->schedule(this, now, true);
+    }
+    
     sleep(1);
   }
 
   thread_running = false;
-  ntop->getTrace()->traceEvent(TRACE_NORMAL,
-                               "Terminated periodic activites...");
+
+  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Terminated periodic activites...");
 }
 
 /* ******************************************* */
@@ -115,15 +129,13 @@ void PeriodicActivities::startPeriodicActivitiesLoop() {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
                                  "The current user cannot access %s.",
                                  ntop->get_callbacks_dir());
-    ntop->getTrace()->traceEvent(
-        TRACE_ERROR,
-        "Please fix the directory right or add --dont-change-user to");
+    ntop->getTrace()->traceEvent(TRACE_ERROR,
+				 "Please fix the directory right or add --dont-change-user to");
     ntop->getTrace()->traceEvent(TRACE_ERROR, "the ntopng command line.");
     exit(0);
   }
 
-  if ((startup_activity =
-           new (std::nothrow) ThreadedActivity(STARTUP_SCRIPT_PATH))) {
+  if ((startup_activity = new (std::nothrow) ThreadedActivity(STARTUP_SCRIPT_PATH))) {
     /*
       Don't call run() as by the time the script will be run
       the delete below will free the memory
@@ -142,38 +154,47 @@ void PeriodicActivities::startPeriodicActivitiesLoop() {
       continue;
     }
 
-    ta = new (std::nothrow) ThreadedActivity(
-        ad[i].path, false, /* Exact */
-        ad[i].periodicity, ad[i].max_duration_secs, ad[i].align_to_localtime,
-        ad[i].exclude_viewed_interfaces, ad[i].exclude_pcap_dump_interfaces,
-        th_pool);
-    if (ta) activities[num_activities++] = ta;
+    ta = new (std::nothrow) ThreadedActivity(ad[i].path, false, /* Exact */
+					     ad[i].periodicity, ad[i].max_duration_secs, ad[i].align_to_localtime,
+					     ad[i].exclude_viewed_interfaces, ad[i].exclude_pcap_dump_interfaces,
+					     th_pool);
+
+    if (ta) {
+      if((strncmp(ad[i].path, "hour", 4) == 0)
+	 || (strncmp(ad[i].path, "daily", 5) == 0))	
+	hour_day_activities[num_hour_day_activities++] = ta;
+      else
+	sec_min_activities[num_sec_min_activities++] = ta;
+    }
+
 
     if (ad[i].periodicity >= 60 /* no delay for sub-minute scripts */) {
       char script_dir[64];
 
-      snprintf(script_dir, sizeof(script_dir), "%s%s", ad[i].path,
-               DELAYED_TRAILER);
+      snprintf(script_dir, sizeof(script_dir), "%s%s", ad[i].path, DELAYED_TRAILER);
 
-      ta = new (std::nothrow) ThreadedActivity(
-          script_dir, true, /* Delayed */
-          ad[i].periodicity, ad[i].max_duration_secs, ad[i].align_to_localtime,
-          ad[i].exclude_viewed_interfaces, ad[i].exclude_pcap_dump_interfaces,
-          th_pool);
-      if (ta) activities[num_activities++] = ta;
+      ta = new (std::nothrow) ThreadedActivity(script_dir, true, /* Delayed */
+					       ad[i].periodicity, ad[i].max_duration_secs, ad[i].align_to_localtime,
+					       ad[i].exclude_viewed_interfaces, ad[i].exclude_pcap_dump_interfaces,
+					       th_pool);
+      if (ta) {
+      if((strncmp(ad[i].path, "hour", 4) == 0)
+	 || (strncmp(ad[i].path, "daily", 5) == 0))	
+	hour_day_activities[num_hour_day_activities++] = ta;
+      else
+	sec_min_activities[num_sec_min_activities++] = ta;
+      }
     }
   }
 
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Found %u activities",
-                               num_activities);
+  ntop->getTrace()->traceEvent(TRACE_INFO, "Found [%u sec/min][%u hour/day] activity dirs",
+                               num_sec_min_activities, num_hour_day_activities);
 
   if (pthread_create(&pthreadLoop, NULL, startActivity, (void *)this) == 0) {
     thread_running = true;
 #ifdef __linux__
-    Utils::setThreadAffinityWithMask(
-        pthreadLoop, ntop->getPrefs()->get_other_cpu_affinity_mask());
+    Utils::setThreadAffinityWithMask(pthreadLoop, ntop->getPrefs()->get_other_cpu_affinity_mask());
 #endif
   }
 }
 
-/* ******************************************* */
