@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,8 @@ Radius::Radius(bool _use_chap) {
     https://it.wikipedia.org/wiki/Password_authentication_protocol
     https://en.wikipedia.org/wiki/Challenge-Handshake_Authentication_Protocol
   */
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   result = 0, use_chap = _use_chap; /* true = CHAP, false = PAP */
   radiusAuthServer = radiusAcctServer = radiusSecret = radiusAdminGroup =
     radiusUnprivCapabilitiesGroup = NULL;
@@ -154,23 +156,54 @@ bool Radius::buildConfiguration(rc_handle **rh) {
 /* Performs the basic configuration for the accounting, Status type, service,
  * username and session id */
 bool Radius::addBasicConfigurationAcct(rc_handle *rh, VALUE_PAIR **send,
-                                       u_int16_t status_type,
-                                       const char *username,
-                                       const char *session_id) {
+                                       u_int32_t status_type,
+                                       RadiusTraffic *info) {
   if (rc_avpair_add(rh, send, PW_ACCT_STATUS_TYPE, &status_type, -1, 0) == NULL) {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
                                  "Radius: unable to set Status Type");
     return false;
   }
 
-  if (rc_avpair_add(rh, send, PW_USER_NAME, username, -1, 0) == NULL) {
-    ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: unable to set username");
-    return false;
+  if(info->username) {
+    if (rc_avpair_add(rh, send, PW_USER_NAME, info->username, -1, 0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: unable to set username");
+      return false;
+    }
   }
 
-  if (rc_avpair_add(rh, send, PW_ACCT_SESSION_ID, session_id, -1, 0) == NULL) {
+  if(info->session_id) {
+    if (rc_avpair_add(rh, send, PW_ACCT_SESSION_ID, info->session_id, -1, 0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                  "Radius: unable to set Session ID");
+      return false;
+    }
+  }
+
+  if(info->last_ip) {
+    u_int32_t addr = ntohl(inet_addr(info->last_ip));
+    if (rc_avpair_add(rh, send, PW_FRAMED_IP_ADDRESS, &(addr), -1, 0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: unable to set IP Address");
+      return false;
+    }
+  }
+
+  if(info->mac) {
+    if (rc_avpair_add(rh, send, PW_CALLING_STATION_ID, info->mac, -1, 0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: unable to set MAC Address");
+      return false;
+    }
+  }
+
+  if(info->nas_port_name) {
+    if (rc_avpair_add(rh, send, PW_NAS_PORT_ID_STRING, info->nas_port_name, -1, 0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: unable to set Nas Port Name");
+      return false;
+    }
+  }
+
+  if (rc_avpair_add(rh, send, PW_NAS_PORT, &(info->nas_port_id), -1, 0) == NULL) {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
-                                 "Radius: unable to set Session ID");
+                                 "Radius: unable to set Nas Port ID");
     return false;
   }
 
@@ -220,6 +253,12 @@ bool Radius::addUpdateConfigurationAcct(rc_handle *rh, VALUE_PAIR **send,
     return false;
   }
 
+  if (rc_avpair_add(rh, send, PW_ACCT_SESSION_TIME, &(info->time), -1, 0) == NULL) {
+    ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                 "Radius: unable to set Accounting Session Time");
+    return false;
+  }
+
   return true;
 }
 
@@ -252,7 +291,7 @@ bool Radius::updateLoginInfo() {
   ntop->getRedis()->get((char *)PREF_RADIUS_UNPRIV_CAP_GROUP, radiusUnprivCapabilitiesGroup, MAX_RADIUS_LEN);
 
   if((radiusAuthServer[0] == '\0') || (radiusAcctServer[0] == '\0')) {
-    ntop->getTrace()->traceEvent(TRACE_INFO, "No Radius server configured for authentication or accounting [Auth: %s][Acct: %s]",
+    ntop->getTrace()->traceEvent(TRACE_DEBUG, "No Radius server configured for authentication or accounting [Auth: %s][Acct: %s]",
 				 radiusAuthServer, radiusAcctServer);
     return(false);
   }
@@ -394,7 +433,7 @@ bool Radius::authenticate(const char *user, const char *password,
 
 /* *************************************** */
 
-bool Radius::startSession(const char *username, const char *session_id) {
+bool Radius::startSession(RadiusTraffic *info) {
   /* Reset the return */
   bool radius_ret = false;
   rc_handle *rh = NULL;
@@ -404,15 +443,15 @@ bool Radius::startSession(const char *username, const char *session_id) {
     ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: Configuration Failed");
     goto radius_auth_out;
   }
-
-  if (!addBasicConfigurationAcct(rh, &send, PW_ACCOUNTING_ON, username, session_id)) {
+  
+  if (!addBasicConfigurationAcct(rh, &send, PW_STATUS_START, info)) {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
                                  "Radius: Accounting Configuration Failed");
     goto radius_auth_out;
   }
 
   ntop->getTrace()->traceEvent(TRACE_DEBUG,
-			       "Radius: performing accounting start for: %s", username);
+			       "Radius: performing accounting start for: %s", info->username);
 
   /* ****************************** */
 
@@ -437,7 +476,7 @@ bool Radius::startSession(const char *username, const char *session_id) {
 
 /* *************************************** */
 
-bool Radius::updateSession(const char *username, const char *session_id, RadiusTraffic *info) {
+bool Radius::updateSession(RadiusTraffic *info) {
   /* Reset the return */
   bool radius_ret = false;
   rc_handle *rh = NULL;
@@ -450,8 +489,7 @@ bool Radius::updateSession(const char *username, const char *session_id, RadiusT
   }
 
   /* Create the basic configuration, used by the accounting */
-  if (!addBasicConfigurationAcct(rh, &send, PW_STATUS_ALIVE, username,
-                                 session_id)) {
+  if (!addBasicConfigurationAcct(rh, &send, PW_STATUS_ALIVE, info)) {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
                                  "Radius: Accounting Configuration Failed");
     goto radius_auth_out;
@@ -465,7 +503,7 @@ bool Radius::updateSession(const char *username, const char *session_id, RadiusT
   }
 
   ntop->getTrace()->traceEvent(TRACE_DEBUG, "Radius: performing accounting interim-update for: %s",
-			       username);
+			       info->username);
 
   /* ****************************** */
 
@@ -489,8 +527,7 @@ bool Radius::updateSession(const char *username, const char *session_id, RadiusT
 
 /* *************************************** */
 
-bool Radius::stopSession(const char *username, const char *session_id,
-                         RadiusTraffic *info) {
+bool Radius::stopSession(RadiusTraffic *info) {
   /* Reset the return */
   bool radius_ret = false;
   rc_handle *rh = NULL;
@@ -503,8 +540,7 @@ bool Radius::stopSession(const char *username, const char *session_id,
   }
 
   /* Create the basic configuration, used by the accounting */
-  if (!addBasicConfigurationAcct(rh, &send, PW_ACCOUNTING_OFF,
-				 username, session_id)) {
+  if (!addBasicConfigurationAcct(rh, &send, PW_STATUS_STOP, info)) {
     ntop->getTrace()->traceEvent(TRACE_ERROR,
                                  "Radius: Accounting Configuration Failed");
     goto radius_auth_out;
@@ -513,15 +549,16 @@ bool Radius::stopSession(const char *username, const char *session_id,
   /* Add to the dictionary the interim-update data (needed even in the stop) */
   addUpdateConfigurationAcct(rh, &send, info);
 
-  /* TODO: Change the terminate clause to the correct one */
-  if (rc_avpair_add(rh, &send, PW_ACCT_TERMINATE_CAUSE, "No More Allowed", -1,
-                    0) == NULL) {
-    ntop->getTrace()->traceEvent(TRACE_ERROR,
-                                 "Radius: unable to set Bytes Sent");
-    return false;
+  if(info->terminate_cause) {
+    if (rc_avpair_add(rh, &send, PW_ACCT_TERMINATE_CAUSE, &(info->terminate_cause), -1,
+                      0) == NULL) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+                                  "Radius: unable to set Bytes Sent");
+      return false;
+    }
   }
 
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Radius: performing accounting stop for: %s", username);
+  ntop->getTrace()->traceEvent(TRACE_DEBUG, "Radius: performing accounting stop for: %s", info->username);
 
   /* ****************************** */
 
