@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,14 +21,19 @@
 
 #include "ntop_includes.h"
 
-//#define DEBUG_RECIPIENT_QUEUE
+// #define DEBUG_RECIPIENT_QUEUE
+// #define DEBUG_DB_QUEUE
+// #define DEBUG_DB_QUEUE_HOST_ALERTS
 
 /* *************************************** */
 
 RecipientQueue::RecipientQueue(u_int16_t _recipient_id) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   recipient_id = _recipient_id;
   queue = NULL, drops = 0, uses = 0;
   last_use = 0;
+  match_alert_id = false;
   skip_alerts = false;
 
   /* No minimum severity */
@@ -41,14 +46,6 @@ RecipientQueue::RecipientQueue(u_int16_t _recipient_id) {
   /* All entities enabled by default */
   for (int i = 0; i < ALERT_ENTITY_MAX_NUM_ENTITIES; i++)
     enabled_entities.setBit(i);
-    
-  /* All flow checks enabled by default */
-  for (int i = 0; i < MAX_DEFINED_FLOW_ALERT_TYPE; i++)
-    enabled_flow_checks.setBit(i);
-    
-  /* All host checks enabled by default */
-  for (int i = 0; i < NUM_DEFINED_HOST_CHECKS; i++)
-    enabled_host_checks.setBit(i);
 }
 
 /* *************************************** */
@@ -75,16 +72,39 @@ AlertFifoItem *RecipientQueue::dequeue() {
 
 /* *************************************** */
 
+bool RecipientQueue::doDebug(const AlertFifoItem* const notification) {
+#ifdef DEBUG_RECIPIENT_QUEUE
+  if (recipient_id 
+#ifdef DEBUG_DB_QUEUE
+                   == 0
+#else
+                   != 0
+#endif
+#ifdef DEBUG_DB_QUEUE_HOST_ALERTS
+      && notification->alert_entity == alert_entity_host
+#endif
+     )
+    return true;
+#endif
+  return false;
+}
+
+/* *************************************** */
+
 /* Filter and Enqueue alerts to the recipient
  * (similar to what recipients.dispatch_notification does in Lua)
  */
-bool RecipientQueue::enqueue(const AlertFifoItem* const notification,
-                             AlertEntity alert_entity) {
-  bool res = false;
+bool RecipientQueue::enqueue(const AlertFifoItem* const notification) {
+  bool res;
 
 #ifdef DEBUG_RECIPIENT_QUEUE
-  //if (recipient_id != 0 && alert_entity == alert_entity_am_host)
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, "Enqueueing alert to recipient %d", recipient_id);
+  if (doDebug(notification)) {
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Enqueueing alert to recipient %d "
+      "[severity %d][category %d][entity %d][alert-id %d]",
+      recipient_id,
+      notification->alert_severity, notification->alert_category, notification->alert_entity,  notification->alert_id);
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s", notification->alert.c_str());
+  }
 #endif
 
   /* Checking if the alerts have not to be enqueued */
@@ -92,36 +112,52 @@ bool RecipientQueue::enqueue(const AlertFifoItem* const notification,
     return true; /* Skipping alerts */
   else if(!skip_alerts) {
     /* In case alerts have not to be skipped, check the filters */
+
 #ifdef DEBUG_RECIPIENT_QUEUE
-    ntop->getTrace()->traceEvent(TRACE_NORMAL, "Checking alert (entity %d) for recipient %d", alert_entity, recipient_id);
+    if (doDebug(notification))
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Checking alert (entity %d) for recipient %d",
+        notification->alert_entity, recipient_id);
 #endif
    
-    if (!notification ||
-        notification->alert_severity <
-            minimum_severity /* Severity too low for this recipient     */
-        ||
-        !(enabled_categories.isSetBit(
-            notification
-                ->alert_category)) /* Category not enabled for this recipient */
-        || !(enabled_entities.isSetBit(
-              alert_entity)) /* Entity not enabled for this recipient */
-        ||
-        (alert_entity_flow == alert_entity && !enabled_flow_checks.isSetBit(notification->alert_id))
-        ||
-        (alert_entity_host == alert_entity && !enabled_host_checks.isSetBit(notification->alert_id))
-    ) {
-#ifdef DEBUG_RECIPIENT_QUEUE
-      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Alert filtered out due to filtering policy for recipient %d", recipient_id);
-#endif
+    if (!notification)
       return true; /* Nothing to enqueue */
+
+    if (match_alert_id) { /* Check by Alert Type */
+      if (alert_entity_flow == notification->alert_entity) {
+        if (!enabled_flow_alert_types.isSetBit(notification->alert_id))
+          return true; /* Nothing to enqueue */
+      } else if (alert_entity_host == notification->alert_entity) {
+        if (!enabled_host_alert_types.isSetBit(notification->alert_id))
+          return true; /* Nothing to enqueue */
+      } else { /* Other */
+        if (!enabled_other_alert_types.isSetBit(notification->alert_id - OTHER_BASE_KEY)) 
+          return true; /* Nothing to enqueue */
+      }
+    } else { /* Check by Severity, Category, Entity */
+
+      if (notification->alert_severity < minimum_severity /* Severity too low for this recipient     */
+          || !(enabled_categories.isSetBit(notification->alert_category)) /* Category not enabled for this recipient */
+          || !(enabled_entities.isSetBit(notification->alert_entity)) /* Entity not enabled for this recipient */) {
+#ifdef DEBUG_RECIPIENT_QUEUE
+        if (doDebug(notification))
+          ntop->getTrace()->traceEvent(TRACE_NORMAL, "Alert filtered out due to filtering policy for recipient %d "
+            "[severity %s (%d vs %d)][category %s (%d)][entity %s (%d)]",
+            recipient_id,
+            notification->alert_severity < minimum_severity ? "Nok" : "Ok", notification->alert_severity, minimum_severity,
+            !(enabled_categories.isSetBit(notification->alert_category)) ? "Nok" : "Ok", notification->alert_category,
+            !(enabled_entities.isSetBit(notification->alert_entity)) ? "Nok" : "Ok", notification->alert_entity);
+#endif
+        return true; /* Nothing to enqueue */
+      }
     }
 
-    if (recipient_id == 0 && /* Default recipient (DB) */
-        alert_entity == alert_entity_flow &&
-        ntop->getPrefs()->do_dump_flows_on_clickhouse()) {
-      /* Do not store flow alerts on ClickHouse as they are retrieved using a view
-      * on historical flows) */
-      /* But still increment the number of uses */
+    if((recipient_id == 0) /* Default recipient (DB) */
+       && (notification->alert_entity == alert_entity_flow)
+       && ntop->getPrefs()->do_dump_flows_on_clickhouse()) {
+      /*
+	Do not store flow alerts on ClickHouse as they are retrieved using a view on historical flows
+	(i.e. flow alerts are not stored but read from flows) But still increment the number of uses 
+      */
       uses++;
 #ifdef DEBUG_RECIPIENT_QUEUE
       ntop->getTrace()->traceEvent(TRACE_NORMAL, "Flow alert (no enqueue - clickhouse uses: %u)", uses);
@@ -134,14 +170,18 @@ bool RecipientQueue::enqueue(const AlertFifoItem* const notification,
       */
     } else {
       /* Other recipients (notifications) */
-      if (alert_entity == alert_entity_flow) {
-        if (!enabled_host_pools.isSetBit(
-                notification->flow.cli_host_pool) &&
+      if (notification->alert_entity == alert_entity_flow) {
+        if (!enabled_host_pools.isSetBit(notification->flow.cli_host_pool) &&
             !enabled_host_pools.isSetBit(notification->flow.srv_host_pool))
           return true;
-      } else if (alert_entity == alert_entity_host) {
-        if (!enabled_host_pools.isSetBit(notification->host.host_pool))
+      } else if (notification->alert_entity == alert_entity_host) {
+        if (!enabled_host_pools.isSetBit(notification->host.host_pool)) {
+#ifdef DEBUG_RECIPIENT_QUEUE
+          if (doDebug(notification))
+            ntop->getTrace()->traceEvent(TRACE_NORMAL, "Alert filtered out due to host pool filtering");
+#endif
           return true;
+        }
       }
     }
   }
@@ -156,6 +196,8 @@ bool RecipientQueue::enqueue(const AlertFifoItem* const notification,
   /* Enqueue the notification (allocate memory for the alert string) */
   AlertFifoItem *new_item = new AlertFifoItem(notification);
 
+  res = false;
+
   if (new_item) {
     res = queue->enqueue(new_item);
 
