@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,8 @@
 /* *************************************** */
 
 Recipients::Recipients() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   memset(&recipient_queues, 0, sizeof(recipient_queues));
   default_recipient_minimum_severity = alert_level_none;
 }
@@ -71,8 +73,7 @@ bool Recipients::enqueue(u_int16_t recipient_id,
      Perform the actual enqueue
    */
   if (recipient_queues[recipient_id]) {
-    res = recipient_queues[recipient_id]->enqueue(
-        notification, alert_entity_other /* TODO */);
+    res = recipient_queues[recipient_id]->enqueue(notification);
     
   }
 
@@ -89,8 +90,7 @@ bool Recipients::enqueue(u_int16_t recipient_id,
 
 /* *************************************** */
 
-bool Recipients::enqueue(const AlertFifoItem* const notification,
-                         AlertEntity alert_entity) {
+bool Recipients::enqueue(const AlertFifoItem* const notification) {
   bool res = true; /* Initialized to true so that if no recipient is responsible
                       for the notification, true will be returned. */
 
@@ -106,8 +106,7 @@ bool Recipients::enqueue(const AlertFifoItem* const notification,
     if (recipient_queues[recipient_id]) {
       bool success;
 
-      success =
-          recipient_queues[recipient_id]->enqueue(notification, alert_entity);
+      success = recipient_queues[recipient_id]->enqueue(notification);
 
       res &= success;
     }
@@ -131,8 +130,10 @@ void Recipients::register_recipient(u_int16_t recipient_id,
                                     Bitmap128 enabled_categories,
                                     Bitmap128 enabled_host_pools,
                                     Bitmap128 enabled_entities,
-                                    Bitmap128 enabled_flow_checks,
-                                    Bitmap128 enabled_host_checks,
+                                    Bitmap128 enabled_flow_alert_types,
+                                    Bitmap128 enabled_host_alert_types,
+                                    Bitmap128 enabled_other_alert_types,
+                                    bool match_alert_id,
                                     bool skip_alerts) {
   if (recipient_id >= MAX_NUM_RECIPIENTS) return;
 
@@ -146,8 +147,10 @@ void Recipients::register_recipient(u_int16_t recipient_id,
     recipient_queues[recipient_id]->setEnabledCategories(enabled_categories);
     recipient_queues[recipient_id]->setEnabledEntities(enabled_entities);
     recipient_queues[recipient_id]->setEnabledHostPools(enabled_host_pools);
-    recipient_queues[recipient_id]->setEnabledFlowChecks(enabled_flow_checks);
-    recipient_queues[recipient_id]->setEnabledHostChecks(enabled_host_checks);
+    recipient_queues[recipient_id]->setEnabledFlowAlertTypes(enabled_flow_alert_types);
+    recipient_queues[recipient_id]->setEnabledHostAlertTypes(enabled_host_alert_types);
+    recipient_queues[recipient_id]->setEnabledOtherAlertTypes(enabled_other_alert_types);
+    recipient_queues[recipient_id]->toggleAlertIDMatch(match_alert_id);
     recipient_queues[recipient_id]->setSkipAlerts(skip_alerts);
   }
 
