@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@ SQLiteAlertStore::SQLiteAlertStore(int interface_id, const char *filename)
     : SQLiteStoreManager(interface_id) {
   char filePath[MAX_PATH + 256];
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   /* Create the directories needed to keep the alerts database */
   snprintf(filePath, sizeof(filePath), "%s/%d/alerts/", ntop->get_working_dir(),
            ifid);
@@ -141,7 +142,7 @@ static int getAlertsCallback(void *data, int argc, char **argv,
 
 /* **************************************************** */
 
-bool SQLiteAlertStore::query(lua_State *vm, const char *query) {
+bool SQLiteAlertStore::query(lua_State *vm, const char *query, bool limit_rows) {
   int rc = SQLITE_ERROR;
 
   if (!ntop->getPrefs()->are_alerts_disabled()) {
