@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2018-23 - ntop.org
+ * (C) 2018-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,10 @@
 
 /* ******************************************************* */
 
-TimeseriesExporter::TimeseriesExporter(NetworkInterface *_if) { iface = _if; }
+TimeseriesExporter::TimeseriesExporter(NetworkInterface *_if) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  iface = _if;
+}
 
 /* ******************************************************* */
 
