@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,20 +24,22 @@
 /* ******************************* */
 
 Trace::Trace() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   traceLevel = TRACE_LEVEL_NORMAL;
   logFile = NULL;
   logFd = NULL;
   traceRedis = NULL;
-
+  dontFreeRedis = false;
   open_log();
 };
 
 /* ******************************* */
 
 Trace::~Trace() {
-  if (logFd) fclose(logFd);
+  if (logFd)   fclose(logFd);
   if (logFile) free(logFile);
-  if (traceRedis) delete traceRedis;
+  if (traceRedis && (!dontFreeRedis))
+    delete traceRedis;
 };
 
 /* ******************************* */
@@ -109,6 +111,7 @@ void Trace::initRedis(const char *redis_host, const char *redis_password,
                       u_int16_t redis_port, u_int8_t _redis_db_id) {
   Utils::initRedis(&traceRedis, redis_host, redis_password, redis_port,
                    _redis_db_id, false);
+  dontFreeRedis = false; /* Free traceRedis on shutdown */
 }
 
 /* ******************************* */
@@ -207,6 +210,13 @@ void Trace::logEvent(int eventTraceLevel, char *log_line) {
 
 /* ******************************* */
 
+void Trace::setRedis(Redis *r) {
+  traceRedis = r;
+  dontFreeRedis = true; /* No need to free traceRedis as this is a shared pointer */
+}
+
+/* ******************************* */
+
 #ifdef WIN32
 
 /* service_win32.cpp */
