@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,10 @@
 
 /* *************************************** */
 
-TrafficStats::TrafficStats() { numPkts.reset(), numBytes.reset(); }
+TrafficStats::TrafficStats() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  numPkts.reset(), numBytes.reset();
+}
 
 /* *************************************** */
 
