@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,11 +23,58 @@
 
 /* *************************************** */
 
-UsedPorts::UsedPorts() { ; }
+UsedPorts::UsedPorts(Host* _h) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  h = _h, bitmap_server_ports = NULL;
+}
 
 /* *************************************** */
 
-UsedPorts::~UsedPorts() { ; }
+UsedPorts::UsedPorts() {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  h = NULL, bitmap_server_ports = NULL;;
+}
+
+/* *************************************** */
+
+void UsedPorts::restore() {
+  if(h && (bitmap_server_ports == NULL)) {
+    char redis_key[128];
+
+    bitmap_server_ports = new (std::nothrow) ServerPortsBitmap();
+
+    if(bitmap_server_ports != NULL) {
+      getRedisKey(redis_key, sizeof(redis_key));
+      
+      u_int actual_len = ntop->getRedis()->len(redis_key);
+      char* json_str = (char *)malloc(actual_len + 1);
+      
+      if(json_str != NULL) {
+	if ((ntop->getRedis()->get(redis_key, json_str, actual_len + 1)) == 0) {
+	  if (!(bitmap_server_ports->deserializer((const char*) json_str)))
+	    ntop->getTrace()->traceEvent(TRACE_WARNING, "Bitmap deserialization went wrong");
+	}
+	
+	free(json_str);
+      }
+    }
+  }
+}
+
+/* *************************************** */
+
+UsedPorts::~UsedPorts() { 
+  if(bitmap_server_ports) {
+    if(h) {
+      char redis_key[128];
+      
+      getRedisKey(redis_key, 128);
+      ntop->getRedis()->set(redis_key, bitmap_server_ports->serializer());
+    }
+
+    delete bitmap_server_ports;
+  }
+}
 
 /* *************************************** */
 
@@ -48,10 +95,9 @@ void UsedPorts::setLuaArray(
       char str[32], buf[64];
 
       snprintf(str, sizeof(str), "%s:%u", isTCP ? "tcp" : "udp", it->first);
-      lua_push_str_table_entry(
-          vm, str,
-          ndpi_protocol2name(iface->get_ndpi_struct(), it->second, buf,
-                             sizeof(buf)));
+      lua_push_str_table_entry(vm, str,
+			       ndpi_protocol2name(iface->get_ndpi_struct(), it->second, buf,
+						  sizeof(buf)));
     }
   }
 }
@@ -61,10 +107,9 @@ void UsedPorts::setLuaArray(
 void UsedPorts::lua(lua_State *vm, NetworkInterface *iface) {
   lua_newtable(vm);
 
-  lua_newtable(vm);
-
   /* ***************************** */
-
+  lua_newtable(vm);
+  
   setLuaArray(vm, iface, true, &tcp_server_ports);
   setLuaArray(vm, iface, false, &udp_server_ports);
 
@@ -92,16 +137,29 @@ void UsedPorts::lua(lua_State *vm, NetworkInterface *iface) {
 
 /* *************************************** */
 
-void UsedPorts::setServerPort(bool isTCP, u_int16_t port,
+/*Return false if not new server port are detected after the learning period, true otherwise */
+bool UsedPorts::setServerPort(bool isTCP, u_int16_t port,
                               ndpi_protocol *proto) {
+  bool set_new_port = false;
+
+  restore();
+  
   if (isTCP) {
     if((proto->master_protocol == NDPI_PROTOCOL_FTP_DATA)
        || (proto->app_protocol == NDPI_PROTOCOL_FTP_DATA))
       ;
-    else
+    else {
+      if (tcp_server_ports.count(port) == 0) set_new_port = true;
       tcp_server_ports[port] = *proto;
-  } else
+      if(bitmap_server_ports) bitmap_server_ports->addPort(true, port);
+    }
+  } else {
+    if (udp_server_ports.count(port) == 0) set_new_port = true;
     udp_server_ports[port] = *proto;
+    if(bitmap_server_ports) bitmap_server_ports->addPort(false, port);
+  }
+
+  return set_new_port;
 }
 
 /* *************************************** */
@@ -113,3 +171,13 @@ void UsedPorts::setContactedPort(bool isTCP, u_int16_t port,
   else
     udp_client_contacted_ports[port] = *proto;
 }
+
+/* *************************************** */
+
+char* UsedPorts::getRedisKey(char *redis_key, size_t key_len) {
+  static char buf[64];
+
+  snprintf(redis_key, key_len, LOCALHOST_SERVER_PORT_BITMAP, 
+        h->getInterface()->get_id(), h->getSerializationKey(buf, sizeof(buf)));
+  return redis_key;
+}
