@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@
 
 ViewInterface::ViewInterface(const char *_endpoint)
     : NetworkInterface(_endpoint) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   is_view = true; /* This is a view interface */
   is_packet_interface = true;
 
@@ -266,28 +267,6 @@ u_int32_t ViewInterface::getNumPacketDrops() {
 
 /* **************************************************** */
 
-u_int64_t ViewInterface::getNumDiscardedProbingPackets() const {
-  u_int64_t tot = 0;
-
-  for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
-    tot += viewed_interfaces[s]->getNumDiscardedProbingPackets();
-
-  return (tot);
-};
-
-/* **************************************************** */
-
-u_int64_t ViewInterface::getNumDiscardedProbingBytes() const {
-  u_int64_t tot = 0;
-
-  for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
-    tot += viewed_interfaces[s]->getNumDiscardedProbingBytes();
-
-  return (tot);
-};
-
-/* **************************************************** */
-
 u_int64_t ViewInterface::getNumNewFlows() {
   u_int64_t tot = 0;
 
@@ -388,25 +367,47 @@ u_int32_t ViewInterface::getCheckPointNumPacketDrops() {
 
 /* **************************************************** */
 
-u_int64_t ViewInterface::getCheckPointNumDiscardedProbingPackets() const {
+u_int64_t ViewInterface::getCheckPointNumTrafficSent() const {
   u_int64_t tot = 0;
 
   for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
-    tot += viewed_interfaces[s]->getCheckPointNumDiscardedProbingPackets();
+    tot += viewed_interfaces[s]->getCheckPointNumTrafficSent();
 
   return (tot);
-};
+}
 
 /* **************************************************** */
 
-u_int64_t ViewInterface::getCheckPointNumDiscardedProbingBytes() const {
+u_int64_t ViewInterface::getCheckPointNumTrafficRcvd() const {
   u_int64_t tot = 0;
 
   for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
-    tot += viewed_interfaces[s]->getCheckPointNumDiscardedProbingBytes();
+    tot += viewed_interfaces[s]->getCheckPointNumTrafficRcvd();
 
   return (tot);
-};
+}
+
+/* **************************************************** */
+
+u_int64_t ViewInterface::getCheckPointNumPacketsSent() const {
+  u_int64_t tot = 0;
+
+  for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
+    tot += viewed_interfaces[s]->getCheckPointNumPacketsSent();
+
+  return (tot);
+}
+
+/* **************************************************** */
+
+u_int64_t ViewInterface::getCheckPointNumPacketsRcvd() const {
+  u_int64_t tot = 0;
+
+  for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
+    tot += viewed_interfaces[s]->getCheckPointNumPacketsRcvd();
+
+  return (tot);
+}
 
 /* **************************************************** */
 
@@ -457,14 +458,13 @@ void ViewInterface::sumStats(TcpFlowStats *_tcpFlowStats, EthStats *_ethStats,
                              LocalTrafficStats *_localStats,
                              nDPIStats *_ndpiStats, PacketStats *_pktStats,
                              TcpPacketStats *_tcpPacketStats,
-                             ProtoStats *_discardedProbingStats,
                              DSCPStats *_dscpStats, SyslogStats *_syslogStats,
                              RoundTripStats *_downloadStats,
                              RoundTripStats *_uploadStats) const {
   for (u_int8_t s = 0; s < num_viewed_interfaces; s++)
     viewed_interfaces[s]->sumStats(_tcpFlowStats, _ethStats, _localStats,
                                    _ndpiStats, _pktStats, _tcpPacketStats,
-                                   _discardedProbingStats, _dscpStats,
+				   _dscpStats,
                                    _syslogStats, _downloadStats, _uploadStats);
 }
 
@@ -495,10 +495,8 @@ Flow *ViewInterface::findFlowByTuple(u_int16_t vlan_id,
 void ViewInterface::viewed_flows_walker(Flow *f, const struct timeval *tv) {
   NetworkStats *network_stats;
   PartializableFlowTrafficStats partials;
-  bool first_partial; /* Whether this is the first time the view is visiting
-                         this flow */
-  const IpAddress *cli_ip = f->get_cli_ip_addr(),
-                  *srv_ip = f->get_srv_ip_addr();
+  bool first_partial; /* Whether this is the first time the view is visiting this flow */
+  const IpAddress *cli_ip = f->get_cli_ip_addr(), *srv_ip = f->get_srv_ip_addr();
 
   if (f->get_last_seen() > getTimeLastPktRcvd())
     setTimeLastPktRcvd(f->get_last_seen());
@@ -516,9 +514,8 @@ void ViewInterface::viewed_flows_walker(Flow *f, const struct timeval *tv) {
       host timers and score
     */
     if (!cli_ip || !srv_ip)
-      ntop->getTrace()->traceEvent(
-          TRACE_ERROR,
-          "Unable to get flow hosts. Out of memory? Expect issues.");
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+				   "Unable to get flow hosts. Out of memory? Expect issues.");
 
     if (cli_ip && srv_ip) {
       Host *cli_host, *srv_host;
@@ -539,7 +536,8 @@ void ViewInterface::viewed_flows_walker(Flow *f, const struct timeval *tv) {
 	}
 #endif
 	
-        findFlowHosts(f->get_vlan_id(), f->get_observation_point_id(),
+        findFlowHosts(f->getInterfaceIndex(),
+		      f->get_vlan_id(), f->get_observation_point_id(),
                       f->getPrivateFlowId(), srcMac,
                       (IpAddress *)cli_ip, &cli_host, dstMac,
                       (IpAddress *)srv_ip, &srv_host);
@@ -819,24 +817,33 @@ void ViewInterface::lua_queues_stats(lua_State *vm) {
 /* **************************************************** */
 
 #ifdef NTOPNG_PRO
-void ViewInterface::getFlowDevices(lua_State *vm) {
+void ViewInterface::getFlowDevices(lua_State *vm) {  
   for (int i = 0; i < num_viewed_interfaces; i++)
     viewed_interfaces[i]->getFlowDevices(vm);
 }
 
 /* **************************************************** */
 
-void ViewInterface::getFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP) {
+void ViewInterface::getFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP, bool showAllStats) {
   for (int i = 0; i < num_viewed_interfaces; i++)
-    viewed_interfaces[i]->getFlowDeviceInfo(vm, deviceIP);
+    viewed_interfaces[i]->getFlowDeviceInfo(vm, deviceIP, showAllStats);
+}
+
+/* **************************************************** */
+
+void ViewInterface::getFlowDeviceInfoByIP(lua_State *vm, u_int32_t deviceIP, bool showAllStats) {
+  for (int i = 0; i < num_viewed_interfaces; i++)
+    viewed_interfaces[i]->getFlowDeviceInfoByIP(vm, deviceIP, showAllStats);
 }
 #endif
 
 /* **************************************************** */
 
-void ViewInterface::getSFlowDevices(lua_State *vm) {
+void ViewInterface::getSFlowDevices(lua_State *vm, bool add_table) {
+  if(add_table) lua_newtable(vm);
+  
   for (int i = 0; i < num_viewed_interfaces; i++)
-    viewed_interfaces[i]->getSFlowDevices(vm);
+    viewed_interfaces[i]->getSFlowDevices(vm, false);
 }
 
 /* **************************************************** */
@@ -847,3 +854,15 @@ void ViewInterface::getSFlowDeviceInfo(lua_State *vm, u_int32_t deviceIP) {
 }
 
 /* **************************************************** */
+
+void ViewInterface::lua(lua_State *vm, bool fullStats) {
+  NetworkInterface::lua(vm, fullStats);
+  lua_newtable(vm);
+  for (int i = 0; i < num_viewed_interfaces; i++)
+    viewed_interfaces[i]->probeLuaStats(vm);
+  lua_pushstring(vm, "probes");
+  lua_insert(vm, -2);
+  lua_settable(vm, -3);
+}
+
+/* **************************************************** */
