@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-23 - ntop.org
+ * (C) 2015-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 VirtualHostHash::VirtualHostHash(NetworkInterface *_iface, u_int _num_hashes,
                                  u_int _max_hash_size)
     : GenericHash(_iface, _num_hashes, _max_hash_size, "VirtualHostHash") {
-  ;
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
 }
 
 /* *********************************************************** */
