@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2016-23 - ntop.org
+ * (C) 2016-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,8 +32,9 @@ ZCCollectorInterface::ZCCollectorInterface(const char *name)
   char ifname[32];
   char *at;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   cluster_id = queue_id = 0;
-
   snprintf(ifname, sizeof(ifname), "%s", &name[7]);
 
   at = strchr(ifname, '@');
@@ -91,7 +92,7 @@ void ZCCollectorInterface::collect_flows() {
       u_char *json = pfring_zc_pkt_buff_data(buffer, zq);
       const char *master = "{ \"if.name\"";
 
-      ntop->getTrace()->traceEvent(TRACE_INFO, "%s", json);
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s", json);
       // fprintf(stdout, "+"); fflush(stdout);
 
       if (strncmp((char *)json, master, strlen(master)) == 0) {
