@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,8 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
   char *tmp, *e, *t;
   const char **topics = Utils::getMessagingTopics();
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   num_subscribers = 0;
   server_secret_key[0] = '\0';
   server_public_key[0] = '\0';
@@ -65,34 +67,15 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
     if (subscriber[num_subscribers].socket == NULL)
       ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to create ZMQ socket");
 
-    if (ntop->getPrefs()->is_zmq_encryption_enabled()
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-        || ntop->getPro()->enableCloudCollection()
-#endif
-       ) {
+    if (ntop->getPrefs()->is_zmq_encryption_enabled()) {
 #if ZMQ_VERSION >= ZMQ_MAKE_VERSION(4, 1, 0)
       const char *secret_key;
 
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-      if (ntop->getPro()->enableCloudCollection()) {
-        ntop->getPro()->generateCloudEncryptionKeys();
+      if (ntop->getPrefs()->get_zmq_encryption_priv_key() == NULL)
+        ZMQUtils::generateEncryptionKeys();
 
-        secret_key = ntop->getPro()->findCloudEncryptionKeys(server_public_key, server_secret_key,
-          sizeof(server_public_key), sizeof(server_secret_key)); 
-
-        if (secret_key == NULL || strlen(secret_key) == 0) {
-          ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to enable ZMQ with encryption");
-          throw("Unable to collect flows");
-        }
-      } else
-#endif
-      {
-        if (ntop->getPrefs()->get_zmq_encryption_priv_key() == NULL)
-          ZMQUtils::generateEncryptionKeys();
-
-        secret_key = findInterfaceEncryptionKeys(server_public_key, server_secret_key,
-                                                 sizeof(server_public_key), sizeof(server_secret_key));
-      }
+      secret_key = findInterfaceEncryptionKeys(server_public_key, server_secret_key,
+                                               sizeof(server_public_key), sizeof(server_secret_key));
 
       if (secret_key != NULL) {
         if (ZMQUtils::setServerEncryptionKeys(subscriber[num_subscribers].socket, secret_key) != 0)
@@ -101,10 +84,6 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
 #else
       ntop->getTrace()->traceEvent(TRACE_ERROR,
           "Unable to enable ZMQ CURVE encryption, ZMQ >= 4.1 is required");
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-      if (ntop->getPro()->enableCloudCollection())
-        throw("Unable to collect flows");
-#endif
 #endif
     }
 
@@ -295,9 +274,8 @@ void ZMQCollectorInterface::collect_flows() {
       sleep(1);
 
       if (ntop->getGlobals()->isShutdown()) {
-        ntop->getTrace()->traceEvent(
-            TRACE_NORMAL,
-            "Flow collection on %s is over: ntop is shutting down", ifname);
+        ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				     "Flow collection on %s is over: ntop is shutting down", ifname);
         free(payload);
         return;
       }
@@ -315,13 +293,15 @@ void ZMQCollectorInterface::collect_flows() {
 
       if (rc < 0 || !isRunning()) {
         if (payload) free(payload);
-        ntop->getTrace()->traceEvent(
-            TRACE_NORMAL, "Flow collection is over: ntop is shutting down");
+        ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				     "Flow collection is over on %s: ntop is shutting down",
+				     ifname);
         return;
       }
 
-      if ((rc == 0) || (now >= next_purge_idle) ||
-          (zmq_max_num_polls_before_purge == 0)) {
+      if ((rc == 0)
+	  || (now >= next_purge_idle)
+	  || (zmq_max_num_polls_before_purge == 0)) {
         checkIdleProbes(now);
         purgeIdle(now);
         next_purge_idle = now + FLOW_PURGE_FREQUENCY;
@@ -527,13 +507,6 @@ void ZMQCollectorInterface::collect_flows() {
                                          uncompressed, msg_id, h->url);
           }
 
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-          if (ntop->getPro()->handleProbeMessage(probe, h, uncompressed, uncompressed_len, source_id, msg_id)) {
-            /* Handled - nothing to do */
-            goto recv_next;
-          }
-#endif
-
           /* Allocate probe info if it's the first time we see it */
           if (probe == NULL) {
             probe = (zmq_probe *) calloc(1, sizeof(zmq_probe));
@@ -612,7 +585,6 @@ void ZMQCollectorInterface::collect_flows() {
           /* ntop->getTrace()->traceEvent(TRACE_INFO, "[%s] %s", h->url,
            * uncompressed); */
 
-         recv_next:
 #ifdef HAVE_ZLIB
           if (compressed /* only if the traffic was actually compressed */)
             if (uncompressed) free(uncompressed);
@@ -658,55 +630,42 @@ bool ZMQCollectorInterface::set_packet_filter(char *filter) {
 
 /* **************************************************** */
 
-void ZMQCollectorInterface::lua(lua_State *vm) {
-  ZMQParserInterface::lua(vm);
+void ZMQCollectorInterface::lua(lua_State *vm, bool fullStats) {
+  ZMQParserInterface::lua(vm, fullStats);
 
   lua_newtable(vm);
   lua_push_uint64_table_entry(vm, "flows", recvStats.num_flows);
-  lua_push_uint64_table_entry(vm, "dropped_flows", recvStats.num_dropped_flows);
-  lua_push_uint64_table_entry(vm, "events", recvStats.num_events);
-  lua_push_uint64_table_entry(vm, "counters", recvStats.num_counters);
-  lua_push_uint64_table_entry(vm, "zmq_msg_rcvd", recvStats.zmq_msg_rcvd);
-  lua_push_uint64_table_entry(vm, "zmq_msg_drops", recvStats.zmq_msg_drops);
+  lua_push_uint64_table_entry(vm, "dropped_flows", recvStats.num_dropped_flows); /* Dropped Flows (due to licenses restrictions, our of memory...) */
+  lua_push_uint64_table_entry(vm, "events", recvStats.num_events);               /* Interface Updates */
+  lua_push_uint64_table_entry(vm, "counters", recvStats.num_counters);           /* sFlow Counters */
+  lua_push_uint64_table_entry(vm, "zmq_msg_rcvd", recvStats.zmq_msg_rcvd);       /* Collected ZMQ Messages */
+  lua_push_uint64_table_entry(vm, "zmq_msg_drops", recvStats.zmq_msg_drops);     /* Dropped ZMQ Messages */
   lua_pushstring(vm, "zmqRecvStats");
   lua_insert(vm, -2);
   lua_settable(vm, -3);
 
+  /* ****************** */
+  
   lua_newtable(vm);
-  lua_push_uint64_table_entry(
-      vm, "flows", recvStats.num_flows - recvStatsCheckpoint.num_flows);
-  lua_push_uint64_table_entry(
-      vm, "dropped_flows",
-      recvStats.num_dropped_flows - recvStatsCheckpoint.num_dropped_flows);
-  lua_push_uint64_table_entry(
-      vm, "events", recvStats.num_events - recvStatsCheckpoint.num_events);
-  lua_push_uint64_table_entry(
-      vm, "counters",
-      recvStats.num_counters - recvStatsCheckpoint.num_counters);
-  lua_push_uint64_table_entry(
-      vm, "zmq_msg_rcvd",
-      recvStats.zmq_msg_rcvd - recvStatsCheckpoint.zmq_msg_rcvd);
-  lua_push_uint64_table_entry(
-      vm, "zmq_msg_drops",
-      recvStats.zmq_msg_drops - recvStatsCheckpoint.zmq_msg_drops);
+  lua_push_uint64_table_entry(vm, "flows", recvStats.num_flows - recvStatsCheckpoint.num_flows);
+  lua_push_uint64_table_entry(vm, "dropped_flows",
+			      recvStats.num_dropped_flows - recvStatsCheckpoint.num_dropped_flows);
+  lua_push_uint64_table_entry(vm, "events", recvStats.num_events - recvStatsCheckpoint.num_events);
+  lua_push_uint64_table_entry(vm, "counters",
+			      recvStats.num_counters - recvStatsCheckpoint.num_counters);
+  lua_push_uint64_table_entry(vm, "zmq_msg_rcvd",
+			      recvStats.zmq_msg_rcvd - recvStatsCheckpoint.zmq_msg_rcvd);
+  lua_push_uint64_table_entry(vm, "zmq_msg_drops",
+			      recvStats.zmq_msg_drops - recvStatsCheckpoint.zmq_msg_drops);
   lua_pushstring(vm, "zmqRecvStats_since_reset");
   lua_insert(vm, -2);
   lua_settable(vm, -3);
 
-  if ((ntop->getPrefs()->is_zmq_encryption_enabled() && strlen(server_public_key) > 0)
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-      || ntop->getPro()->enableCloudCollection()
-#endif
-     ) {
+  if ((ntop->getPrefs()->is_zmq_encryption_enabled() && strlen(server_public_key) > 0)) {
     char *probe_key;
     char hex_key[83];
 
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-    if (ntop->getPro()->enableCloudCollection())
-      probe_key = ntop->getPro()->getCloudKey();
-    else
-#endif
-      probe_key = Utils::toHex(server_public_key, strlen(server_public_key), hex_key, sizeof(hex_key));
+    probe_key = Utils::toHex(server_public_key, strlen(server_public_key), hex_key, sizeof(hex_key));
 
     lua_newtable(vm);
     lua_push_str_table_entry(vm, "public_key", probe_key ? probe_key : "");
@@ -728,4 +687,4 @@ void ZMQCollectorInterface::purgeIdle(time_t when, bool force_idle,
 }
 
 #endif
-#endif
\ No newline at end of file
+#endif
