@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2019-23 - ntop.org
+ * (C) 2019-24 - ntop.org
  *
  * This code is proprietary code subject to the terms and conditions
  * defined in LICENSE file which is part of this source code package.
@@ -20,7 +20,8 @@
  * @param endpoint The ZMQ endpoint.
  */
 ZMQPublisher::ZMQPublisher(char *endpoint) {
-
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
   server_secret_key[0] = '\0';
   server_public_key[0] = '\0';
 
@@ -48,34 +49,14 @@ ZMQPublisher::ZMQPublisher(char *endpoint) {
     throw "Unable to initialize ZMQ (pub_socket)";
   }
 
-  if (ntop->getPrefs()->is_zmq_encryption_enabled()
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-        || ntop->getPro()->enableCloudCollection()
-#endif
-     ) {
+  if (ntop->getPrefs()->is_zmq_encryption_enabled()) {
 #if ZMQ_VERSION >= ZMQ_MAKE_VERSION(4, 1, 0)
     const char *secret_key;
+    if (ntop->getPrefs()->get_zmq_encryption_priv_key() == NULL)
+      ZMQUtils::generateEncryptionKeys();
 
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-    if (ntop->getPro()->enableCloudCollection()) {
-      ntop->getPro()->generateCloudEncryptionKeys();
-
-      secret_key = ntop->getPro()->findCloudEncryptionKeys(server_public_key, server_secret_key,
-        sizeof(server_public_key), sizeof(server_secret_key)); 
-
-      if (secret_key == NULL || strlen(secret_key) == 0) {
-        ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to enable ZMQ with encryption");
-        throw("Unable to publish events");
-      }
-    } else
-#endif
-    {
-      if (ntop->getPrefs()->get_zmq_encryption_priv_key() == NULL)
-        ZMQUtils::generateEncryptionKeys();
-
-      secret_key = ZMQUtils::findEncryptionKeys(server_public_key, server_secret_key,
-        sizeof(server_public_key), sizeof(server_secret_key));
-    }
+    secret_key = ZMQUtils::findEncryptionKeys(server_public_key, server_secret_key,
+      sizeof(server_public_key), sizeof(server_secret_key));
 
     if (secret_key != NULL) {
       if (ZMQUtils::setServerEncryptionKeys(pub_socket, secret_key) < 0)
@@ -84,10 +65,6 @@ ZMQPublisher::ZMQPublisher(char *endpoint) {
 #else
     ntop->getTrace()->traceEvent(TRACE_ERROR,
         "Unable to enable ZMQ CURVE encryption, ZMQ >= 4.1 is required");
-#if defined(NTOPNG_PRO) && !defined(HAVE_NEDGE)
-    if (ntop->getPro()->enableCloudCollection())
-      throw("Unable to collect flows");
-#endif
 #endif
   }
 
