@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 
 #include "flow_alerts_includes.h"
 
-ndpi_serializer* RemoteToLocalInsecureProtoAlert::getAlertJSON(
+ndpi_serializer* RemoteToLocalInsecureFlowAlert::getAlertJSON(
     ndpi_serializer* serializer) {
   Flow* f = getFlow();
 
