@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,18 +22,17 @@
 #include "ntop_includes.h"
 #include "flow_checks_includes.h"
 
+/* ***************************************************** */
+
 void BlacklistedFlow::protocolDetected(Flow *f) {
-  if (f->isBlacklistedFlow()) {
+  if ((f->get_protocol_category() == CUSTOM_CATEGORY_MALWARE) &&
+      !(f->isBlacklistedServer()) &&
+      !(f->isBlacklistedClient())) {
     FlowAlertType alert_type = BlacklistedFlowAlert::getClassType();
     u_int8_t c_score, s_score;
-    risk_percentage cli_score_pctg = CLIENT_FAIR_RISK_PERCENTAGE;
+    risk_percentage cli_score_pctg = CLIENT_HIGH_RISK_PERCENTAGE;
 
-    if (f->isBlacklistedServer())
-      cli_score_pctg =
-          CLIENT_HIGH_RISK_PERCENTAGE; /* High severity for the client as it can
-                                          be compromised */
-
-    computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+    computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
     f->triggerAlertAsync(alert_type, c_score, s_score);
   }
@@ -42,26 +41,8 @@ void BlacklistedFlow::protocolDetected(Flow *f) {
 /* ***************************************************** */
 
 FlowAlert *BlacklistedFlow::buildAlert(Flow *f) {
-  bool is_server_bl = f->isBlacklistedServer();
-  bool is_client_bl = f->isBlacklistedClient();
-  BlacklistedFlowAlert *alert =
-      new (std::nothrow) BlacklistedFlowAlert(this, f);
-
-  if (alert) {
-    /*
-      When a BLACKLISTED client contacts a normal host, the client is assumed to
-      be the attacker and the server the victim When a normal client contacts a
-      BLACKLISTED server, both peers are considered to be attackers When both
-      peers are blacklisted, both are considered attackers
-    */
-    if (is_client_bl && !is_server_bl)
-      alert->setCliAttacker(), alert->setSrvVictim();
-    else if (!is_client_bl && is_server_bl)
-      alert->setCliAttacker(), alert->setSrvAttacker();
-    else if (is_client_bl && is_server_bl)
-      alert->setCliAttacker(), alert->setSrvAttacker();
-  }
-
+  BlacklistedFlowAlert *alert = new (std::nothrow) BlacklistedFlowAlert(this, f);
+  
   return alert;
 }
 
