@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -50,7 +50,7 @@ void BroadcastNonUDPTraffic::flowBegin(Flow *f) {
 
       risk_percentage cli_score_pctg = CLIENT_HIGH_RISK_PERCENTAGE;
 
-      computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+      computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
       f->triggerAlertAsync(alert_type, c_score, s_score);
     }
