@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@ LuaEngine *CustomFlowLuaScript::initVM(const char *script_path) {
 
   if (stat(where, &s) != 0) {
     ntop->getTrace()->traceEvent(
-        TRACE_NORMAL,
+        TRACE_DEBUG,
         "Unable to find script %s: ignored `Flow User Check Script` flow check",
         where);
     return (NULL);
@@ -52,10 +52,10 @@ LuaEngine *CustomFlowLuaScript::initVM(const char *script_path) {
     LuaEngine *lua;
 
     try {
-      lua = new LuaEngine(NULL);
-      lua->load_script(
-          (char *)where,
-          NULL /* NetworkInterface filled later via lua->setFlow(f); */);
+      lua = new LuaEngine();
+      lua->load_script((char *)where,
+		       lua_engine_mode_callback,
+		       NULL /* NetworkInterface filled later via lua->setFlow(f); */);
       ntop->getTrace()->traceEvent(TRACE_NORMAL, "Loaded custom user script %s",
                                    where);
     } catch (std::bad_alloc &ba) {
@@ -185,7 +185,7 @@ void CustomFlowLuaScript::checkFlow(Flow *f, LuaEngine *lua) {
     u_int8_t c_score, s_score;
     risk_percentage cli_score_pctg = CLIENT_FAIR_RISK_PERCENTAGE;
 
-    computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+    computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
     f->triggerAlertAsync(alert_type, c_score, s_score);
   }
