@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@ void LowGoodputFlow::checkLowGoodput(Flow *f) {
       break; /* Continue with the check */
   };
 
-  computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+  computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
   f->triggerAlertAsync(alert_type, c_score, s_score);
 }
