@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,7 @@
  *
  */
 
+
 #include "ntop_includes.h"
 #include "flow_checks_includes.h"
 
@@ -35,9 +36,16 @@ void RemoteAccess::protocolDetected(Flow *f) {
     case NDPI_PROTOCOL_CATEGORY_VPN:
     case NDPI_PROTOCOL_CATEGORY_FILE_SHARING:
       if (!f->isLocalToLocal()) {
+  #ifdef DEBUG_REMOTE_ACCESS
+        ntop->getTrace()->traceEvent(
+            TRACE_WARNING, "SYN Flag %s for flow %p; flags: %u",
+            (f->getTcpFlags() & TH_SYN) ? "set" : "not set", f,
+            f->getTcpFlags());
+        break;
+  #endif
         if (cli) cli->incrRemoteAccess();
 
-        computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+        computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
         f->triggerAlertAsync(alert_type, c_score, s_score);
       }
       break;
