@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -110,22 +110,24 @@ bool UnexpectedServer::loadConfiguration(json_object *config) {
         /* Domain name */
         char whitelisted_domain[255];
 
-        snprintf(whitelisted_domain, sizeof(whitelisted_domain), "%s",
-                 server_ptr);
+        snprintf(whitelisted_domain, sizeof(whitelisted_domain), "%s", server_ptr);
         Utils::stringtolower(whitelisted_domain);
 
         if (!whitelist_automa) whitelist_automa = ndpi_init_automa();
 
         if (whitelist_automa) {
           char *str = strdup(whitelisted_domain);
-          if (str) {
-            ndpi_add_string_to_automa(whitelist_automa, str);
-          }
+	  
+          if (str)
+            ndpi_add_string_to_automa(whitelist_automa, str);          
         }
       }
     }
   }
 
+  if(whitelist_automa)
+    ndpi_finalize_automa(whitelist_automa);
+  
   return (true);
 }
 
@@ -139,7 +141,7 @@ void UnexpectedServer::protocolDetected(Flow *f) {
     u_int8_t c_score, s_score;
     risk_percentage cli_score_pctg = CLIENT_HIGH_RISK_PERCENTAGE;
 
-    computeCliSrvScore(alert_type, cli_score_pctg, &c_score, &s_score);
+    computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
     f->triggerAlertAsync(alert_type, c_score, s_score);
   }
