@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-23 - ntop.org
+ * (C) 2013-24 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,8 @@
 
 nDPIStats::nDPIStats(bool _enable_throughput_stats,
                      bool _enable_behavior_stats) {
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
 #ifdef NTOPNG_PRO
   nextMinPeriodicUpdate = 0;
 #endif
@@ -38,6 +40,8 @@ nDPIStats::nDPIStats(bool _enable_throughput_stats,
 nDPIStats::nDPIStats(nDPIStats &stats) {
   std::unordered_map<u_int16_t, ProtoCounter *>::iterator it;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  
 #ifdef NTOPNG_PRO
   nextMinPeriodicUpdate = 0;
 #endif
@@ -74,6 +78,8 @@ nDPIStats::nDPIStats(nDPIStats &stats) {
 nDPIStats::~nDPIStats() {
   std::unordered_map<u_int16_t, ProtoCounter *>::iterator it;
 
+  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+  
   for (it = counters.begin(); it != counters.end(); ++it) {
     ProtoCounter *c = it->second;
 
@@ -87,11 +93,11 @@ void nDPIStats::sum(nDPIStats *stats) {
   std::unordered_map<u_int16_t, ProtoCounter *>::iterator it;
   std::unordered_map<u_int16_t, CategoryCounter>::iterator it1;
 
-  for (it = stats->counters.begin(); it != stats->counters.end(); ++it) {
+  for (it = counters.begin(); it != counters.end(); ++it) {
     u_int16_t proto_id = it->first;
     ProtoCounter *c = it->second;
     std::unordered_map<u_int16_t, ProtoCounter *>::iterator it1 =
-        counters.find(proto_id);
+        stats->counters.find(proto_id);
 
     if (it1 != counters.end())
       it1->second->sum(c);
@@ -101,19 +107,19 @@ void nDPIStats::sum(nDPIStats *stats) {
 
       if (pc != NULL) {
         pc->sum(c);
-        counters[proto_id] = pc;
+        stats->counters[proto_id] = pc;
       }
     }
   }
 
-  for (it1 = stats->cat_counters.begin(); it1 != stats->cat_counters.end();
+  for (it1 = cat_counters.begin(); it1 != cat_counters.end();
        ++it1) {
     u_int16_t cat_id = it1->first;
 
-    if (cat_counters.find(cat_id) == cat_counters.end())
-      cat_counters[cat_id] = it1->second;
+    if (stats->cat_counters.find(cat_id) == stats->cat_counters.end())
+      stats->cat_counters[cat_id] = it1->second;
     else
-      cat_counters[cat_id].sum(it1->second);
+      stats->cat_counters[cat_id].sum(it1->second);
   }
 }
 
@@ -171,8 +177,7 @@ void nDPIStats::incStats(u_int32_t when, u_int16_t proto_id,
   if (cbr != counters.end()) {
     pc = cbr->second;
   } else {
-    pc = new (std::nothrow)
-        ProtoCounter(proto_id, enable_throughput_stats, enable_behavior_stats);
+    pc = new (std::nothrow)ProtoCounter(proto_id, enable_throughput_stats, enable_behavior_stats);
 
     if (!pc) return;
 
